(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 9.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       157,          7]
NotebookDataLength[     52878,       1637]
NotebookOptionsPosition[     49826,       1531]
NotebookOutlinePosition[     50184,       1547]
CellTagsIndexPosition[     50141,       1544]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{
Cell[TextData[{
 "Reference: Maciej Maliborski and Andrzej Rostworowski, ",
 StyleBox["\[OpenCurlyDoubleQuote]Lecture Notes on Turbulent Instability of \
Anti-de Sitter Spacetime\[CloseCurlyDoubleQuote]",
  FontSlant->"Italic"]
}], "Text",
 CellChangeTimes->{{3.5846803289472437`*^9, 3.5846803851255503`*^9}}],

Cell[CellGroupData[{

Cell["Derivation of the field equations", "Subsection",
 CellChangeTimes->{{3.580292671457686*^9, 3.580292675562725*^9}, {
  3.580303668791206*^9, 3.580303677674041*^9}}],

Cell[CellGroupData[{

Cell["Package loading", "Subsubsection",
 CellChangeTimes->{{3.580293321810114*^9, 3.580293323425664*^9}, {
  3.580303651121377*^9, 3.580303654343399*^9}}],

Cell[TextData[{
 "For tensor computations we use the GRQUICK package by Jaime Varela \
available at ",
 ButtonBox["http://library.wolfram.com/infocenter/MathSource/8329",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["http://library.wolfram.com/infocenter/MathSource/8329"], None},
  ButtonNote->"http://library.wolfram.com/infocenter/MathSource/8329"]
}], "Text",
 CellChangeTimes->{{3.580302467155319*^9, 3.5803024678660717`*^9}, {
  3.58030250142693*^9, 3.5803025541002007`*^9}, {3.5838488326226883`*^9, 
  3.58384890190904*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"SetDirectory", "[", 
   RowBox[{"NotebookDirectory", "[", "]"}], "]"}], ";"}]], "Input",
 CellChangeTimes->{{3.583643479779008*^9, 3.5836435001951647`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"<<", "GRQUICK.m"}]], "Input",
 CellChangeTimes->{{3.580293014095889*^9, 3.5802930141017857`*^9}}],

Cell[BoxData[
 SuperscriptBox["\<\"The convention for this program follow Sean M. Carroll's \
(Spacetime and Geometry) and the indices run from 0 \\nto D-1.\\n\\nWhile \
working do not use the variables GARRAY,RARRAY,RsARRAY, CHARRAY, \
SPEEDOFLIGHT.  \\n\\nType ?helpGRQUICK for a list of functions or ?Function \
for a function description.\\n\\nMore functions and improvements coming \
soon!!\"\>", "\[Prime]",
  MultilineFunction->None]], "Print",
 CellChangeTimes->{
  3.5836435020168867`*^9, {3.583643693777875*^9, 3.583643719220331*^9}}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Metric ansatz", "Subsubsection",
 CellChangeTimes->{{3.580293426207161*^9, 3.580293430407048*^9}, {
  3.580302447353703*^9, 3.580302457367387*^9}}],

Cell["", "Text"],

Cell[TextData[{
 "Parametrization of ",
 Cell[BoxData[
  FormBox[
   RowBox[{"(", 
    RowBox[{"3", "+", "1"}], ")"}], TraditionalForm]]],
 " - dimensional asymptotically AdS metric"
}], "Text",
 CellChangeTimes->{{3.5803029516502132`*^9, 3.580302986201507*^9}}],

Cell[BoxData[
 FormBox[
  RowBox[{
   SuperscriptBox["ds", "2"], "=", 
   RowBox[{
    FractionBox["\[ScriptL]", 
     RowBox[{
      SuperscriptBox[
       RowBox[{"cos", " "}], "2"], "x"}]], 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"-", "A"}], " ", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{
         RowBox[{"-", "2"}], " ", "\[Delta]"}]], 
       SuperscriptBox["dt", "2"]}], "+", 
      FractionBox[
       SuperscriptBox["dx", "2"], "A"], "+", 
      RowBox[{
       SuperscriptBox["sin", "2"], "x", " ", 
       SuperscriptBox["d\[CapitalOmega]", "2"]}]}], ")"}]}]}], 
  TraditionalForm]], "Input",
 Evaluatable->False,
 CellChangeTimes->{{3.580302757728442*^9, 3.580302876285923*^9}}],

Cell["where", "Text",
 CellChangeTimes->{{3.5803028819696198`*^9, 3.580302885705689*^9}}],

Cell[BoxData[
 FormBox[
  RowBox[{
   SuperscriptBox["d\[CapitalOmega]", "2"], "=", 
   RowBox[{
    SubsuperscriptBox["d\[Theta]", "1", "2"], "+", 
    RowBox[{
     SubsuperscriptBox["d\[Theta]", "2", "2"], " ", 
     SuperscriptBox["sin", "2"], 
     SubscriptBox["\[Theta]", "1"]}]}]}], TraditionalForm]], "Input",
 Evaluatable->False,
 CellChangeTimes->{{3.580302890352664*^9, 3.5803029374237213`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Metin", "[", 
  RowBox[{
   RowBox[{"DiagonalMatrix", "[", 
    RowBox[{
     FractionBox["\[ScriptL]", 
      SuperscriptBox[
       RowBox[{"Cos", "[", "x", "]"}], "2"]], 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", 
         RowBox[{"A", "[", 
          RowBox[{"t", ",", "x"}], "]"}]}], 
        RowBox[{"Exp", "[", 
         RowBox[{
          RowBox[{"-", "2"}], " ", 
          RowBox[{"\[Delta]", "[", 
           RowBox[{"t", ",", "x"}], "]"}]}], "]"}]}], ",", 
       FractionBox["1", 
        RowBox[{"A", "[", 
         RowBox[{"t", ",", "x"}], "]"}]], ",", 
       RowBox[{
        RowBox[{"Sin", "[", "x", "]"}], "^", "2"}], ",", 
       RowBox[{
        RowBox[{
         RowBox[{"Sin", "[", "x", "]"}], "^", "2"}], " ", 
        RowBox[{
         RowBox[{"Sin", "[", 
          SubscriptBox["\[Theta]", "1"], "]"}], "^", "2"}]}]}], "}"}]}], 
    "]"}], ",", 
   RowBox[{"vars", "=", 
    RowBox[{"{", 
     RowBox[{"t", ",", "x", ",", 
      SubscriptBox["\[Theta]", "1"], ",", 
      SubscriptBox["\[Theta]", "2"]}], "}"}]}]}], "]"}]], "Input",
 CellChangeTimes->{{3.580293154765513*^9, 3.580293237622531*^9}, {
   3.580293379223453*^9, 3.580293408662528*^9}, {3.580293737028533*^9, 
   3.5802937386221867`*^9}, 3.580293798411573*^9, {3.580296258231089*^9, 
   3.5802962679690437`*^9}}],

Cell[BoxData["\<\"Metric Success\"\>"], "Print",
 CellChangeTimes->{{3.583643698458459*^9, 3.58364372591987*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"MatrixForm", "[", "GMET", "]"}]], "Input",
 CellChangeTimes->{{3.580302994767445*^9, 3.580303033953445*^9}}],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{
          RowBox[{"-", "2"}], " ", 
          RowBox[{"\[Delta]", "[", 
           RowBox[{"t", ",", "x"}], "]"}]}]]}], " ", "\[ScriptL]", " ", 
       RowBox[{"A", "[", 
        RowBox[{"t", ",", "x"}], "]"}], " ", 
       SuperscriptBox[
        RowBox[{"Sec", "[", "x", "]"}], "2"]}], "0", "0", "0"},
     {"0", 
      FractionBox[
       RowBox[{"\[ScriptL]", " ", 
        SuperscriptBox[
         RowBox[{"Sec", "[", "x", "]"}], "2"]}], 
       RowBox[{"A", "[", 
        RowBox[{"t", ",", "x"}], "]"}]], "0", "0"},
     {"0", "0", 
      RowBox[{"\[ScriptL]", " ", 
       SuperscriptBox[
        RowBox[{"Tan", "[", "x", "]"}], "2"]}], "0"},
     {"0", "0", "0", 
      RowBox[{"\[ScriptL]", " ", 
       SuperscriptBox[
        RowBox[{"Sin", "[", 
         SubscriptBox["\[Theta]", "1"], "]"}], "2"], " ", 
       SuperscriptBox[
        RowBox[{"Tan", "[", "x", "]"}], "2"]}]}
    },
    GridBoxAlignment->{
     "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
      "RowsIndexed" -> {}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[0.7]}, 
        Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Output",
 CellChangeTimes->{3.580543985129325*^9, 3.583643309951644*^9, 
  3.5836437276755257`*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["The stress-energy tensor", "Subsubsection",
 CellChangeTimes->{{3.5803025948951*^9, 3.580302596306175*^9}, {
  3.580302701508216*^9, 3.580302710132894*^9}}],

Cell[TextData[{
 "Construct the stress-energy tensor for the massless scalar field ",
 Cell[BoxData[
  FormBox["\[Phi]", TraditionalForm]]]
}], "Text",
 CellChangeTimes->{{3.580293899262641*^9, 3.58029392437426*^9}, {
  3.580302714403675*^9, 3.5803027212033978`*^9}, {3.5803032016104107`*^9, 
  3.580303212220682*^9}}],

Cell[BoxData[
 FormBox[
  RowBox[{
   SubscriptBox["T", "\[Alpha]\[Beta]"], "=", 
   RowBox[{
    RowBox[{
     RowBox[{
      SubscriptBox["\[PartialD]", "\[Alpha]"], "\[Phi]"}], 
     RowBox[{
      SubscriptBox["\[PartialD]", "\[Beta]"], "\[Phi]"}]}], "-", 
    RowBox[{
     FractionBox["1", "2"], 
     SubscriptBox["g", "\[Alpha]\[Beta]"], 
     RowBox[{
      SubscriptBox["\[PartialD]", "\[Mu]"], "\[Phi]"}], 
     RowBox[{
      SuperscriptBox["\[PartialD]", "\[Mu]"], "\[Phi]"}]}]}]}], 
  TraditionalForm]], "Input",
 Evaluatable->False,
 CellChangeTimes->{{3.580299915817309*^9, 3.580299997335905*^9}, {
  3.580302285869247*^9, 3.5803023330722017`*^9}, {3.5803031793031178`*^9, 
  3.5803032556358747`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"Tdndn", "[", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"a_", ",", "b_"}], "}"}]}], "}"}], "]"}], ":=", 
   RowBox[{"With", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"xa", "=", 
        RowBox[{"vars", "[", 
         RowBox[{"[", 
          RowBox[{"a", "+", "1"}], "]"}], "]"}]}], ",", 
       RowBox[{"xb", "=", 
        RowBox[{"vars", "[", 
         RowBox[{"[", 
          RowBox[{"b", "+", "1"}], "]"}], "]"}]}]}], "}"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{
       RowBox[{"D", "[", 
        RowBox[{
         RowBox[{"\[Phi]", "[", 
          RowBox[{"t", ",", "x"}], "]"}], ",", "xa"}], "]"}], 
       RowBox[{"D", "[", 
        RowBox[{
         RowBox[{"\[Phi]", "[", 
          RowBox[{"t", ",", "x"}], "]"}], ",", "xb"}], "]"}]}], "-", 
      RowBox[{
       FractionBox["1", "2"], 
       RowBox[{"Metric", "[", 
        RowBox[{"a", ",", "b"}], "]"}], 
       RowBox[{"Sum", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"D", "[", 
           RowBox[{
            RowBox[{"\[Phi]", "[", 
             RowBox[{"t", ",", "x"}], "]"}], ",", 
            RowBox[{"vars", "[", 
             RowBox[{"[", 
              RowBox[{"m", "+", "1"}], "]"}], "]"}]}], "]"}], 
          RowBox[{"D", "[", 
           RowBox[{
            RowBox[{"\[Phi]", "[", 
             RowBox[{"t", ",", "x"}], "]"}], ",", 
            RowBox[{"vars", "[", 
             RowBox[{"[", 
              RowBox[{"n", "+", "1"}], "]"}], "]"}]}], "]"}], 
          RowBox[{"IMetric", "[", 
           RowBox[{"m", ",", "n"}], "]"}]}], ",", 
         RowBox[{"{", 
          RowBox[{"m", ",", "0", ",", "3"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"n", ",", "0", ",", "3"}], "}"}]}], "]"}]}]}]}], 
    "\[IndentingNewLine]", "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.580293855956067*^9, 3.580293877805732*^9}, {
  3.580293956043333*^9, 3.5802939732668743`*^9}, {3.580294038680807*^9, 
  3.580294112008759*^9}, {3.5802941971883793`*^9, 3.580294285545835*^9}, {
  3.580294374995224*^9, 3.580294429111966*^9}, {3.580543038858954*^9, 
  3.5805430437154217`*^9}}],

Cell[BoxData[
 FormBox[
  RowBox[{
   SuperscriptBox["T", "\[Alpha]\[Beta]"], "=", 
   RowBox[{
    SuperscriptBox["g", "\[Alpha]\[Mu]"], 
    SuperscriptBox["g", "\[Beta]\[Nu]"], 
    SubscriptBox["T", "\[Mu]\[Nu]"]}]}], TraditionalForm]], "Input",
 Evaluatable->False,
 CellChangeTimes->{{3.580299915817309*^9, 3.580299997335905*^9}, {
  3.580302285869247*^9, 3.5803023330722017`*^9}, {3.5803031793031178`*^9, 
  3.580303303205226*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"Tupup", "[", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"a_", ",", "b_"}], "}"}], ",", 
     RowBox[{"{", "}"}]}], "}"}], "]"}], ":=", 
  RowBox[{"Sum", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"IMetric", "[", 
      RowBox[{"a", ",", "i"}], "]"}], 
     RowBox[{"IMetric", "[", 
      RowBox[{"b", ",", "j"}], "]"}], 
     RowBox[{"Tdndn", "[", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"i", ",", "j"}], "}"}]}], "}"}], "]"}]}], ",", 
    RowBox[{"{", 
     RowBox[{"i", ",", "0", ",", "3"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"j", ",", "0", ",", "3"}], "}"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.580294431111516*^9, 3.5802944465404177`*^9}, {
  3.5802945889097633`*^9, 3.5802946013367567`*^9}, {3.580294636046568*^9, 
  3.5802947045494213`*^9}, {3.580295204339031*^9, 3.580295206979456*^9}, {
  3.580543058301778*^9, 3.5805430738878937`*^9}}],

Cell["Define auxiliary variables", "Text",
 CellChangeTimes->{{3.5802961613608522`*^9, 3.580296169669334*^9}}],

Cell[BoxData[{
 FormBox[
  RowBox[{
   RowBox[{"\[CapitalPhi]", "(", 
    RowBox[{"t", ",", "x"}], ")"}], "=", 
   RowBox[{
    RowBox[{"\[Phi]", "'"}], 
    RowBox[{"(", 
     RowBox[{"t", ",", "x"}], ")"}]}]}], 
  TraditionalForm], "\[IndentingNewLine]", 
 FormBox[
  RowBox[{
   RowBox[{"\[CapitalPi]", "(", 
    RowBox[{"t", ",", "x"}], ")"}], " ", "=", 
   FractionBox[
    RowBox[{
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{"\[Delta]", "(", 
       RowBox[{"t", ",", "x"}], ")"}]], 
     RowBox[{
      OverscriptBox["\[Phi]", "."], "(", 
      RowBox[{"t", ",", "x"}], ")"}]}], 
    RowBox[{"A", "(", 
     RowBox[{"t", ",", "x"}], ")"}]]}], TraditionalForm]}], "Input",
 Evaluatable->False,
 CellChangeTimes->{{3.580303328674642*^9, 3.580303337973645*^9}, {
  3.58030337730733*^9, 3.580303459030464*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"Derivative", "/:", 
   RowBox[{
    RowBox[{
     RowBox[{"Derivative", "[", 
      RowBox[{"0", ",", "1"}], "]"}], "[", "\[Phi]", "]"}], "[", 
    RowBox[{"t_", ",", "x_"}], "]"}], ":=", 
   RowBox[{"\[CapitalPhi]", "[", 
    RowBox[{"t", ",", "x"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Derivative", "/:", 
   RowBox[{
    RowBox[{
     RowBox[{"Derivative", "[", 
      RowBox[{"1", ",", "0"}], "]"}], "[", "\[Phi]", "]"}], "[", 
    RowBox[{"t_", ",", "x_"}], "]"}], ":=", 
   RowBox[{
    RowBox[{"A", "[", 
     RowBox[{"t", ",", "x"}], "]"}], 
    RowBox[{"Exp", "[", 
     RowBox[{"-", 
      RowBox[{"\[Delta]", "[", 
       RowBox[{"t", ",", "x"}], "]"}]}], "]"}], 
    RowBox[{"\[CapitalPi]", "[", 
     RowBox[{"t", ",", "x"}], "]"}]}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.5802959684155493`*^9, 3.580296044444875*^9}, {
  3.58385095309804*^9, 3.583850953837504*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Einsteins equations", "Subsubsection",
 CellChangeTimes->{{3.580303056676907*^9, 3.5803030610947657`*^9}}],

Cell["Set units", "Text",
 CellChangeTimes->{{3.580296175584906*^9, 3.5802962058194304`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"G", "=", 
   FractionBox[
    RowBox[{"3", "-", "1"}], 
    RowBox[{"8", " ", "\[Pi]"}]]}], ";", 
  RowBox[{"\[CapitalLambda]", "=", 
   RowBox[{"-", 
    FractionBox[
     RowBox[{"3", " ", "2"}], 
     RowBox[{"2", " ", 
      SuperscriptBox["\[ScriptL]", "2"]}]]}]}], ";", 
  RowBox[{"\[ScriptL]", "=", "1"}], ";"}]], "Input",
 CellChangeTimes->{{3.580296220931333*^9, 3.5802962442853937`*^9}, {
  3.580296296403368*^9, 3.5802963327963533`*^9}}],

Cell["\<\
Define funciton which calculates (and stores) Einstein\[CloseCurlyQuote]s \
equations\
\>", "Text",
 CellChangeTimes->{{3.580296383942477*^9, 3.580296407745565*^9}}],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{
    SubscriptBox["G", "\[Alpha]\[Beta]"], "+", 
    RowBox[{"\[CapitalLambda]", " ", 
     SubscriptBox["g", "\[Alpha]\[Beta]"]}]}], "=", 
   RowBox[{"8", "\[Pi]", " ", "G", " ", 
    SubscriptBox["T", "\[Alpha]\[Beta]"]}]}], TraditionalForm]], "Input",
 Evaluatable->False,
 CellChangeTimes->{{3.580299915817309*^9, 3.580299997335905*^9}, {
  3.580302285869247*^9, 3.5803023330722017`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"EinsteinEqu", "[", 
   RowBox[{"a_", ",", "b_"}], "]"}], ":=", 
  RowBox[{
   RowBox[{"EinsteinEqu", "[", 
    RowBox[{"a", ",", "b"}], "]"}], "=", 
   RowBox[{
    RowBox[{
     RowBox[{"Einstein", "[", 
      RowBox[{"a", ",", "b"}], "]"}], "+", 
     RowBox[{"\[CapitalLambda]", " ", 
      RowBox[{"Metric", "[", 
       RowBox[{"a", ",", "b"}], "]"}]}]}], "\[Equal]", 
    RowBox[{"8", " ", "\[Pi]", " ", "G", " ", 
     RowBox[{"Tdndn", "[", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"a", ",", "b"}], "}"}]}], "}"}], "]"}]}]}]}]}]], "Input",
 CellChangeTimes->{{3.5802964089640512`*^9, 3.580296446558918*^9}, {
  3.580543096699732*^9, 3.580543099598695*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"EinsteinEqu", "[", 
  RowBox[{"0", ",", "0"}], "]"}]], "Input",
 CellChangeTimes->{{3.580296448271564*^9, 3.580296455686001*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"3", " ", 
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{
      RowBox[{"-", "2"}], " ", 
      RowBox[{"\[Delta]", "[", 
       RowBox[{"t", ",", "x"}], "]"}]}]], " ", 
    RowBox[{"A", "[", 
     RowBox[{"t", ",", "x"}], "]"}], " ", 
    SuperscriptBox[
     RowBox[{"Sec", "[", "x", "]"}], "2"]}], "+", 
   RowBox[{
    FractionBox["1", "2"], " ", 
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{
      RowBox[{"-", "2"}], " ", 
      RowBox[{"\[Delta]", "[", 
       RowBox[{"t", ",", "x"}], "]"}]}]], " ", 
    RowBox[{"A", "[", 
     RowBox[{"t", ",", "x"}], "]"}], " ", 
    SuperscriptBox[
     RowBox[{"Csc", "[", "x", "]"}], "2"], " ", 
    SuperscriptBox[
     RowBox[{"Sec", "[", "x", "]"}], "2"], " ", 
    RowBox[{"(", 
     RowBox[{"1", "+", 
      RowBox[{"2", " ", 
       RowBox[{"A", "[", 
        RowBox[{"t", ",", "x"}], "]"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "2"}], "+", 
         RowBox[{"Cos", "[", 
          RowBox[{"2", " ", "x"}], "]"}]}], ")"}]}], "+", 
      RowBox[{"Cos", "[", 
       RowBox[{"2", " ", "x"}], "]"}], "-", 
      RowBox[{
       RowBox[{"Sin", "[", 
        RowBox[{"2", " ", "x"}], "]"}], " ", 
       RowBox[{
        SuperscriptBox["A", 
         TagBox[
          RowBox[{"(", 
           RowBox[{"0", ",", "1"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"t", ",", "x"}], "]"}]}]}], ")"}]}]}], "\[Equal]", 
  RowBox[{"2", " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"-", "2"}], " ", 
        RowBox[{"\[Delta]", "[", 
         RowBox[{"t", ",", "x"}], "]"}]}]], " ", 
      SuperscriptBox[
       RowBox[{"A", "[", 
        RowBox[{"t", ",", "x"}], "]"}], "2"], " ", 
      SuperscriptBox[
       RowBox[{"\[CapitalPi]", "[", 
        RowBox[{"t", ",", "x"}], "]"}], "2"]}], "+", 
     RowBox[{
      FractionBox["1", "2"], " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"-", "2"}], " ", 
        RowBox[{"\[Delta]", "[", 
         RowBox[{"t", ",", "x"}], "]"}]}]], " ", 
      RowBox[{"A", "[", 
       RowBox[{"t", ",", "x"}], "]"}], " ", 
      SuperscriptBox[
       RowBox[{"Sec", "[", "x", "]"}], "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"-", 
          RowBox[{"A", "[", 
           RowBox[{"t", ",", "x"}], "]"}]}], " ", 
         SuperscriptBox[
          RowBox[{"Cos", "[", "x", "]"}], "2"], " ", 
         SuperscriptBox[
          RowBox[{"\[CapitalPi]", "[", 
           RowBox[{"t", ",", "x"}], "]"}], "2"]}], "+", 
        RowBox[{
         RowBox[{"A", "[", 
          RowBox[{"t", ",", "x"}], "]"}], " ", 
         SuperscriptBox[
          RowBox[{"Cos", "[", "x", "]"}], "2"], " ", 
         SuperscriptBox[
          RowBox[{"\[CapitalPhi]", "[", 
           RowBox[{"t", ",", "x"}], "]"}], "2"]}]}], ")"}]}]}], 
    ")"}]}]}]], "Output",
 CellChangeTimes->{3.580543996776375*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"eq", "[", "1", "]"}], "=", 
  RowBox[{"Equal", "@@@", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"First", "@", 
        RowBox[{"Solve", "[", 
         RowBox[{
          RowBox[{"EinsteinEqu", "[", 
           RowBox[{"0", ",", "0"}], "]"}], ",", 
          RowBox[{
           SuperscriptBox["A", 
            TagBox[
             RowBox[{"(", 
              RowBox[{"0", ",", "1"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"t", ",", "x"}], "]"}]}], "]"}]}], "//", "Simplify"}], "//",
       "Expand"}], "//", "FullSimplify"}], ")"}]}]}]], "Input",
 CellChangeTimes->{{3.5802958246882*^9, 3.5802958568392344`*^9}, {
   3.5802958990843353`*^9, 3.580295910506407*^9}, {3.580296084756558*^9, 
   3.5802961056789007`*^9}, 3.5802963723271303`*^9, {3.58029647076606*^9, 
   3.58029648545932*^9}, {3.580296565578052*^9, 3.58029659257513*^9}, {
   3.5802968154411*^9, 3.5802968200544977`*^9}, {3.580298977182934*^9, 
   3.580299051934916*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    SuperscriptBox["A", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "1"}], ")"}],
      Derivative],
     MultilineFunction->None], "[", 
    RowBox[{"t", ",", "x"}], "]"}], "\[Equal]", 
   RowBox[{
    RowBox[{"Cot", "[", "x", "]"}], "+", 
    RowBox[{"3", " ", 
     RowBox[{"Tan", "[", "x", "]"}]}], "+", 
    RowBox[{
     FractionBox["1", "2"], " ", 
     RowBox[{"A", "[", 
      RowBox[{"t", ",", "x"}], "]"}], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "2"}], " ", 
        RowBox[{"Cot", "[", "x", "]"}]}], "-", 
       RowBox[{"6", " ", 
        RowBox[{"Tan", "[", "x", "]"}]}], "-", 
       RowBox[{
        RowBox[{"Sin", "[", 
         RowBox[{"2", " ", "x"}], "]"}], " ", 
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox[
           RowBox[{"\[CapitalPi]", "[", 
            RowBox[{"t", ",", "x"}], "]"}], "2"], "+", 
          SuperscriptBox[
           RowBox[{"\[CapitalPhi]", "[", 
            RowBox[{"t", ",", "x"}], "]"}], "2"]}], ")"}]}]}], ")"}]}]}]}], 
  "}"}]], "Output",
 CellChangeTimes->{3.580543998735667*^9, 3.583643822430745*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"eq", "[", "2", "]"}], "=", 
  RowBox[{"Equal", "@@@", 
   RowBox[{"(", 
    RowBox[{"First", "@", 
     RowBox[{"Solve", "[", 
      RowBox[{
       RowBox[{"EinsteinEqu", "[", 
        RowBox[{"0", ",", "1"}], "]"}], ",", 
       RowBox[{
        SuperscriptBox["A", 
         TagBox[
          RowBox[{"(", 
           RowBox[{"1", ",", "0"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"t", ",", "x"}], "]"}]}], "]"}]}], ")"}]}]}]], "Input",
 CellChangeTimes->{{3.580296626076467*^9, 3.58029666491304*^9}, {
  3.58029670235826*^9, 3.580296809993572*^9}, {3.5802989923802433`*^9, 
  3.580299000367469*^9}, {3.5802990550438643`*^9, 3.580299057824929*^9}, {
  3.580299090240711*^9, 3.5802991010577297`*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    SuperscriptBox["A", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"1", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "[", 
    RowBox[{"t", ",", "x"}], "]"}], "\[Equal]", 
   RowBox[{
    RowBox[{"-", "2"}], " ", 
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{"-", 
      RowBox[{"\[Delta]", "[", 
       RowBox[{"t", ",", "x"}], "]"}]}]], " ", 
    SuperscriptBox[
     RowBox[{"A", "[", 
      RowBox[{"t", ",", "x"}], "]"}], "2"], " ", 
    RowBox[{"Cos", "[", "x", "]"}], " ", 
    RowBox[{"Sin", "[", "x", "]"}], " ", 
    RowBox[{"\[CapitalPi]", "[", 
     RowBox[{"t", ",", "x"}], "]"}], " ", 
    RowBox[{"\[CapitalPhi]", "[", 
     RowBox[{"t", ",", "x"}], "]"}]}]}], "}"}]], "Output",
 CellChangeTimes->{3.580543999343988*^9, 3.583643860806231*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"eq", "[", "3", "]"}], "=", 
  RowBox[{"Equal", "@@@", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      RowBox[{"First", "@", 
       RowBox[{"Solve", "[", 
        RowBox[{
         RowBox[{"EinsteinEqu", "[", 
          RowBox[{"1", ",", "1"}], "]"}], ",", 
         RowBox[{
          SuperscriptBox["\[Delta]", 
           TagBox[
            RowBox[{"(", 
             RowBox[{"0", ",", "1"}], ")"}],
            Derivative],
           MultilineFunction->None], "[", 
          RowBox[{"t", ",", "x"}], "]"}]}], "]"}]}], "/.", 
      RowBox[{"Rule", "@@@", 
       RowBox[{"eq", "[", "1", "]"}]}]}], "//", "Simplify"}], 
    ")"}]}]}]], "Input",
 CellChangeTimes->{{3.580298514718718*^9, 3.580298520558918*^9}, {
  3.580299002590843*^9, 3.580299008066409*^9}, {3.580299062444069*^9, 
  3.58029914193185*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    SuperscriptBox["\[Delta]", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "1"}], ")"}],
      Derivative],
     MultilineFunction->None], "[", 
    RowBox[{"t", ",", "x"}], "]"}], "\[Equal]", 
   RowBox[{
    RowBox[{"-", 
     RowBox[{"Cos", "[", "x", "]"}]}], " ", 
    RowBox[{"Sin", "[", "x", "]"}], " ", 
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox[
       RowBox[{"\[CapitalPi]", "[", 
        RowBox[{"t", ",", "x"}], "]"}], "2"], "+", 
      SuperscriptBox[
       RowBox[{"\[CapitalPhi]", "[", 
        RowBox[{"t", ",", "x"}], "]"}], "2"]}], ")"}]}]}], "}"}]], "Output",
 CellChangeTimes->{3.580543999503385*^9, 3.583643863098411*^9}]
}, Open  ]],

Cell["Wave equation", "Text",
 CellChangeTimes->{{3.580299159083064*^9, 3.580299161443722*^9}}],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{
    SubscriptBox["\[Del]", "\[Alpha]"], 
    SuperscriptBox["T", "\[Alpha]\[Beta]"]}], "=", "0"}], 
  TraditionalForm]], "Input",
 Evaluatable->False,
 CellChangeTimes->{{3.580299915817309*^9, 3.58030004110063*^9}, {
  3.580540142551118*^9, 3.580540152268283*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"dTupup", "[", "b_", "]"}], ":=", 
  RowBox[{
   RowBox[{"dTupup", "[", "b", "]"}], "=", 
   RowBox[{
    RowBox[{"Sum", "[", 
     RowBox[{
      RowBox[{"Coderv", "[", 
       RowBox[{"\"\<Tupup\>\"", ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"a", ",", "b"}], "}"}], ",", 
          RowBox[{"{", "}"}]}], "}"}], ",", "a"}], "]"}], ",", 
      RowBox[{"{", 
       RowBox[{"a", ",", "0", ",", "3"}], "}"}]}], "]"}], "//", 
    "Simplify"}]}]}]], "Input",
 CellChangeTimes->{{3.580540165493669*^9, 3.580540203415205*^9}, {
  3.580543125615159*^9, 3.580543133803549*^9}, {3.580543314498105*^9, 
  3.580543316375246*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"dTupup", "/@", 
  RowBox[{"Range", "[", 
   RowBox[{"0", ",", "3"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.5805431467532377`*^9, 3.580543178204039*^9}, {
  3.580543301758325*^9, 3.5805433454140863`*^9}, {3.580543933815975*^9, 
  3.580543946261964*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{"\[Delta]", "[", 
      RowBox[{"t", ",", "x"}], "]"}]], " ", 
    SuperscriptBox[
     RowBox[{"Cos", "[", "x", "]"}], "2"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"-", 
        RowBox[{"A", "[", 
         RowBox[{"t", ",", "x"}], "]"}]}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          SuperscriptBox[
           RowBox[{"Cos", "[", "x", "]"}], "2"], " ", 
          RowBox[{"\[CapitalPhi]", "[", 
           RowBox[{"t", ",", "x"}], "]"}], " ", 
          RowBox[{
           SuperscriptBox["\[CapitalPi]", 
            TagBox[
             RowBox[{"(", 
              RowBox[{"0", ",", "1"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"t", ",", "x"}], "]"}]}], "+", 
         RowBox[{
          RowBox[{"\[CapitalPi]", "[", 
           RowBox[{"t", ",", "x"}], "]"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"2", " ", 
             RowBox[{"\[CapitalPhi]", "[", 
              RowBox[{"t", ",", "x"}], "]"}], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"Cot", "[", "x", "]"}], "-", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"Cos", "[", "x", "]"}], "2"], " ", 
                RowBox[{
                 SuperscriptBox["\[Delta]", 
                  TagBox[
                   RowBox[{"(", 
                    RowBox[{"0", ",", "1"}], ")"}],
                   Derivative],
                  MultilineFunction->None], "[", 
                 RowBox[{"t", ",", "x"}], "]"}]}]}], ")"}]}], "+", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"Cos", "[", "x", "]"}], "2"], " ", 
             RowBox[{
              SuperscriptBox["\[CapitalPhi]", 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"t", ",", "x"}], "]"}]}]}], ")"}]}]}], ")"}]}], "-", 
      RowBox[{
       SuperscriptBox[
        RowBox[{"Cos", "[", "x", "]"}], "2"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"\[CapitalPi]", "[", 
           RowBox[{"t", ",", "x"}], "]"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"2", " ", 
             RowBox[{"\[CapitalPhi]", "[", 
              RowBox[{"t", ",", "x"}], "]"}], " ", 
             RowBox[{
              SuperscriptBox["A", 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"t", ",", "x"}], "]"}]}], "-", 
            RowBox[{
             SuperscriptBox["\[ExponentialE]", 
              RowBox[{"\[Delta]", "[", 
               RowBox[{"t", ",", "x"}], "]"}]], " ", 
             RowBox[{
              SuperscriptBox["\[CapitalPi]", 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"t", ",", "x"}], "]"}]}]}], ")"}]}], "-", 
         RowBox[{
          SuperscriptBox["\[ExponentialE]", 
           RowBox[{"\[Delta]", "[", 
            RowBox[{"t", ",", "x"}], "]"}]], " ", 
          RowBox[{"\[CapitalPhi]", "[", 
           RowBox[{"t", ",", "x"}], "]"}], " ", 
          RowBox[{
           SuperscriptBox["\[CapitalPhi]", 
            TagBox[
             RowBox[{"(", 
              RowBox[{"1", ",", "0"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"t", ",", "x"}], "]"}]}]}], ")"}]}]}], ")"}]}], ",", 
   RowBox[{
    RowBox[{"-", 
     RowBox[{"A", "[", 
      RowBox[{"t", ",", "x"}], "]"}]}], " ", 
    SuperscriptBox[
     RowBox[{"Cos", "[", "x", "]"}], "2"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"A", "[", 
        RowBox[{"t", ",", "x"}], "]"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          SuperscriptBox[
           RowBox[{"\[CapitalPhi]", "[", 
            RowBox[{"t", ",", "x"}], "]"}], "2"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"-", "2"}], " ", 
             RowBox[{"Cot", "[", "x", "]"}]}], "+", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"Cos", "[", "x", "]"}], "2"], " ", 
             RowBox[{
              SuperscriptBox["\[Delta]", 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"t", ",", "x"}], "]"}]}]}], ")"}]}], "+", 
         RowBox[{
          SuperscriptBox[
           RowBox[{"Cos", "[", "x", "]"}], "2"], " ", 
          RowBox[{"\[CapitalPi]", "[", 
           RowBox[{"t", ",", "x"}], "]"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"\[CapitalPi]", "[", 
              RowBox[{"t", ",", "x"}], "]"}], " ", 
             RowBox[{
              SuperscriptBox["\[Delta]", 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"t", ",", "x"}], "]"}]}], "-", 
            RowBox[{
             SuperscriptBox["\[CapitalPi]", 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"t", ",", "x"}], "]"}]}], ")"}]}], "-", 
         RowBox[{
          SuperscriptBox[
           RowBox[{"Cos", "[", "x", "]"}], "2"], " ", 
          RowBox[{"\[CapitalPhi]", "[", 
           RowBox[{"t", ",", "x"}], "]"}], " ", 
          RowBox[{
           SuperscriptBox["\[CapitalPhi]", 
            TagBox[
             RowBox[{"(", 
              RowBox[{"0", ",", "1"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"t", ",", "x"}], "]"}]}]}], ")"}]}], "-", 
      RowBox[{
       SuperscriptBox[
        RowBox[{"Cos", "[", "x", "]"}], "2"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          SuperscriptBox[
           RowBox[{"\[CapitalPi]", "[", 
            RowBox[{"t", ",", "x"}], "]"}], "2"], " ", 
          RowBox[{
           SuperscriptBox["A", 
            TagBox[
             RowBox[{"(", 
              RowBox[{"0", ",", "1"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"t", ",", "x"}], "]"}]}], "+", 
         RowBox[{
          RowBox[{"\[CapitalPhi]", "[", 
           RowBox[{"t", ",", "x"}], "]"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"\[CapitalPhi]", "[", 
              RowBox[{"t", ",", "x"}], "]"}], " ", 
             RowBox[{
              SuperscriptBox["A", 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"t", ",", "x"}], "]"}]}], "-", 
            RowBox[{
             SuperscriptBox["\[ExponentialE]", 
              RowBox[{"\[Delta]", "[", 
               RowBox[{"t", ",", "x"}], "]"}]], " ", 
             RowBox[{
              SuperscriptBox["\[CapitalPi]", 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"t", ",", "x"}], "]"}]}]}], ")"}]}], "-", 
         RowBox[{
          SuperscriptBox["\[ExponentialE]", 
           RowBox[{"\[Delta]", "[", 
            RowBox[{"t", ",", "x"}], "]"}]], " ", 
          RowBox[{"\[CapitalPi]", "[", 
           RowBox[{"t", ",", "x"}], "]"}], " ", 
          RowBox[{
           SuperscriptBox["\[CapitalPhi]", 
            TagBox[
             RowBox[{"(", 
              RowBox[{"1", ",", "0"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"t", ",", "x"}], "]"}]}]}], ")"}]}]}], ")"}]}], ",", "0", 
   ",", "0"}], "}"}]], "Output",
 CellChangeTimes->{3.580544002652844*^9, 3.583643874069931*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"eq", "[", "4", "]"}], "=", 
  RowBox[{"With", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"rules", "=", 
      RowBox[{"Flatten", "@", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"Rule", "@@", 
             RowBox[{"First", "[", 
              RowBox[{"eq", "[", "#", "]"}], "]"}]}], "&"}], "/@", 
           RowBox[{"Range", "[", "3", "]"}]}], ")"}], ",", 
         RowBox[{
          RowBox[{
           SuperscriptBox["\[CapitalPhi]", 
            TagBox[
             RowBox[{"(", 
              RowBox[{"1", ",", "0"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"t", ",", "x"}], "]"}], "\[Rule]", 
          RowBox[{"D", "[", 
           RowBox[{
            RowBox[{"\[Phi]", "[", 
             RowBox[{"t", ",", "x"}], "]"}], ",", "t", ",", "x"}], "]"}]}]}], 
        "}"}]}]}], "}"}], ",", "\[IndentingNewLine]", 
    RowBox[{"Equal", "@@@", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{"First", "@", 
          RowBox[{"Solve", "[", 
           RowBox[{
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               RowBox[{"dTupup", "[", "0", "]"}], "//.", "rules"}], ")"}], 
             "\[Equal]", "0"}], ",", 
            RowBox[{
             SuperscriptBox["\[CapitalPi]", 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"t", ",", "x"}], "]"}]}], "]"}]}], "//", "Simplify"}], "//",
         "TrigReduce"}], "//", "FullSimplify"}], ")"}]}]}], 
   "\[IndentingNewLine]", "]"}]}]], "Input",
 CellChangeTimes->{{3.580540478643506*^9, 3.580540513797439*^9}, {
   3.580543351649384*^9, 3.5805433549377747`*^9}, {3.5805433877467318`*^9, 
   3.580543401098445*^9}, {3.5805434355444717`*^9, 3.580543456132163*^9}, {
   3.580543489741644*^9, 3.5805435619264402`*^9}, {3.5805435973642263`*^9, 
   3.580543597897187*^9}, {3.5805436711216917`*^9, 3.5805436921150713`*^9}, 
   3.5805439241679287`*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    SuperscriptBox["\[CapitalPi]", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"1", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "[", 
    RowBox[{"t", ",", "x"}], "]"}], "\[Equal]", 
   RowBox[{
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{"-", 
      RowBox[{"\[Delta]", "[", 
       RowBox[{"t", ",", "x"}], "]"}]}]], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"2", " ", 
       RowBox[{"(", 
        RowBox[{"2", "+", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "1"}], "+", 
            RowBox[{"A", "[", 
             RowBox[{"t", ",", "x"}], "]"}]}], ")"}], " ", 
          RowBox[{"Cos", "[", 
           RowBox[{"2", " ", "x"}], "]"}]}]}], ")"}], " ", 
       RowBox[{"Csc", "[", 
        RowBox[{"2", " ", "x"}], "]"}], " ", 
       RowBox[{"\[CapitalPhi]", "[", 
        RowBox[{"t", ",", "x"}], "]"}]}], "+", 
      RowBox[{
       RowBox[{"A", "[", 
        RowBox[{"t", ",", "x"}], "]"}], " ", 
       RowBox[{
        SuperscriptBox["\[CapitalPhi]", 
         TagBox[
          RowBox[{"(", 
           RowBox[{"0", ",", "1"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"t", ",", "x"}], "]"}]}]}], ")"}]}]}], "}"}]], "Output",
 CellChangeTimes->{3.58054400380905*^9, 3.583643875044368*^9}]
}, Open  ]],

Cell["Cross check with equations in a paper", "Text",
 CellChangeTimes->{{3.580300300070911*^9, 3.580300304720416*^9}, {
  3.580320555369022*^9, 3.5803205612559233`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"eqPaper", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"D", "[", 
       RowBox[{
        RowBox[{"\[CapitalPi]", "[", 
         RowBox[{"t", ",", "x"}], "]"}], ",", "t"}], "]"}], "\[Equal]", 
      RowBox[{
       FractionBox["1", 
        SuperscriptBox[
         RowBox[{"Tan", "[", "x", "]"}], "2"]], 
       RowBox[{"D", "[", 
        RowBox[{
         RowBox[{
          SuperscriptBox[
           RowBox[{"Tan", "[", "x", "]"}], "2"], 
          RowBox[{"A", "[", 
           RowBox[{"t", ",", "x"}], "]"}], 
          SuperscriptBox["\[ExponentialE]", 
           RowBox[{"-", 
            RowBox[{"\[Delta]", "[", 
             RowBox[{"t", ",", "x"}], "]"}]}]], 
          RowBox[{"\[CapitalPhi]", "[", 
           RowBox[{"t", ",", "x"}], "]"}]}], ",", "x"}], "]"}]}]}], ",", 
     "\[IndentingNewLine]", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"D", "[", 
       RowBox[{
        RowBox[{"\[CapitalPi]", "[", 
         RowBox[{"t", ",", "x"}], "]"}], ",", "t"}], "]"}], "\[Equal]", 
      RowBox[{
       RowBox[{"Exp", "[", 
        RowBox[{"-", 
         RowBox[{"\[Delta]", "[", 
          RowBox[{"t", ",", "x"}], "]"}]}], "]"}], 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{
           SuperscriptBox["\[CapitalPhi]", 
            TagBox[
             RowBox[{"(", 
              RowBox[{"0", ",", "1"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"t", ",", "x"}], "]"}], 
          RowBox[{"A", "[", 
           RowBox[{"t", ",", "x"}], "]"}]}], "+", 
         RowBox[{
          RowBox[{"\[CapitalPhi]", "[", 
           RowBox[{"t", ",", "x"}], "]"}], 
          FractionBox[
           RowBox[{"2", "-", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{"1", "-", 
               RowBox[{"A", "[", 
                RowBox[{"t", ",", "x"}], "]"}]}], ")"}], 
             RowBox[{"Cos", "[", 
              RowBox[{"2", " ", "x"}], "]"}]}]}], 
           RowBox[{
            RowBox[{"Sin", "[", "x", "]"}], 
            RowBox[{"Cos", "[", "x", "]"}]}]]}]}], ")"}]}]}], ",", 
     RowBox[{
      RowBox[{"D", "[", 
       RowBox[{
        RowBox[{"A", "[", 
         RowBox[{"t", ",", "x"}], "]"}], ",", "x"}], "]"}], "\[Equal]", 
      RowBox[{
       RowBox[{
        FractionBox[
         RowBox[{"1", "+", 
          RowBox[{"2", " ", 
           SuperscriptBox[
            RowBox[{"Sin", "[", "x", "]"}], "2"]}]}], 
         RowBox[{
          RowBox[{"Sin", "[", "x", "]"}], 
          RowBox[{"Cos", "[", "x", "]"}]}]], 
        RowBox[{"(", 
         RowBox[{"1", "-", 
          RowBox[{"A", "[", 
           RowBox[{"t", ",", "x"}], "]"}]}], ")"}]}], "-", 
       RowBox[{
        RowBox[{"Sin", "[", "x", "]"}], 
        RowBox[{"Cos", "[", "x", "]"}], 
        RowBox[{"A", "[", 
         RowBox[{"t", ",", "x"}], "]"}], 
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox[
           RowBox[{"\[CapitalPhi]", "[", 
            RowBox[{"t", ",", "x"}], "]"}], "2"], "+", 
          SuperscriptBox[
           RowBox[{"\[CapitalPi]", "[", 
            RowBox[{"t", ",", "x"}], "]"}], "2"]}], ")"}]}]}]}], ",", 
     RowBox[{
      RowBox[{"D", "[", 
       RowBox[{
        RowBox[{"\[Delta]", "[", 
         RowBox[{"t", ",", "x"}], "]"}], ",", "x"}], "]"}], "\[Equal]", 
      RowBox[{
       RowBox[{"-", 
        RowBox[{"Sin", "[", "x", "]"}]}], 
       RowBox[{"Cos", "[", "x", "]"}], 
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox[
          RowBox[{"\[CapitalPhi]", "[", 
           RowBox[{"t", ",", "x"}], "]"}], "2"], "+", 
         SuperscriptBox[
          RowBox[{"\[CapitalPi]", "[", 
           RowBox[{"t", ",", "x"}], "]"}], "2"]}], ")"}]}]}], ",", 
     RowBox[{
      RowBox[{
       SuperscriptBox["A", 
        TagBox[
         RowBox[{"(", 
          RowBox[{"1", ",", "0"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{"t", ",", "x"}], "]"}], "\[Equal]", 
      RowBox[{
       RowBox[{"-", 
        RowBox[{"Sin", "[", 
         RowBox[{"2", " ", "x"}], "]"}]}], 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         RowBox[{"\[Delta]", "[", 
          RowBox[{"t", ",", "x"}], "]"}]}]], " ", 
       SuperscriptBox[
        RowBox[{"A", "[", 
         RowBox[{"t", ",", "x"}], "]"}], "2"], " ", " ", 
       RowBox[{"\[CapitalPi]", "[", 
        RowBox[{"t", ",", "x"}], "]"}], " ", 
       RowBox[{"\[CapitalPhi]", "[", 
        RowBox[{"t", ",", "x"}], "]"}]}]}]}], "}"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.5803002374082336`*^9, 3.580300526170567*^9}, {
   3.580302152660901*^9, 3.580302155223255*^9}, 3.580302257817425*^9, {
   3.5805438766485777`*^9, 3.580543879288529*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"eqPaper", "//.", 
   RowBox[{"Rule", "@@@", 
    RowBox[{"Flatten", "[", 
     RowBox[{"eq", "/@", 
      RowBox[{"Range", "[", "4", "]"}]}], "]"}]}]}], "//", 
  "Simplify"}]], "Input",
 CellChangeTimes->{{3.580300532664521*^9, 3.580300594788394*^9}, 
   3.5803022107978086`*^9, 3.580302253183852*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"True", ",", "True", ",", "True", ",", "True", ",", "True"}], 
  "}"}]], "Output",
 CellChangeTimes->{3.5805440053004427`*^9, 3.583643897498921*^9}]
}, Open  ]],

Cell["Summary", "Text",
 CellChangeTimes->{{3.580300193558773*^9, 3.580300194817505*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"Column", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"First", "@", 
      RowBox[{"eq", "[", "#", "]"}]}], "&"}], "/@", 
    RowBox[{"Range", "[", "4", "]"}]}], "]"}], "//", 
  "TraditionalForm"}]], "Input",
 CellChangeTimes->{{3.580320602299993*^9, 3.580320720290105*^9}, {
  3.580320760702462*^9, 3.580320830572736*^9}, {3.580320949790738*^9, 
  3.58032102878493*^9}, {3.5803212898505783`*^9, 3.580321317065583*^9}, {
  3.580321412633794*^9, 3.580321419081544*^9}, {3.580321454840807*^9, 
  3.580321474245562*^9}, {3.580321581222218*^9, 3.5803215939533567`*^9}}],

Cell[BoxData[
 FormBox[
  TagBox[GridBox[{
     {
      RowBox[{
       RowBox[{
        SuperscriptBox["A", 
         TagBox[
          RowBox[{"(", 
           RowBox[{"0", ",", "1"}], ")"}],
          Derivative],
         MultilineFunction->None], "(", 
        RowBox[{"t", ",", "x"}], ")"}], "\[LongEqual]", 
       RowBox[{
        RowBox[{
         FractionBox["1", "2"], " ", 
         RowBox[{"A", "(", 
          RowBox[{"t", ",", "x"}], ")"}], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", 
            RowBox[{
             RowBox[{"sin", "(", 
              RowBox[{"2", " ", "x"}], ")"}], " ", 
             RowBox[{"(", 
              RowBox[{
               SuperscriptBox[
                RowBox[{"\[CapitalPi]", "(", 
                 RowBox[{"t", ",", "x"}], ")"}], "2"], "+", 
               SuperscriptBox[
                RowBox[{"\[CapitalPhi]", "(", 
                 RowBox[{"t", ",", "x"}], ")"}], "2"]}], ")"}]}]}], "-", 
           RowBox[{"6", " ", 
            RowBox[{"tan", "(", "x", ")"}]}], "-", 
           RowBox[{"2", " ", 
            RowBox[{"cot", "(", "x", ")"}]}]}], ")"}]}], "+", 
        RowBox[{"3", " ", 
         RowBox[{"tan", "(", "x", ")"}]}], "+", 
        RowBox[{"cot", "(", "x", ")"}]}]}]},
     {
      RowBox[{
       RowBox[{
        SuperscriptBox["A", 
         TagBox[
          RowBox[{"(", 
           RowBox[{"1", ",", "0"}], ")"}],
          Derivative],
         MultilineFunction->None], "(", 
        RowBox[{"t", ",", "x"}], ")"}], "\[LongEqual]", 
       RowBox[{
        RowBox[{"-", "2"}], " ", 
        RowBox[{"sin", "(", "x", ")"}], " ", 
        RowBox[{"cos", "(", "x", ")"}], " ", 
        SuperscriptBox[
         RowBox[{"A", "(", 
          RowBox[{"t", ",", "x"}], ")"}], "2"], " ", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"-", 
          RowBox[{"\[Delta]", "(", 
           RowBox[{"t", ",", "x"}], ")"}]}]], " ", 
        RowBox[{"\[CapitalPi]", "(", 
         RowBox[{"t", ",", "x"}], ")"}], " ", 
        RowBox[{"\[CapitalPhi]", "(", 
         RowBox[{"t", ",", "x"}], ")"}]}]}]},
     {
      RowBox[{
       RowBox[{
        SuperscriptBox["\[Delta]", 
         TagBox[
          RowBox[{"(", 
           RowBox[{"0", ",", "1"}], ")"}],
          Derivative],
         MultilineFunction->None], "(", 
        RowBox[{"t", ",", "x"}], ")"}], "\[LongEqual]", 
       RowBox[{
        RowBox[{"sin", "(", "x", ")"}], " ", 
        RowBox[{"(", 
         RowBox[{"-", 
          RowBox[{"cos", "(", "x", ")"}]}], ")"}], " ", 
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox[
           RowBox[{"\[CapitalPi]", "(", 
            RowBox[{"t", ",", "x"}], ")"}], "2"], "+", 
          SuperscriptBox[
           RowBox[{"\[CapitalPhi]", "(", 
            RowBox[{"t", ",", "x"}], ")"}], "2"]}], ")"}]}]}]},
     {
      RowBox[{
       RowBox[{
        SuperscriptBox["\[CapitalPi]", 
         TagBox[
          RowBox[{"(", 
           RowBox[{"1", ",", "0"}], ")"}],
          Derivative],
         MultilineFunction->None], "(", 
        RowBox[{"t", ",", "x"}], ")"}], "\[LongEqual]", 
       RowBox[{
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"-", 
          RowBox[{"\[Delta]", "(", 
           RowBox[{"t", ",", "x"}], ")"}]}]], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"A", "(", 
            RowBox[{"t", ",", "x"}], ")"}], " ", 
           RowBox[{
            SuperscriptBox["\[CapitalPhi]", 
             TagBox[
              RowBox[{"(", 
               RowBox[{"0", ",", "1"}], ")"}],
              Derivative],
             MultilineFunction->None], "(", 
            RowBox[{"t", ",", "x"}], ")"}]}], "+", 
          RowBox[{"2", " ", 
           RowBox[{"csc", "(", 
            RowBox[{"2", " ", "x"}], ")"}], " ", 
           RowBox[{"\[CapitalPhi]", "(", 
            RowBox[{"t", ",", "x"}], ")"}], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              RowBox[{"cos", "(", 
               RowBox[{"2", " ", "x"}], ")"}], " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"A", "(", 
                 RowBox[{"t", ",", "x"}], ")"}], "-", "1"}], ")"}]}], "+", 
             "2"}], ")"}]}]}], ")"}]}]}]}
    },
    DefaultBaseStyle->"Column",
    GridBoxAlignment->{"Columns" -> {{Left}}},
    GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
   "Column"], TraditionalForm]], "Output",
 CellChangeTimes->{3.580544005961796*^9}]
}, Open  ]]
}, Open  ]]
}, Open  ]]
},
WindowSize->{740, 866},
WindowMargins->{{Automatic, 182}, {40, Automatic}},
ShowSelection->True,
FrontEndVersion->"9.0 for Linux x86 (64-bit) (February 7, 2013)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[557, 20, 309, 6, 51, "Text"],
Cell[CellGroupData[{
Cell[891, 30, 170, 2, 44, "Subsection"],
Cell[CellGroupData[{
Cell[1086, 36, 155, 2, 35, "Subsubsection"],
Cell[1244, 40, 536, 11, 49, "Text"],
Cell[1783, 53, 191, 4, 31, "Input"],
Cell[CellGroupData[{
Cell[1999, 61, 121, 2, 31, "Input"],
Cell[2123, 65, 544, 9, 203, "Print"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[2716, 80, 153, 2, 35, "Subsubsection"],
Cell[2872, 84, 16, 0, 30, "Text"],
Cell[2891, 86, 262, 8, 32, "Text"],
Cell[3156, 96, 731, 24, 53, "Input",
 Evaluatable->False],
Cell[3890, 122, 89, 1, 30, "Text"],
Cell[3982, 125, 407, 11, 33, "Input",
 Evaluatable->False],
Cell[CellGroupData[{
Cell[4414, 140, 1354, 39, 144, "Input"],
Cell[5771, 181, 113, 1, 22, "Print"]
}, Open  ]],
Cell[CellGroupData[{
Cell[5921, 187, 132, 2, 31, "Input"],
Cell[6056, 191, 1635, 47, 97, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[7740, 244, 162, 2, 35, "Subsubsection"],
Cell[7905, 248, 318, 7, 32, "Text"],
Cell[8226, 257, 717, 21, 49, "Input",
 Evaluatable->False],
Cell[8946, 280, 2232, 64, 148, "Input"],
Cell[11181, 346, 438, 11, 35, "Input",
 Evaluatable->False],
Cell[11622, 359, 988, 28, 31, "Input"],
Cell[12613, 389, 110, 1, 30, "Text"],
Cell[12726, 392, 824, 26, 80, "Input",
 Evaluatable->False],
Cell[13553, 420, 944, 27, 52, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[14534, 452, 112, 1, 35, "Subsubsection"],
Cell[14649, 455, 93, 1, 30, "Text"],
Cell[14745, 458, 483, 14, 48, "Input"],
Cell[15231, 474, 175, 4, 31, "Text"],
Cell[15409, 480, 438, 11, 35, "Input",
 Evaluatable->False],
Cell[15850, 493, 767, 22, 31, "Input"],
Cell[CellGroupData[{
Cell[16642, 519, 153, 3, 31, "Input"],
Cell[16798, 524, 3043, 95, 124, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[19878, 624, 1060, 27, 34, "Input"],
Cell[20941, 653, 1180, 38, 47, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[22158, 696, 786, 21, 34, "Input"],
Cell[22947, 719, 846, 26, 36, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[23830, 750, 850, 25, 34, "Input"],
Cell[24683, 777, 721, 23, 36, "Output"]
}, Open  ]],
Cell[25419, 803, 95, 1, 30, "Text"],
Cell[25517, 806, 311, 9, 33, "Input",
 Evaluatable->False],
Cell[25831, 817, 700, 20, 31, "Input"],
Cell[CellGroupData[{
Cell[26556, 841, 279, 6, 31, "Input"],
Cell[26838, 849, 8520, 242, 178, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[35395, 1096, 2185, 59, 80, "Input"],
Cell[37583, 1157, 1389, 44, 36, "Output"]
}, Open  ]],
Cell[38987, 1204, 170, 2, 30, "Text"],
Cell[39160, 1208, 4802, 141, 211, "Input"],
Cell[CellGroupData[{
Cell[43987, 1353, 336, 9, 31, "Input"],
Cell[44326, 1364, 187, 4, 31, "Output"]
}, Open  ]],
Cell[44528, 1371, 89, 1, 30, "Text"],
Cell[CellGroupData[{
Cell[44642, 1376, 599, 13, 31, "Input"],
Cell[45244, 1391, 4542, 135, 100, "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}
]
*)

(* End of internal cache information *)
