(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 9.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       157,          7]
NotebookDataLength[    269041,       5273]
NotebookOptionsPosition[    265163,       5148]
NotebookOutlinePosition[    265521,       5164]
CellTagsIndexPosition[    265478,       5161]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{
Cell[TextData[{
 "Reference: Maciej Maliborski and Andrzej Rostworowski, ",
 StyleBox["\[OpenCurlyDoubleQuote]Lecture Notes on Turbulent Instability of \
Anti-de Sitter Spacetime\[CloseCurlyDoubleQuote]",
  FontSlant->"Italic"]
}], "Text",
 CellChangeTimes->{{3.5846803289472437`*^9, 3.5846803851255503`*^9}}],

Cell[CellGroupData[{

Cell["Evolution", "Subsection",
 CellChangeTimes->{{3.580482555331523*^9, 3.580482561578541*^9}, {
  3.580485995296743*^9, 3.5804859968819513`*^9}}],

Cell[CellGroupData[{

Cell["Code", "Subsubsection",
 InitializationGroup->True,
 CellChangeTimes->{{3.5804781423145313`*^9, 3.580478143164708*^9}}],

Cell[TextData[{
 "For clarity the numerical subroutines are separated from this notebook. To \
experiment with numerical evolution code the source file ",
 StyleBox["\[CloseCurlyDoubleQuote]SourceFile.m\[CloseCurlyDoubleQuote]", 
  "Input"],
 " must be loaded first. Please provide the path to this file (by default \
location of this notebook). "
}], "Item",
 CellChangeTimes->{{3.584678798374009*^9, 3.584678989036086*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"SetDirectory", "[", 
   RowBox[{"NotebookDirectory", "[", "]"}], "]"}], ";"}]], "Input",
 CellChangeTimes->{{3.580633206398056*^9, 3.580633221066622*^9}}],

Cell[BoxData[
 RowBox[{"<<", "\"\<SourceFile.m\>\""}]], "Input",
 CellChangeTimes->{{3.580624890735178*^9, 3.5806249197854767`*^9}, 
   3.58063319855685*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Defining initial data", "Subsubsection",
 CellChangeTimes->{{3.580626060193921*^9, 3.580626065365962*^9}}],

Cell[TextData[{
 "For any expermient initial data must be defined first, ie. values of the ",
 Cell[BoxData[
  FormBox[
   RowBox[{"\[CapitalPhi]", "(", 
    RowBox[{
     RowBox[{"t", "=", "0"}], ",", "x"}], ")"}], TraditionalForm]]],
 " and ",
 Cell[BoxData[
  FormBox[
   RowBox[{"\[CapitalPi]", "(", 
    RowBox[{
     RowBox[{"t", "=", "0"}], ",", "x"}], ")"}], TraditionalForm]]],
 " scalar field profiles at the discrete set of points (spatial grid). These \
objects are represented in ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " as a flat lists (vectors",
 StyleBox[" ", "Input"],
 StyleBox[Cell[BoxData[
  FormBox[
   ButtonBox["VectorQ",
    BaseStyle->"Link",
    ButtonData->"paclet:ref/VectorQ"], TextForm]], "Input"], "Input"],
 ")."
}], "Item",
 CellChangeTimes->CompressedData["
1:eJwd0FFIUwEAheFbmFERS2IpYuUgzSWmiVS0LZixZFBBblqQI2vMyhZGWWmJ
re1KNmqNRSsqZs7KijSRQoohEgw03CCaSGEiPgTdmA9hYbW0+9+Hw/d0Hs7R
HG2odCwWBKFADgrulvHmHskofWj8hJMvmjNbZPsO5GWhNcuT7pKNPWzLwFxj
nRrTRqpzUJP7Kx9P+TeX4P7w1YO4z1Jlw4ZNpmN4rrH2LP64I7aia53Bh2dq
JwI4O3MtiO/SLH/QmW1PobZ+asUV2anhjTtx/vqqcgyb3IpbgjWVmBq5bEFR
UNlwQrXtBDZ5j7RjWZ/Tix2R6C0s2b2yC/OadAY3uyTnLpwbqDmJ/QuO05gj
Jc7jBkepC8e6kj7scPy7iZrRyTcY1VkHcc29nzE0+trjKIb+flT6896vqP98
W8KhQLXgkc0wJZbisNWswsGex2vR/z59PSZMq/OxbEFbgK3Pu4vwcGayFF8N
xLdi9qFZPc5EtOVYN35R0eZdUuFR9i2y4MtH5jaM6YsCOHrpwjJRttNcvBx3
qIvFp/2SsTA8fQN7Q9N3cS6qCeH3+8fDmIp3P8PAl71+3Wv5D8+3B5jc7urE
lD34BIciFb9R/dauWL+nsNcgmxgzKP4HvxJYeA==
  "]],

Cell["\<\
Clear any previous definitions of symbols\
\>", "Text",
 CellChangeTimes->{{3.580626125170595*^9, 3.580626132072968*^9}, {
  3.584679387414213*^9, 3.58467940322206*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"Clear", "[", 
   RowBox[{
   "X", ",", "\[CapitalPi]", ",", "\[CapitalPhi]", ",", "\[Epsilon]", ",", 
    "\[Sigma]"}], "]"}], ";"}]], "Input",
 CellChangeTimes->{{3.580626332380067*^9, 3.580626332601348*^9}, 
   3.583327098649705*^9}],

Cell["Define spatial grid", "Text",
 CellChangeTimes->{{3.580479695297282*^9, 3.580479697811748*^9}, {
  3.580482365229279*^9, 3.58048236700921*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"X", "=", 
   RowBox[{"With", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"n", "=", "65"}], "}"}], ",", 
     RowBox[{"N", "@", 
      RowBox[{"Range", "[", 
       RowBox[{"0", ",", 
        FractionBox["\[Pi]", "2"], ",", 
        RowBox[{
         FractionBox["\[Pi]", "2"], "/", 
         RowBox[{"(", 
          RowBox[{"n", "-", "1"}], ")"}]}]}], "]"}]}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"X", "//", "Short"}]}], "Input",
 CellChangeTimes->{{3.580473839161524*^9, 3.580473962048113*^9}, {
   3.5804741455288963`*^9, 3.5804741906250134`*^9}, 3.580474351002509*^9, {
   3.580474602455761*^9, 3.5804746047943*^9}, {3.5804746965631523`*^9, 
   3.580474721047655*^9}, {3.580474756047286*^9, 3.5804747639445*^9}, 
   3.5804749570857677`*^9, {3.5804750108417463`*^9, 3.5804750124867153`*^9}, {
   3.5804750830503607`*^9, 3.5804750835631523`*^9}, {3.580475117223477*^9, 
   3.580475119951385*^9}, {3.580475228766856*^9, 3.5804752310820503`*^9}, {
   3.5804769440725193`*^9, 3.58047696553258*^9}, {3.5804774352383137`*^9, 
   3.580477489567349*^9}, 3.580477590923512*^9, {3.5804776331179743`*^9, 
   3.580477633442761*^9}, {3.580477759752592*^9, 3.580477760947213*^9}, {
   3.580477793245263*^9, 3.58047779881894*^9}, {3.580477851289905*^9, 
   3.580477852960273*^9}, {3.58047960503271*^9, 3.5804796099955177`*^9}, {
   3.5804796609038486`*^9, 3.580479745350217*^9}, {3.580626157171513*^9, 
   3.580626203745491*^9}, {3.583327103239874*^9, 3.583327123118311*^9}}],

Cell[BoxData[
 TagBox[
  RowBox[{"{", 
   RowBox[{
   "0.`", ",", "0.02454369260617026`", ",", "0.04908738521234052`", ",", 
    RowBox[{"\[LeftSkeleton]", "60", "\[RightSkeleton]"}], ",", 
    "1.5462526341887264`", ",", "1.5707963267948966`"}], "}"}],
  Short]], "Output",
 CellChangeTimes->{3.583330651186234*^9}]
}, Open  ]],

Cell[TextData[{
 "Define initial data profiles ",
 " ",
 Cell[BoxData[
  FormBox[
   RowBox[{"\[CapitalPhi]", "(", 
    RowBox[{
     RowBox[{"t", "=", "0"}], ",", "x"}], ")"}], TraditionalForm]]],
 " and ",
 Cell[BoxData[
  FormBox[
   RowBox[{"\[CapitalPi]", "(", 
    RowBox[{
     RowBox[{"t", "=", "0"}], ",", "x"}], ")"}], TraditionalForm]]]
}], "Text",
 CellChangeTimes->{{3.5806262252210712`*^9, 3.580626251422241*^9}, 
   3.5846833946412497`*^9}],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"{", 
     RowBox[{"\[Epsilon]", ",", "\[Sigma]"}], "}"}], "=", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"1", "/", "2"}], ",", 
      RowBox[{"1", "/", "4"}]}], "}"}]}], ";"}], "\[IndentingNewLine]", 
  RowBox[{"(*", 
   RowBox[{"Profiles", " ", 
    RowBox[{"parameters", ":", " ", 
     RowBox[{"amplitude", " ", "and", " ", "width"}]}]}], 
   "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"\[CapitalPi]", "[", "x_", "]"}], ":=", 
   RowBox[{
    RowBox[{"If", "[", 
     RowBox[{
      RowBox[{"x", "<", 
       RowBox[{"\[Pi]", "/", "2"}]}], ",", 
      RowBox[{"\[Epsilon]", 
       FractionBox["2", "\[Pi]"], " ", 
       RowBox[{"Exp", "[", 
        RowBox[{"-", 
         SuperscriptBox[
          RowBox[{"(", 
           FractionBox[
            RowBox[{"Tan", "[", "x", "]"}], 
            RowBox[{
             RowBox[{"\[Pi]", "/", "2"}], " ", "\[Sigma]"}]], ")"}], "2"]}], 
        "]"}]}], ",", "0"}], "]"}], "//", 
    RowBox[{
     RowBox[{"Chop", "[", 
      RowBox[{"#", ",", "$MinMachineNumber"}], "]"}], "&"}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"\[CapitalPhi]", "[", "x_", "]"}], ":=", 
    RowBox[{
     RowBox[{"If", "[", 
      RowBox[{
       RowBox[{"x", "<", 
        RowBox[{"\[Pi]", "/", "2"}]}], ",", 
       RowBox[{"\[Epsilon]", 
        FractionBox["2", "\[Pi]"], " ", "x", " ", 
        RowBox[{"Exp", "[", 
         RowBox[{"-", 
          SuperscriptBox[
           RowBox[{"(", 
            FractionBox[
             RowBox[{"Tan", "[", "x", "]"}], 
             RowBox[{
              RowBox[{"\[Pi]", "/", "2"}], " ", "\[Sigma]"}]], ")"}], "2"]}], 
         "]"}]}], ",", "0"}], "]"}], "//", 
     RowBox[{
      RowBox[{"Chop", "[", 
       RowBox[{"#", ",", "$MinMachineNumber"}], "]"}], "&"}]}]}], ";"}], 
  "\[IndentingNewLine]", 
  RowBox[{"(*", 
   RowBox[{
   "Use", " ", "the", " ", "If", " ", "condition", " ", "to", " ", "avoid", 
    " ", "undreflow"}], "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"SetAttributes", "[", 
     RowBox[{"#", ",", "Listable"}], "]"}], "&"}], "/@", 
   RowBox[{"{", 
    RowBox[{"\[CapitalPi]", ",", "\[CapitalPhi]"}], "}"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"(*", 
   RowBox[{
   "Set", " ", "listable", " ", "attributes", " ", "for", " ", "simpler", " ",
     "usage"}], "*)"}]}]}], "Input",
 CellChangeTimes->{{3.580479756096974*^9, 3.5804798430614862`*^9}, {
  3.580479924186016*^9, 3.580479939583112*^9}, {3.580626339297474*^9, 
  3.580626393261417*^9}, {3.580626431873362*^9, 3.58062653630329*^9}, {
  3.583327141382949*^9, 3.5833271419133987`*^9}, {3.583327344822195*^9, 
  3.5833274283597307`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"\[CapitalPhi]", "[", "X", "]"}]], "Input",
 CellChangeTimes->{{3.580626283377651*^9, 3.580626296917338*^9}, {
  3.583327323591147*^9, 3.583327348413786*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "0", ",", "0.007782029736892975`", ",", "0.015382370202600408`", ",", 
   "0.02262495713520096`", ",", "0.029344806396502398`", ",", 
   "0.03539313189756645`", ",", "0.04064196441115233`", ",", 
   "0.04498811781345047`", ",", "0.04835636132480264`", ",", 
   "0.05070167247425656`", ",", "0.05201046641544587`", ",", 
   "0.052300723475005834`", ",", "0.051620968916687396`", ",", 
   "0.050048097131221006`", ",", "0.04768407673214706`", ",", 
   "0.04465162275276218`", ",", "0.04108897601307417`", ",", 
   "0.03714398561818687`", ",", "0.03296774532977879`", ",", 
   "0.028708084028212243`", ",", "0.0245032494475162`", ",", 
   "0.02047614681931405`", ",", "0.016729493671795923`", ",", 
   "0.013342222880203862`", ",", "0.010367403719561843`", ",", 
   "0.007831853506279633`", ",", "0.005737483095055912`", ",", 
   "0.00406426630564575`", ",", "0.002774560986462713`", ",", 
   "0.0018183586905322782`", ",", "0.0011389258345496792`", ",", 
   "0.0006782469457854078`", ",", "0.0003817097273604793`", ",", 
   "0.00020158917983563928`", ",", "0.00009908231235346968`", ",", 
   "0.00004488349072857707`", ",", "0.00001852367454169327`", ",", 
   "6.8699361723262665`*^-6", ",", "2.2522755696565045`*^-6", ",", 
   "6.399231287116975`*^-7", ",", "1.5382571469523338`*^-7", ",", 
   "3.0377836812692964`*^-8", ",", "4.753027133182165`*^-9", ",", 
   "5.632307494628139`*^-10", ",", "4.7763973018291126`*^-11", ",", 
   "2.6974944935725564`*^-12", ",", "9.248950239513873`*^-14", ",", 
   "1.706716597721608`*^-15", ",", "1.4453574837033703`*^-17", ",", 
   "4.534457490809504`*^-20", ",", "3.9303353123774396`*^-23", ",", 
   "6.2443042164918415`*^-27", ",", "1.0098122054285567`*^-31", ",", 
   "6.98314801903305`*^-38", ",", "5.506814658257762`*^-46", ",", 
   "6.094354813916715`*^-57", ",", "2.909155456725577`*^-72", ",", 
   "1.2933612493500963`*^-94", ",", "4.6511464863516717`*^-129", ",", 
   "3.442993463101459`*^-186", ",", "2.275107799128765`*^-291", ",", "0", ",",
    "0", ",", "0", ",", "0"}], "}"}]], "Output",
 CellChangeTimes->{3.58333065193742*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"GraphicsRow", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"Plot", "[", 
      RowBox[{
       RowBox[{"\[CapitalPhi]", "[", "x", "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"x", ",", "0", ",", 
         RowBox[{"\[Pi]", "/", "2"}]}], "}"}], ",", 
       RowBox[{"AxesLabel", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"\"\<x\>\"", ",", "\"\<\[CapitalPhi](x)\>\""}], "}"}]}], ",", 
       RowBox[{"Epilog", "\[RuleDelayed]", 
        RowBox[{"Point", "/@", 
         RowBox[{"Transpose", "@", 
          RowBox[{"{", 
           RowBox[{"X", ",", 
            RowBox[{"\[CapitalPhi]", "[", "X", "]"}]}], "}"}]}]}]}]}], "]"}], 
     ",", 
     RowBox[{"Plot", "[", 
      RowBox[{
       RowBox[{"\[CapitalPi]", "[", "x", "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"x", ",", "0", ",", 
         RowBox[{"\[Pi]", "/", "2"}]}], "}"}], ",", 
       RowBox[{"AxesLabel", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"\"\<x\>\"", ",", "\"\<\[CapitalPi](x)\>\""}], "}"}]}], ",", 
       
       RowBox[{"Epilog", "\[RuleDelayed]", 
        RowBox[{"Point", "/@", 
         RowBox[{"Transpose", "@", 
          RowBox[{"{", 
           RowBox[{"X", ",", 
            RowBox[{"\[CapitalPi]", "[", "X", "]"}]}], "}"}]}]}]}]}], "]"}]}],
     "}"}], ",", 
   RowBox[{"ImageSize", "\[Rule]", "Large"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.5806265441880913`*^9, 3.580626619994156*^9}, {
  3.580626673902686*^9, 3.580626750660898*^9}}],

Cell[BoxData[
 GraphicsBox[{{}, {InsetBox[
     GraphicsBox[{{}, {}, 
       {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJxFlnc41W/4x60ykj1CZY8oZKfz+dwRCtmVyggJ2Vtmha+VhGRlZTullC0r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         "]]}},
      AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
      Axes->True,
      AxesLabel->{
        FormBox["\"x\"", TraditionalForm], 
        FormBox["\"\[CapitalPhi](x)\"", TraditionalForm]},
      AxesOrigin->{0, 0},
      Epilog->{
        PointBox[{0., 0}], 
        PointBox[{0.02454369260617026, 0.007782029736892975}], 
        PointBox[{0.04908738521234052, 0.015382370202600408`}], 
        PointBox[{0.07363107781851078, 0.02262495713520096}], 
        PointBox[{0.09817477042468103, 0.029344806396502398`}], 
        PointBox[{0.1227184630308513, 0.03539313189756645}], 
        PointBox[{0.14726215563702155`, 0.04064196441115233}], 
        PointBox[{0.1718058482431918, 0.04498811781345047}], 
        PointBox[{0.19634954084936207`, 0.04835636132480264}], 
        PointBox[{0.22089323345553233`, 0.05070167247425656}], 
        PointBox[{0.2454369260617026, 0.05201046641544587}], 
        PointBox[{0.2699806186678728, 0.052300723475005834`}], 
        PointBox[{0.2945243112740431, 0.051620968916687396`}], 
        PointBox[{0.3190680038802134, 0.050048097131221006`}], 
        PointBox[{0.3436116964863836, 0.04768407673214706}], 
        PointBox[{0.36815538909255385`, 0.04465162275276218}], 
        PointBox[{0.39269908169872414`, 0.04108897601307417}], 
        PointBox[{0.4172427743048944, 0.03714398561818687}], 
        PointBox[{0.44178646691106466`, 0.03296774532977879}], 
        PointBox[{0.4663301595172349, 0.028708084028212243`}], 
        PointBox[{0.4908738521234052, 0.0245032494475162}], 
        PointBox[{0.5154175447295755, 0.02047614681931405}], 
        PointBox[{0.5399612373357456, 0.016729493671795923`}], 
        PointBox[{0.5645049299419159, 0.013342222880203862`}], 
        PointBox[{0.5890486225480862, 0.010367403719561843`}], 
        PointBox[{0.6135923151542565, 0.007831853506279633}], 
        PointBox[{0.6381360077604268, 0.005737483095055912}], 
        PointBox[{0.662679700366597, 0.00406426630564575}], 
        PointBox[{0.6872233929727672, 0.002774560986462713}], 
        PointBox[{0.7117670855789375, 0.0018183586905322782`}], 
        PointBox[{0.7363107781851077, 0.0011389258345496792`}], 
        PointBox[{0.760854470791278, 0.0006782469457854078}], 
        PointBox[{0.7853981633974483, 0.0003817097273604793}], 
        PointBox[{0.8099418560036186, 0.00020158917983563928`}], 
        PointBox[{0.8344855486097889, 0.00009908231235346968}], 
        PointBox[{0.859029241215959, 0.00004488349072857707}], 
        PointBox[{0.8835729338221293, 0.00001852367454169327}], 
        PointBox[{0.9081166264282996, 6.8699361723262665`*^-6}], 
        PointBox[{0.9326603190344698, 2.2522755696565045`*^-6}], 
        PointBox[{0.9572040116406401, 6.399231287116975*^-7}], 
        PointBox[{0.9817477042468103, 1.5382571469523338`*^-7}], 
        PointBox[{1.0062913968529805`, 3.0377836812692964`*^-8}], 
        PointBox[{1.030835089459151, 4.753027133182165*^-9}], 
        PointBox[{1.055378782065321, 5.632307494628139*^-10}], 
        PointBox[{1.0799224746714913`, 4.7763973018291126`*^-11}], 
        PointBox[{1.1044661672776617`, 2.6974944935725564`*^-12}], 
        PointBox[{1.1290098598838318`, 9.248950239513873*^-14}], 
        PointBox[{1.1535535524900022`, 1.706716597721608*^-15}], 
        PointBox[{1.1780972450961724`, 1.4453574837033703`*^-17}], 
        PointBox[{1.2026409377023426`, 4.534457490809504*^-20}], 
        PointBox[{1.227184630308513, 3.9303353123774396`*^-23}], 
        PointBox[{1.2517283229146832`, 6.2443042164918415`*^-27}], 
        PointBox[{1.2762720155208536`, 1.0098122054285567`*^-31}], 
        PointBox[{1.3008157081270237`, 6.98314801903305*^-38}], 
        PointBox[{1.325359400733194, 5.506814658257762*^-46}], 
        PointBox[{1.3499030933393643`, 6.094354813916715*^-57}], 
        PointBox[{1.3744467859455345`, 2.909155456725577*^-72}], 
        PointBox[{1.3989904785517047`, 1.2933612493500963`*^-94}], 
        PointBox[{1.423534171157875, 4.6511464863516717`*^-129}], 
        PointBox[{1.4480778637640452`, 3.442993463101459*^-186}], 
        PointBox[{1.4726215563702154`, 2.275107799128765*^-291}], 
        PointBox[{1.4971652489763858`, 0}], 
        PointBox[{1.521708941582556, 0}], 
        PointBox[{1.5462526341887264`, 0}], 
        PointBox[{1.5707963267948966`, 0}]},
      Method->{},
      PlotRange->
       NCache[{{0, Rational[1, 2] Pi}, {0., 0.05232228997897222}}, {{
         0, 1.5707963267948966`}, {0., 0.05232228997897222}}],
      PlotRangeClipping->True,
      PlotRangePadding->{
        Scaled[0.02], 
        Scaled[0.02]}], {192., -116.80842387373012`}, 
     ImageScaled[{0.5, 0.5}], {360., 222.49223594996212`}], InsetBox[
     GraphicsBox[{{}, {}, 
       {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJxF13k0VV+8AHBTUmZFyKzMYxFxz/lGUobMUUimzDMpQ0qZkmQOZcic4keU
KWMUynxNocyzOxlLePet9dbr/HHP+qy9797f/T3fvdc5graeRrepKCgo3pF/
/vdO3Xi0e0bRBr3Z3uEudwsLp5caVPkSAap5rrnKkP2nTNZ+NEEfTDlP2ouR
Xb4Fg6ylZlAVx3edj+y54047HxNuwQ5qf5mF7BiudsbSOjsYaiTJ71thoUDM
Moui1BFKE/tPLJLdpESQM852BXc+pt9dZP/QDGvJT/CE5MLywf/I/iPBIBHc
4g0K5t9KnpEdeWbIJ7/OF4Y0XEMdyT6ukl3XXXkHIm7kGiBkv1ZzodkpuQv1
7pEnmcmW0VK4KlgYAOYq0tPjN7FQZ7CfrJ0dBCkW7/IKyB68lSCakfAA1O9n
8sqQXX5WRnmm7SG4iWhjVyyxcFcpcfxuSyg8u3MhMp9sGrh5+nXdY9DgSpxm
ILtTvaVDsToM6GWVntZaYCFeU9SjszIcqN0/yNmTzadH/LheEgmdObM+b82x
MGtoahFVHAX93qvMWmS/vVZ3wFP4BHROBBdP38CC8s3wK5rZT2FLb3PkCNlG
blw/UhOeQ//3I4JiZlhgUIbGlMtxcCdg7798UywQarxZp9riILJVBuUn+2P9
0Ic7LfHQ/OPKDdprWLjYlr2fWZcISd9q4/OMsCByecBg6XwSmNLgBKnIPtpx
KPdsdRIkH8RUWBhiofe7y+X2ymQ4s3tlnMoACzexCnHEkheweaZeV/AqFi6Y
Ok6rSqWCe9QlopUuFk6NpClEFKdCPfZXWqoOFpbH9ke4C9Mgd69p50CLnL+Z
dkGN7JfAuzK+nalJzg/JsiIlIQvE3g6a8gEWnrGnY5oYs4H9vHoMLYqF/vJw
fkWjbHC7OMm9jMGCxbLlHN9YNkyEimrmqmDBw4Lem7T6Gv7bK5ufUMRCEuIU
lcaSB5xe4fN+klgYHTV2ZbqWByHM6D6bBDn//qD3OC0PaA0kA9+JYaGwlOO4
u1A+1CfUv+47jYVa/rasCwoFsEFD82WWHwu/KIWqFsyKQORdAK/sMfL6MhnT
LV8VwVeaph+PWbHgpPI7uG+yCKyMvx7BMmOB5NOrXuf8BrYmBpocGMj1MRvS
HRtUDL2jz0quHcKCxJexOcWsd7Ca+MfKfGsAVNu0j6r7lkGy7aXntIMDwIIt
6FFKLINax8lgYv8AzE5TJUtXlEEFc+Pzkd4BiKWo4+daL4MnnAbiL78PwLSq
pCLBpxyumt6+Qvo8AFHv6a0zfd4Dr1+Q4FL5AAxlff/wx7sSMAom2xRPB+Bt
qVgQIb4SGkl/cn2iBuBhfdiF+fJKqFDPSpsMHwDxMcy3PmIlSJj32Jc/HIBg
jpLJIu8PcGf8Y4aI/wAIP3tGb+b9EY6JFn60th4Ar0A9mwqvavBYb/nKc2YA
tD0wRXRx1SCS5wDisuT+thL4m/9VQ0D3Eb0zUuR4tGjv0+Gq4ZFTi6KKyAAg
XA2pN11r4LDB/WuC3ANwtFq697BDLRw15GHWoxyA/E0GsLT4BH7xq6GSXf3g
Xn07lkq4Cea4sEs6Fv3k/WwoQKnQBGaHGniUzfqBMIp5f6DRBKSKqiYB437w
2z029NehCQL68uwXtPshEG3h3S5ugkCVa+baKv0Q0cpXsnKmGYIrvUlOnP2Q
3Tv8DaveAuXWtyc4+/sAu6h1pNC2FfJ0Mc4dqn0QLbtF8fFGO5x8rV0aSdML
3pLtyU353yEupFnxN28X/LFzLZ3w6AXK6KCfbkydYFtvahDn0A+OD09E6fJ8
BTsitqkpCgtncpqTAxc/Q4xclWdBxBBwFbYLp+41AVVTlVJY4Ajw88gocER9
AlYJne5fqT8gZiimlomxCq5kqecSEsYB3Y8X0/R6Dyfw3zUfVP2ED7EtUh/5
3kFqfKPNUuNP2BDr/HH44C1wKrwPNm7/CXpvlLs9fpEd8OK96OhPEDVAnwdn
vwVualu+3j8/ITjHp+6F8FvgO7G9KYD+glyZ4uhu6WIQAcH8ltZfQE20SL9i
VATpX2spqZ0nQYgr5nLEWB4QJssC8G6TwHpLsWOrJQ8u/ykgjnlNQtaQ73BA
cR5sSCVOVd6bBHoafEJVQB7oJbg2O0RNwlh0pTErVx5Q3eQJ7SycBApW3QsY
i1xwJd2nSJifBNn1ZvTW2mtoofe7F7I8CQ8FFTh5h18D52kXggtuEvT6UmTX
ml7DFzPTyYtbkzD3joG+Nek1CNTLNG0emoLu4dMcushrwEb+enDj9BRQ+aRb
t8RnA4ZX7UDAfgqQwtqp63GZcMUS62PrNAUN7abxG/aZYPLScT7XbQouvQvf
rzmfCa5csV0id6ZA2Il1qnkmA9LZx15KRUyBydott9bzGbDDeEdZuWgK2vJV
7Z+svYTK/SJv/dUpuHrR/0iFbxo0IZi5OMIUMHV4vXe7mgbfg3uu929MgcQ7
OUs90TSY+bMJ1/am4K/Uvs+TsVRg21ZnsmCahq3uOdz4pVTwwo8XO8hNw915
1f5lwRcgOckye99vGjyvJmdLbCeB3oJAi/+9aWBx/nXn73ASeOHksj2Dp4Hx
hocGnnyOV/41sLQJmwYm6pNxSkFJgOGKx2okkT2FyhtSJoGuEWsbfeU0tGt0
TaYfSwS3VtaCtPVpmPZJn+YwiIfYb4JhCdvToJoiRr2kEA9l/fK2T3en4dyF
rOM/uOJhY9KQ7z71DIRYWLZxzsZB8F58ivWxGaCWarpHGxgHMefYIkXPzkDs
OcFcUbPnUFLE5vTBZwbMa6ZFSVoxEDbYqEZ9dwa6uddunT4RA5ZU7icNg2bA
xDZ46+XsUzhq+bV79fEMnDRtfWj08Ck4MAcrnkqeAUtnvZ5ftdEg4D9HlVg1
A30crBKGmCeQdLE6w+vvDEzv8RUqe0aAq9ftuw0Us0DFDbkBGhGgnsFmyHBo
FhpKzCe2uSKAuOVGU8Q4C4V0cupv28JBr1jQ9RffLNQbxWgt8ocDHetTZT21
WbgTqL8T++sxBP+8OSAZMQu/c6SjxKNDYeMyknE7ehbG+dbTTBxDwa2cxzEr
dhZWNfZiKjVCwSJs7A/bi1mYyzlvzEYRCioSN4T+FM6Cbs6XQxcCHsLvOybe
7R2z4CnVeMlnOQT8GXWYbzPOwavwmLrkU0GA85cYzWSdA0P5LnWHlUBwmDyS
O8I+B80V0jpJ7wPBtKL9nC7fHKS8GzA7rB4Iijc0rc7KzkHRenApejsANvLU
SigN58CDmDH36tNd8MYo62QmzYHYjUUFz3d+QOGR9OB56hwsNzIPa4f6QWwW
oeLhqzlIO5Ng5G7qB8VUb3js8uZg1Y45K5zSD6bbuXCilXNgEX3++K65L5hc
240rH5gD7tW+xQ/cPnDOo2GolW0eSl14BgtTPKE1i5v+I8c8uBgtLa4YeIJR
nz8Ucs/DFWnj7GJ6T/BQkC16IjQPZk2uBcmPPKDwT1aA3pl5cH10G8vq7w6c
kaE8I4bz8CbvRLmgryv8ydKwXYmbhyjmKNX8ZkdAt5EE+eR5oHgyrBUY7gih
ekotd9PmwcqxX7JTyxHo9sSFaHLmob3K7vXwgAOwmzNP81TMQ3po4lLy2m2Q
O/7DRm9wHtSyL3LRKtmDr+tAfNLoPAz4napQpLKHjy3fm39MzMOB6LrMYJcd
IN6Ngo7z8/AWwy5g42AH2t15Uw+25wHZdr6a/soWbkd52pRzLcAEPWPKPo8N
FP1yit/mXQDZ2AsCEzhrWD1n24wILUDqKebjgs3W4DNnItgpsQBNeztvhxys
4aG6ytS06gJ848tv7XK/Bel/aWyOWy2AieN0Cl+/JfR6pVvfzVkAEZo9f3+h
6yARx7LrV7AAPzNuJtRPmcHj/yKSfYoXoFyN42viazM4h/PpdH+/AO2RF78u
CZlBhquOgn3LArAp/r4pJGUKLg5/DxtOL8BfT4FXf8xMoDXcJ0dvfgEWHimP
tfGbAG/+IkZ3eQFSoOAz66Ix9M5gvS+TyPNNGhwTCzQGJZuSMYRqEVzWDH3P
5RkBjaXVfxJCi2AsbqZ/ktkQrIKwWmIii5Az89Ig+qcBVKVrz56WWASZuaMe
bqUG4DJ6jkvwzCLs5T2tidA3gD5T5scn1BfB957e4G9pfcg0bDKlsV0EsaaE
gUA/XTh/WWh/4jW5nfmq0vW0y6CQ2xn1NX8RmJxejpkbXwaZA59j5W8Wwcfa
c4Ge6TIIVX0WCytfhH7hzUXfcE2gF71tLNG8CB2pIiPngi/BBG1Rkf/kIlyL
fX7IKeoijNganLWeXYS5gWdpH3QvQn/DTr3W4iI8u54jnMF6Eb74aw3wEBZB
q6RLSTFDHf6bX95rOViE0OTuGMc6NQj9Im3MzL8EKSk3Kr6xXYBgoaGJHaEl
cOHS4zZuAvAPCXGaFlkCXkne07yWAC7neu5/kFmCpTtXrg6koGBc4FVkgS5B
4FH97SecCJyOqNgrvElun+KvUdVRAYFpi6h4myWQiTRjHN48D9wozbGg20vw
JqXf2ur1eWDaMhHTc18CrY7hn2K7yrB9e8toI3gJtqtzh/1qlKDj0vmiC6+W
YLSgY0f2liLc+xoi8yB7CYp8PecTWRVBTKu1sj5vCXRK2t8ttipAhK5+s0rJ
EgxwHTG3kFEADePbPxQalqA9nB49xXAWmqzjGcQnl6Akq3BPiygHXtNDCY6z
S/C7VrLsTbkc8NvzcBUsLsFlpiq/IR85CHEsPC1MXAKGS2yvefGygPGoR3mp
lsEUXm6EHpeBqqAlL9ZTy8A9j3Hvz5cAhz2ZbX2xZaCVHOG5ikoAxwO/+7FS
y6DEVmcnNCIOfo8OntArLsOfVpupLmZxOPOEPfeQ5jL40/+93RIrCqUpaoO/
HZdB8MvV03Ttp8CKM9JC2W0ZjDP940P8TgFj+vcpf69lKAl1SjohdArcMsxw
6/eWwSbyi3neQ2GQyHM/jHuyDK1fyq71aAtBfnna+em3y+DcsrdXySIALrsW
EiP/LcMNyu8pqXn8IHeJ72R3xTLwHWm2cxPnh08jOX9r6pahzyVflKjEBwMH
bxvjvy3D3+Ub4QRHHqDUa7iktrIMjP6plXhmLvjy4uE5JfwyON4P+Gb5lhNi
ptRFpdeXQb8Y2yB+hRM473yl49oljxegJj0QfgJkX/V+Ixxdgdym5JZNFg64
uTxtmC2xAhT1DDXCdsdASCFfPUVmBb5qGHs0sh2DxfuOZ2POrEDMWG9nyGc2
8GNdPX5PZQXiJ6xSzcXY4Kny5rC+9grIX+mRFD1ggZqIw1YHziuQfLx00PET
I4T0duhtuq9Ap9ns4U0MI2hwx8CK9wokmml/t2lkgN4SFsHhgBWgdVlAWjro
YQHLNVv6ZAXSxRUcd9ePALuwlIvVmxWYNinusUujhbiEp6ZvSlbAqPSl34oU
LRylWlHfKF+BgFPZ/UjLIaCYenMyunYFHE/4H4iRaGA1U7Trw7cVONssf9TZ
gRocmSJrKHpXoK6paSr5MDVM35/P18GuwDj3r2GLYioYscwPmRpfgbbdlfyX
G5TQyi0sx4hbgcPfGlW1X1IARD/iuU5aAa8vdvuZVyig9vcUXe4WOZ6ZdsNG
3AFaNpI9pXywAqIlEWV87/fRVyl8ifYsqzD+iEJV6sZf1I+Ne6vuzCps6aqm
d/DvoPjQgGlapVXIms0alc3dRl2II92GqqsgF/VWpk9sG7XufVG4cHEVHJkP
KHJUtlDdWPYbx66tAjHeuSHm7gb6dc/vktWNVfCuHL4+Rr+Bqrtj5d/cXIXN
Q4zFgjnrqLJu4lFwWAXhAavWO1gSKnyU9ZPL3VXQ/zuKtdMnopkBXkUfglZB
XITf4QWJgHIu9SRRPFwFzhi79fAXBJSpPdY9JWoVnN5oUOO/49E/4Qz8LWmr
ICTtaYOVXUP7KekecX1ahbEWdf74iEUUV5JmZdC0CrkvP9M+plhEj5hLqka2
rkL9IEUs9f0F9MJ7vY2N76tQzr0pE35/Hi21TXbonVgFtb5TBLuXs2gnk+jF
w9OrEPGyfidHbBadq63mR+dXYXqZYpi3egblOTY+8ha3CttJkvbZE9Po089C
OpEHq7C7fSi2T20KLfCsFG2gXoOa14fYF35Noi0nNWk2D68BSafkOe7BJPrH
17nelmUN2p30Bmye/kKdTpXJooJrkKiU8EO+exzVCEeOb6qvgZLOBxzr5jBq
Ld9DkLy8Brc/6AgtOg6jQRPWXbY6a+BMpFcsnhhC3yuGRfQar0Ek3V5XXd8g
KjDfufPWfg2m/HMU838MoJgEy8FppzXorjLTcbYbQM1QXDmX+xrsqT4/9x7X
j8amsLpG3lkDroHrX3IY+tG/mtcnbCPW4OaMb2+tfS/Kub5Ukxa9BlVJk6rW
FL3o2ayglN7YNZg+JuB9C9ODumxn6qMv1uBqzV7npaYudKRwrpmraA1suR/9
DdzpRDeM72YavFuDrxVYE0mDTpSZ4khQZNkalPJO+8S97UA1r0spbFavgWaX
pIusezv6gc63oLdjDdDiFbFuri/ofHDoWkPXGjDMTRTFpLShnMTnCiV9azDk
zIRh4GhDg0fftTwZXQMP5jpbbt5WVKN4/qf60hpwNyiXsGi3oP58m6fl19ZA
qI/uot9YM1qUQO3OT1yDGXOkRdGzGaUPEtjd3SGPJ++dk5fRhPbrmJ/4QIcD
Kq6nJVviDShNk5NVLgMOTnOzJ0t51aPnFO7mx7Pg4JNykKNX7Sc0nSfprAcn
DiyKZp/2mdehNmtd+qJiOLAd7i3/0V6NJtiMp7BL4aCoq8zGSroabR1cnqCW
w0Gb1/CBWXIVKtZw2G1SCQexyRJ0jp4fUUKsWlTaZRy0N9jucmtXokLUBj2R
OjhwTzmZ59NegZrcteLw18dBRsKxH3VaFWj1raA8IzMcYJJ1TsybvEcfyH1o
onfEweHvEn37T8vQsrzPh/+44KB4+zHukkAZOs3Zr7fogYOTy0m3T3j8h2pS
4sdb/XHgG39h/9NwCcrUL/b7fgQOLvd1bQdOF6MXNJUuuEXjwLvN8YeYXDHq
U3sp0jwWB8qC3LqMj96gQzm27EopOGgWGV3hO1OEZvi+kifk4yDE17PvoCkf
7V4ovvfzDQ4KA1PI70f5KIVlTeP3EhxwiMeJPMjMQ+01hq6++YADHuHjDyae
5KJS7Cwutm044K24duFH5Gv02H917/I7cNDTsDLDeOg1+ueKI36xCwesGK/t
+vBstD24wc9zCAceJ5mfBgtlofazbg+CF3Dw0gxvSZfxEtUJ4WxpXMFBgvG5
4JrOdPQMZysNNQEHMUppTqf301AK3ZPRT3ZwQEk4MM68k4pmVHQkpRzBA7PZ
AoVJbjIadvXO8CgjHqr+63Jn301C3RYEuHnZ8JD6fiIgwiwJVTl5LyuXG0/+
fq6yPeBNRIceiRSXSeLhLZr2W+xnHFrP07+6LosHLrZRargeh+Z9vC+rpICH
9o27udrvnqM+y9jKegweBPZOG+7VPEOZjB43dl7FA0Pbi0+xYtHo5ooMFZMR
Hv4EqS8HmzxBx8N/aBia4sF17hZVakQUWlwj3zlshQe/wOe/S/9GoPHGEwwn
7fAgbNetZX4hAr23FqVv5YiHA2TAMv5JOKopOImd9cTDm4+KBHqpMFS67ukJ
MT88WF0IBNrwx+jxa0rmrvfw8K2IOPd7+hE6HRX7i/gQD3Sxt65olISiIQTM
8n48HgY11QqL8CHo7ehFKfUUPOTcehVGs3wf1T2V5BmejodNKeO466vBKPf1
lQ36XDzg86nc6eiCUEpSipJ+IXl+/zmjbYFAdPGpemDCWzy8cKgLpVELQD82
ph1wVuJh56H349Lku2jGjUvqltV4MONxW1zs8EfD1glhWZ/w0DZq/S6Yxh81
Er1yVKQNDzNnxEZ3nvqh+Nit42eH8FA2T9f64Jc3ukrga5H+Qf7/Uf0GJl1v
dNnosqfYT7Jtr4xR1nuhsxypHbzzeDDaVt5RNPNEp+81+XMu48F3/JMcg5EH
+uvHovAxHB5E/pyiaDRxR39kng+h28IDa4GaxU8vV3SEwlaS+g8eHjrJaU4+
cUEHbaNH9vbwQC0TcHfpjTPqlOie9puKAKqPmyu09x1RW7OGddxRAgjbnDXn
WbdHbaKMtFcZCKAgfp1HGOxR65r57CUmAghVvoKWODv05klmvVk2AmilHUsR
1bBFLXVz86aOEyBF8IRZVr4Nan5fafcnBwG4v8xEsTHYoNd/3Soa5SZA9v7R
sPfdt1BTlo39IR7y/ERHg+9VVug1tahrWD4CcFYk2bW8uYka5ZZR9QgRgPe2
dB2m0AK96kh5s1WCAFRH3CbTKa+juqnJFc1SBOgXfzdeK2GGaneIH22UIcCi
ns041twUvSJpVFVzhgDNOPxF4R4TVNNynrFKgQBXdahdiGwm6KVngfaV5whg
u5iyv2ppjKrjc1j/UyGAC13ir1IqI1RNQMnpHYYAk6FLr7isDNELht8a3qAE
CDZ8kf6nwQBFKtZd89QJgNlYiFgR0EeV72p8SdMmx1es+G58TBtVKhrheaFL
gNyjhTiY0kLPjbr5JumR8wONJcL4K+hZ1WSB50YEsHK+6GslfBk94yZ+N8aE
AE0ijhJntTRRuYz6riemBHDKnip47H8JlTmYCwwzJ0Cc12ejwvmLqJRcYF+o
Jbl/XOFjWvGLqKQNk9gDKwLstyg5/PZWR8U+nxsMsCXAuoKlTiuHGiocGSnr
6UKA477Fxwd1EdRnSCHE1o0A0zRZDWcVMWjT6env1zwI5O85lz4dUVXUqhXj
gvEhgNIzlWQX0fNoybHlalk/Aty6/l1jREEZ/Wv74rCwPwE4CsRVu7SV0HRK
Ut6RQAKIFmfLn32uiC4ZZK3/DSLA0Y9aj3jqFVDlbF11wn0CJJkGZ94nnUWH
0MJfQ6EEKFRfSi3xOYOyBVty5z0hQKwBt3tZmCxq8+2I84unBJDX7Vak15FB
y7irqqKfkeP5wNfzjUca1athveYdT4C8jqTQnUkJNIOuMdc+kQDVVOF8b/rF
0VUzN5JZMgHekIScr3SLodFbX56jaQTgKQtR3Z0SQUcv+f2Uf0mAirDiGOff
p1GxZEHp0xkEWEme3g7iOo1+ORvcSf+aAP4yDA+sfIRRKm/5Q6NFBCi+HKFi
9kAANWz6afy9mAAZZipbQkX8aDZzTE7jOwI8GODgf2nFh6Kl81BQRgDKj4H9
nwkn0Wd7ibFp7wlQ+vRjSNI3bnRcV20ippIA8dH3JorKudDAlZeBvtUEuEDb
xkqTeQLtUNHqcKglgKBzFikilwPljN46Yf6JAJYmjc5t79nRj2KGHy40kePd
kvjBvHYMJd2mJTC2E8B4PLar+isLqvahAqXsJMB703pkkpUFjaOxebbxjQCf
VK2fPv7ChMrk1kmM9RDg0O/V35qKDOh9klNAdx8Boi+uXbxIQY9+V+Nobx4g
QLLjrPbb4SOoy6TX7aJhAhDTck/PvzmM1sjyVb4cJQDdvD5+KJcWpXvwjer5
GAHyt3QEPIsOoQW8Itl3fhHANMutaLeHGp02H/uhvkAATWP2a8diKVAGxKzQ
eokAUw5lTKoRB4gi/4BvyAoBOm2yMOlU+0jUTCdDLZ4A1GkKglKyu8j7Ns3R
YSIBRk++NF+Z+I2MF7bkb66Tz49l1VHGVzuIrFstKr9DgBfydOdnLm4h1/XO
0ev/IQDp/n79DalN5JHc+2G3vwRIfPbbtFZwAxnaeONVREEE1UOTe9TyJIRi
+DTyhYoIEeW5apNaRES85vWRWRoinHhr/TLGnYAE30/L4T9ChJe6zZorBWtI
wS12T4SeCBRY5+1X4qtIj1q8qgUjEbh5Xn22alhGhGifYFNYibDR+8tpnnsR
0V2keV15jAgpldN4ial55E7nQ/d+diKcUXO5GvxxDmmPvUfLxE0Eti9PB148
nUFIXhv9kjxEcA7YI/JETyMnjb2ytPjI/Wm/ap5KnkI8TjgphwsRQUYm7zzh
1S8k9fcMTe4pIkw+2VR02J5AWsZu9TWJEIEDPZyd5jCOsGebufyVIIJ58X+J
Hg9GEfTRwDluaSKMxqxuaYiOIE72+tTKskSgOevyRm1yCPkkdvmV71ly/ze8
XKGPsMj80c9O8YpEEHzI63HRZQBhXkMV/1MiQoIRLkbCuh+xLT/XvaxKBEU1
lZ5G314kJvF9Oh1KBD/iysINgR7kwx0ZR5ELRBDqvJNwz6sLoVMRobDVIMLz
O41POIw6kTM8Od8faBIhCjMt8WCqHbHY503LuEKE2jXnzr3HX5HSFvYzo7pE
mKhpSHi+34qM5MXvb+kRAXvoWe489jNCGcn47bghEeSn2zN+1LYgJjqH7A2u
ESFJT7kv5n0TEiIdKudhRoQiBnPrj+GNSBHz3t+nN4iQ6M1L+b2xHtkd2Ej+
epMIPZR+t82CapFTH71s524RoUrhhZ/7n2pEL3VVhtqWCB9KPpWpxlYhOZaz
X1EHIiCvNFtH8JXId9Q6ydKJCMa+1EwVdRXIpsC4daALERxHK/QsUt8jV+YG
fn/wIIKS33Oetw/LkPuSsUH/eRFh8Uby+zDF/5D33lf2inyIsB1+9Z53aAly
cv8TxSt/IkgfcOeTLIoRA427j5LvEUEk6HWx1WIREhYtT/M8kAjBObucSlGF
CI6j4PCjEHJ7llaP7X4eInzT+knQQyJcfufRv9qfi1zP5aa/84gIZjWyjfpV
OUiz7HMmpwgixIYJPwh5l41s3dGKs4ki53N7MOH13SxE4hM1m0U0EVSSkhRZ
yjKQpCv32PViyf2jxOmFnNORjtgzLy7HEUHqfWSo2UIqso9d5VRLIIJ7uL9k
YOALxNHGhkchhQiFezxLV8aSkFeFJzOlU4mQn1XiuVWQiPSuDfKLphPBXzNp
NuFxAqISqC3MnUmEc0xBN/jc4hDPJpr8Y9nk+uhHI4ZWY5E82kYRxhwijI+P
zH7meYYwJp6VoCggr4cUzLDc/gRRH117+7uQXP/rFbT31KMQf/4i6fU35OfT
SXmZqj8CmXzLIz9fQoR2jq7XzjJhCDtp6P2v/8j7u9rkM/fvR4i2crzCaDkR
Aiz+DHoMhiIVrYeUv38gwm324VP3Qh4gi0ebatqqiPCX41DVTPJ9hMcwULWx
hgitsRxm4R1BSMQEDn1fT4SFNEt2wwf3kDrhN01vG4kgpivul73vjxCc7dTz
m4lAcrTz9Ui6g5wq423N/EwEnfZTYUHgh9zYGr6U2kaEEMr1gdR9HyQWk/A1
/isR6oY8Awt7vZGWR7paTzuIkPUqu+xFpRcixdysG9JFhEdqD9u0LN0Rm2tB
3Xd7iLB56nBP92NXJOWlooF3HxGi1VR9ir86I51T+D6XASJcY5cyAhEn5EC0
2Nh+kHz+da8Y02Y6IAoe9oM3h4kQBJEhz6RvI06VfGZmo+R61H666D9gh/Rf
SDTXniBCBm6A0eymDXI48ur4xV9EOBoWo7+GWiOYrsNWyBQRDCZGeDTtrRCv
Yy2/zs2Qzx/OyheTrpZI/o1gG7k5IjzkMdOrSjBHfmSdmxFfIILewzLF9aHr
CNM8wV54iQhfs9GI4XNmyD2f204ca+TztlPNXvCiCRKlg3NUwZP3q5yYSE2v
EfLi1F1HKyIRwu2a59LvGiIFewcOj9aJMLyrWCt4zgD5OBTlULBJBGGxh8bh
7HpI23+sDp3bRCiXKjLgWNRBsFHpt3G/ifDJxN6U/H6GrKu8sz+3TwTekdvy
xogmQnVc0d6cggRhZTtOmS81ELa1ersQKhLkdvs0IScuIoJfNO1yaEjApqmS
p1Kqhshl9dh+oSXBtWEF9warC8iFe9dtl+lIIPxqdU1AD0X0DadsmOhJ4Orx
M0eMHoN4UK9bmzKTYBmboRK+r4TcHw+yDmQlQaRZS5m97Dkk5gONdeYxElib
dh6tClVAXsU+u9XCTgLBu++OyqyfQd46ctyaP0ECiTqekzmh8kjthSyro9wk
uFSzvswsKYd0colZyfCQIE7C4rrUmDSy+O38TX8BEnjkPAym8xBHdvJaLNOF
SHD6mCvDozuiyOEQHcuGUyS49WiGKSDnNMJhhrWYFiHBg8NNghokYURE7qYF
rTgJpJdslxxthRDFI/PmEpIkaLF34E8iCCAa0x7metIkkFcTz1BT5Efskh7e
SJEnwdTfQOyKHzfi437kRu1ZEoR7+3xXv8GJPNJMuP5TkQQmvHysPx04kHj+
k9eplEmwWhOzU51+HMneyTUTUSFB+837pTQkNqSsT8pMG0OCHuAsOOXCijQW
fzD1QMnrl9LTeEvBgvy0/HrtozoJrhoU2PFQ0CNrigbXfmiQ4MtH14r6Djrk
L9Ooyb4mCczkK1jWG2kRhkUbEyEtEmxfmvS2/kWDnGxeNtbUIUH9lHvWwilq
RCLd19jlKgnufZ3bzX1Giaj4/jWK1SdBgYNr/DwHBXL9NJPRkDEJ5vPkf3hT
7WKc9lMM/1wjQbqTAm1p3Q7m7jC/Id91EnS+2nMUztvCRJQVGaibk0ClkPmo
aPUGJuWJvIGDJQn+nqB5ZbxBwuTb1upHW5HjP6r4JOwaEVOpelG/1JoEloYP
v+SU4zEDayZ6W/YkiLqwe9jGfxkz/WXiKrcjCaq93ymuSyxiSFkOV1FnEjwx
xPNGs8xjKAPwurauJCjaymI8LzyLYTG6pxvhTn7+asMq1remMQKSlLrFniQo
Z+wXL2yexMjSROt0e5PztTG+hHv2E4NOsOmQfMnjx2ZM40fGMHofX2pz+JNg
942ECcutUcxjOYlK9kByPrOkm0WuDmKqi6t52UNI8OlixKGP432YtVOXI48/
Is//Y0Hq4koXRihrkHAsggQLgWOeYbQdGMz4q/xjUSQYnEg95Db5BWPGZW9+
LJoE9GziGyMLrZiYRNJntlgSHL/QfJbJuxlT0Ftzjy2OBAzFnQo9I42YZsZQ
abYEsm1oFetZ6jFbkcwvWFPI9URjs5UnW41haRvSYU0lQWCB1tsrjB8xklSZ
FKzpJBid48hy46rEWAdLubBkksBHOozvcmkZptNLC2EuIMEHvJBsynQBZraE
hcRURILPryWN5HryMAfLwwVMxSSguxF9y3A5B6Nw24GFqZRcn0d22+LPZ2Ey
bzyeYfhIAn/hsZZvMsmY6hTtVIZqEiw2XjlgV0zEDAywXmWoJQEpwiQV7xSP
odPL/kjfQALKJhWX/MQYjI96/ZOjX0jQL1RWuSz+GKMpuS1LN0QCX8fj/Htr
XhjcX5dg6i1yfAu+2hGPrmBuXNcR/71NAvc/PEduHVzCtFZIDuF+k2D8OA7D
9ekiJs1lVfbHHgkMJo+wetcCRmPEfabs0Dpouh3+9NNBAfOywkvbin0dPr1W
f+QfJYC54uLPWaOwDoHWjXY+pHXV18OhlR6+6/C3+f6S606i6h8nxDpgdx2a
P918VzqcoMK7F2/hHbgBAg8rPXXT9c/PX37aSUezCfDfhQ79bVulzyLfge/p
JqQPWs/1KKcpuNAV0Age2YJzY4Uxai4ZclXZp5DP8VuQb12cie55iXerYtqM
WLfhxdKd2E8R/Lw7Li+NrWO3wb1vvXv5HQVNu0HWNUaOHaD4v8v2PKawMOmf
nde6NsdT/tnr9S0NtrR/fnDk8VRwxj+/Gu04aVTwz0MBZnF/q/5Zu9YnwHDs
nw09aNojJv75ulAKx6df/+wYXVMhMvvPYeYUuN3Vf27488y2YP+f20r5y8co
fv+/v9uWH7BQ//NYJ/ZV0OF/3kk/OWzA8s8HeiWnI9j+mZYa/OqO//NxV1tW
Ea5/Psm/ccvi5D8LDYSXxvH+s0Tkib02/n+WV32jsyv4z/8D2FeInw==
         "]]}},
      AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
      Axes->True,
      AxesLabel->{
        FormBox["\"x\"", TraditionalForm], 
        FormBox["\"\[CapitalPi](x)\"", TraditionalForm]},
      AxesOrigin->{0, 0},
      Epilog->{
        PointBox[{0., 0.3183098861837907}], 
        PointBox[{0.02454369260617026, 0.3170684159781475}], 
        PointBox[{0.04908738521234052, 0.31336707253930685`}], 
        PointBox[{0.07363107781851078, 0.307274561306409}], 
        PointBox[{0.09817477042468103, 0.29890374349299365`}], 
        PointBox[{0.1227184630308513, 0.28840918492165807`}], 
        PointBox[{0.14726215563702155`, 0.2759837667413242}], 
        PointBox[{0.1718058482431918, 0.26185440294075213`}], 
        PointBox[{0.19634954084936207`, 0.24627692591296296`}], 
        PointBox[{0.22089323345553233`, 0.22953022001220888`}], 
        PointBox[{0.2454369260617026, 0.21190970425685046`}], 
        PointBox[{0.2699806186678728, 0.19372028900839586`}], 
        PointBox[{0.2945243112740431, 0.17526895723272282`}], 
        PointBox[{0.3190680038802134, 0.15685714807684192`}], 
        PointBox[{0.3436116964863836, 0.13877314777041255`}], 
        PointBox[{0.36815538909255385`, 0.1212847185608814}], 
        PointBox[{0.39269908169872414`, 0.10463221822504117`}], 
        PointBox[{0.4172427743048944, 0.08902247781298762}], 
        PointBox[{0.44178646691106466`, 0.07462371031934636}], 
        PointBox[{0.4663301595172349, 0.06156171425397854}], 
        PointBox[{0.4908738521234052, 0.04991760987374024}], 
        PointBox[{0.5154175447295755, 0.03972729882537718}], 
        PointBox[{0.5399612373357456, 0.030982767863748695`}], 
        PointBox[{0.5645049299419159, 0.023635263701907255`}], 
        PointBox[{0.5890486225480862, 0.017600251189307404`}], 
        PointBox[{0.6135923151542565, 0.012763936758742997`}], 
        PointBox[{0.6381360077604268, 0.008991003524768837}], 
        PointBox[{0.662679700366597, 0.006133078021550053}], 
        PointBox[{0.6872233929727672, 0.004037349448278547}], 
        PointBox[{0.7117670855789375, 0.0025547102800535662`}], 
        PointBox[{0.7363107781851077, 0.001546800438473759}], 
        PointBox[{0.760854470791278, 0.0008914279560978862}], 
        PointBox[{0.7853981633974483, 0.00048600791948543977`}], 
        PointBox[{0.8099418560036186, 0.0002488933969042077}], 
        PointBox[{0.8344855486097889, 0.00011873460543269545`}], 
        PointBox[{0.859029241215959, 0.00005224908370411736}], 
        PointBox[{0.8835729338221293, 0.00002096451105803366}], 
        PointBox[{0.9081166264282996, 7.5650373227349816`*^-6}], 
        PointBox[{0.9326603190344698, 2.4148937439390125`*^-6}], 
        PointBox[{0.9572040116406401, 6.685336886698523*^-7}], 
        PointBox[{0.9817477042468103, 1.56685586357696*^-7}], 
        PointBox[{1.0062913968529805`, 3.018791267389835*^-8}], 
        PointBox[{1.030835089459151, 4.610851126222274*^-9}], 
        PointBox[{1.055378782065321, 5.33676400392095*^-10}], 
        PointBox[{1.0799224746714913`, 4.42290758258557*^-11}], 
        PointBox[{1.1044661672776617`, 2.4423514033222615`*^-12}], 
        PointBox[{1.1290098598838318`, 8.192089872860396*^-14}], 
        PointBox[{1.1535535524900022`, 1.4795295754042595`*^-15}], 
        PointBox[{1.1780972450961724`, 1.2268575363533596`*^-17}], 
        PointBox[{1.2026409377023426`, 3.770416712632974*^-20}], 
        PointBox[{1.227184630308513, 3.20272534002431*^-23}], 
        PointBox[{1.2517283229146832`, 4.988545918615799*^-27}], 
        PointBox[{1.2762720155208536`, 7.912202047433023*^-32}], 
        PointBox[{1.3008157081270237`, 5.368283897100012*^-38}], 
        PointBox[{1.325359400733194, 4.154959519064316*^-46}], 
        PointBox[{1.3499030933393643`, 4.5146609738041394`*^-57}], 
        PointBox[{1.3744467859455345`, 2.11660101102005*^-72}], 
        PointBox[{1.3989904785517047`, 9.244961057126278*^-95}], 
        PointBox[{1.423534171157875, 3.26732338470563*^-129}], 
        PointBox[{1.4480778637640452`, 2.377630063449732*^-186}], 
        PointBox[{1.4726215563702154`, 1.5449371831392676`*^-291}], 
        PointBox[{1.4971652489763858`, 0}], 
        PointBox[{1.521708941582556, 0}], 
        PointBox[{1.5462526341887264`, 0}], 
        PointBox[{1.5707963267948966`, 0}]},
      Method->{},
      PlotRange->
       NCache[{{0, Rational[1, 2] Pi}, {0., 0.3183098861837886}}, {{
         0, 1.5707963267948966`}, {0., 0.3183098861837886}}],
      PlotRangeClipping->True,
      PlotRangePadding->{
        Scaled[0.02], 
        Scaled[0.02]}], {576., -116.80842387373012`}, 
     ImageScaled[{0.5, 0.5}], {360., 222.49223594996212`}]}, {}},
  ContentSelectable->True,
  ImageSize->Large,
  PlotRangePadding->{6, 5}]], "Output",
 CellChangeTimes->{3.583330652193006*^9}]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"Clear", "[", 
   RowBox[{
   "X", ",", "\[CapitalPi]", ",", "\[CapitalPhi]", ",", "\[Epsilon]", ",", 
    "\[Sigma]"}], "]"}], ";"}]], "Input",
 CellChangeTimes->{{3.580626758347375*^9, 3.580626771814959*^9}, 
   3.583327096272304*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Simple run", "Subsubsection",
 CellChangeTimes->{{3.580479535089082*^9, 3.580479537211094*^9}}],

Cell[TextData[{
 "There are three main functions defined in  '",
 StyleBox["SourceFile.m", "Input"],
 "'  which form a complete solver for the problem at hand. They are: ",
 StyleBox["Constraints", "Input"],
 " function which determines values of the metric functions ",
 Cell[BoxData[
  FormBox[
   RowBox[{"A", "(", 
    RowBox[{"t", ",", "x"}], ")"}], TraditionalForm]]],
 ", ",
 Cell[BoxData[
  FormBox[
   RowBox[{"\[Delta]", "(", 
    RowBox[{"t", ",", "x"}], ")"}], TraditionalForm]]],
 " at grid points for a given fields ",
 Cell[BoxData[
  FormBox[
   RowBox[{"\[CapitalPhi]", "(", 
    RowBox[{"t", ",", "x"}], ")"}], TraditionalForm]]],
 ", ",
 Cell[BoxData[
  FormBox[
   RowBox[{"\[CapitalPi]", "(", 
    RowBox[{"t", ",", "x"}], ")"}], TraditionalForm]]],
 " represented as vectors, ",
 StyleBox["Velocities", "Input"],
 " function which computes right hand side of the dynamical equations for a \
given fields ",
 Cell[BoxData[
  FormBox[
   RowBox[{"\[CapitalPhi]", "(", 
    RowBox[{"t", ",", "x"}], ")"}], TraditionalForm]]],
 ", ",
 Cell[BoxData[
  FormBox[
   RowBox[{"\[CapitalPi]", "(", 
    RowBox[{"t", ",", "x"}], ")"}], TraditionalForm]]],
 " represented as vectors and major function, called ",
 StyleBox["Solver", "Input"],
 ", which performs time evolution of initial data using method of lines (it \
accepts all the options of the built-in function ",
 StyleBox["NDSolve", "Input"],
 ").  Please note, that the checking for horizon formation is not implemed in \
this solver, but it can be easily done using the ",
 StyleBox["EventLocator", "Input"],
 StyleBox[" method of ", "Text"],
 StyleBox["NDSolve", "Input"],
 StyleBox[". \[LineSeparator]", "Text"],
 "This example shows how to perform evolution, and how to visualize \
solution."
}], "Item",
 CellChangeTimes->CompressedData["
1:eJwdz11IUwEAhuFTmGERS2QqY5WD1FaYJpKQW3CMFbsR8iwLcmTG/GthlJWW
2NrOyEYtmWVRMGsmVmSJGBKIRLDQdINoIYWIeBFxQgOxkFraeXfx8Vx9F6+h
urHcsVYQhFx1KLhbp1r6FVH52PQFZ160ZLSqDhzNzkRbpifZpRp55E3FLLFG
i0njFXo0ZP3OwTMduwvwcOj6MSyTjtixcaelFi80VZ3HxXtyG7q2mv14rmo6
gEsLN7rwXZL0B526U3E0NsxuvKY6O5a7H1dubi7FkMWdcE9XZTnGx69KKAsa
O05riuux2XeyHYsGnD7sHgl3YsHBTT2Y3VxidtOlOA/g8nDlaRxcdZxFvRK7
iNsdhS783DPvx27Hv9tomJx5g+ES2yimP/gVQdHfHkU5+PdT4r/i+4amr3cV
fBuoEDyqqZbYehyzWTU42t+7BTs+JG/DmCUtB4tWjTuw7XlfHp7ImC/EoeHo
XtQdXzLhwoixFGumLie0+9Yd8iT61kj46onVixFTXgAnr1xKkVUfW/M34D5t
vvx0UBF3heZu4cvg3H1cDhuC+ONhXQjj0b5n6O3tTDO9VkSprEGLtp/FOlxM
SdfjHc/7IbPq90j1BP4H92NMiw==
  "]],

Cell["Define spatial grid", "Text",
 CellChangeTimes->{{3.580479695297282*^9, 3.580479697811748*^9}, {
  3.580482365229279*^9, 3.58048236700921*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"X", "=", 
   RowBox[{"With", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"n", "=", "65"}], "}"}], ",", 
     RowBox[{"N", "@", 
      RowBox[{"Range", "[", 
       RowBox[{"0", ",", 
        FractionBox["\[Pi]", "2"], ",", 
        RowBox[{
         FractionBox["\[Pi]", "2"], "/", 
         RowBox[{"(", 
          RowBox[{"n", "-", "1"}], ")"}]}]}], "]"}]}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"X", "//", "Short"}]}], "Input",
 CellChangeTimes->{{3.580473839161524*^9, 3.580473962048113*^9}, {
   3.5804741455288963`*^9, 3.5804741906250134`*^9}, 3.580474351002509*^9, {
   3.580474602455761*^9, 3.5804746047943*^9}, {3.5804746965631523`*^9, 
   3.580474721047655*^9}, {3.580474756047286*^9, 3.5804747639445*^9}, 
   3.5804749570857677`*^9, {3.5804750108417463`*^9, 3.5804750124867153`*^9}, {
   3.5804750830503607`*^9, 3.5804750835631523`*^9}, {3.580475117223477*^9, 
   3.580475119951385*^9}, {3.580475228766856*^9, 3.5804752310820503`*^9}, {
   3.5804769440725193`*^9, 3.58047696553258*^9}, {3.5804774352383137`*^9, 
   3.580477489567349*^9}, 3.580477590923512*^9, {3.5804776331179743`*^9, 
   3.580477633442761*^9}, {3.580477759752592*^9, 3.580477760947213*^9}, {
   3.580477793245263*^9, 3.58047779881894*^9}, {3.580477851289905*^9, 
   3.580477852960273*^9}, {3.58047960503271*^9, 3.5804796099955177`*^9}, {
   3.5804796609038486`*^9, 3.580479745350217*^9}, 3.580626958816483*^9, {
   3.58063280487262*^9, 3.58063282213236*^9}, {3.583327182536057*^9, 
   3.5833271862427797`*^9}}],

Cell[BoxData[
 TagBox[
  RowBox[{"{", 
   RowBox[{
   "0.`", ",", "0.02454369260617026`", ",", "0.04908738521234052`", ",", 
    RowBox[{"\[LeftSkeleton]", "60", "\[RightSkeleton]"}], ",", 
    "1.5462526341887264`", ",", "1.5707963267948966`"}], "}"}],
  Short]], "Output",
 CellChangeTimes->{3.583330652674315*^9}]
}, Open  ]],

Cell["Define initial data", "Text",
 CellChangeTimes->{{3.580479750425507*^9, 3.580479752686597*^9}, {
  3.580482359999281*^9, 3.58048236277625*^9}, {3.580632806165841*^9, 
  3.580632806974493*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"{", 
    RowBox[{"\[Epsilon]", ",", "\[Sigma]"}], "}"}], "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"1", "/", "2"}], ",", 
     RowBox[{"1", "/", "4"}]}], "}"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"\[CapitalPi]", "[", "x_", "]"}], ":=", 
   RowBox[{
    RowBox[{"If", "[", 
     RowBox[{
      RowBox[{"x", "\[Equal]", 
       RowBox[{"\[Pi]", "/", "2"}]}], ",", "0", ",", 
      RowBox[{
       RowBox[{"2", "/", "\[Pi]"}], " ", "\[Epsilon]", " ", 
       RowBox[{"Exp", "[", 
        RowBox[{"-", 
         SuperscriptBox[
          RowBox[{"(", 
           FractionBox[
            RowBox[{"Tan", "[", "x", "]"}], 
            RowBox[{
             RowBox[{"\[Pi]", "/", "2"}], " ", "\[Sigma]"}]], ")"}], "2"]}], 
        "]"}]}]}], "]"}], "//", 
    RowBox[{
     RowBox[{"Chop", "[", 
      RowBox[{"#", ",", "$MinMachineNumber"}], "]"}], "&"}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"\[CapitalPhi]", "[", "x_", "]"}], ":=", 
   RowBox[{
    RowBox[{"If", "[", 
     RowBox[{
      RowBox[{"x", "\[Equal]", 
       RowBox[{"\[Pi]", "/", "2"}]}], ",", "0", ",", 
      RowBox[{
       RowBox[{"2", "/", "\[Pi]"}], " ", "\[Epsilon]", " ", "x", " ", 
       RowBox[{"Exp", "[", 
        RowBox[{"-", 
         SuperscriptBox[
          RowBox[{"(", 
           FractionBox[
            RowBox[{"Tan", "[", "x", "]"}], 
            RowBox[{
             RowBox[{"\[Pi]", "/", "2"}], " ", "\[Sigma]"}]], ")"}], "2"]}], 
        "]"}]}]}], "]"}], "//", 
    RowBox[{
     RowBox[{"Chop", "[", 
      RowBox[{"#", ",", "$MinMachineNumber"}], "]"}], "&"}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"SetAttributes", "[", 
     RowBox[{"#", ",", "Listable"}], "]"}], "&"}], "/@", 
   RowBox[{"{", 
    RowBox[{"\[CapitalPi]", ",", "\[CapitalPhi]"}], "}"}]}], ";"}]}], "Input",\

 CellChangeTimes->{{3.580479756096974*^9, 3.5804798430614862`*^9}, {
  3.580479924186016*^9, 3.580479939583112*^9}, {3.583327446303732*^9, 
  3.583327447457271*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Plot", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"\[CapitalPhi]", "[", "x", "]"}], ",", 
     RowBox[{"\[CapitalPi]", "[", "x", "]"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"x", ",", "0", ",", 
     RowBox[{"\[Pi]", "/", "2"}]}], "}"}], ",", "\[IndentingNewLine]", 
   RowBox[{"AxesLabel", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"x", ",", "None"}], "}"}]}], ",", 
   RowBox[{"PlotLabel", "\[Rule]", "\"\<Initial data profiles\>\""}], ",", 
   RowBox[{"PlotRange", "\[Rule]", "All"}], ",", 
   RowBox[{"PlotLegends", "\[Rule]", 
    RowBox[{"LineLegend", "[", 
     RowBox[{"{", 
      RowBox[{
      "\"\<\[CapitalPhi](0,x)\>\"", ",", "\"\<\[CapitalPi](0,x)\>\""}], "}"}],
      "]"}]}]}], "\[IndentingNewLine]", "]"}]], "Input",
 CellChangeTimes->{{3.580479845036976*^9, 3.5804799117485447`*^9}, {
  3.5804799511122093`*^9, 3.580479969381691*^9}, {3.5804801592634783`*^9, 
  3.5804801648997087`*^9}, {3.580480195848237*^9, 3.5804802570793133`*^9}, {
  3.580482384199154*^9, 3.580482385901071*^9}, {3.580484732350885*^9, 
  3.5804847405887413`*^9}}],

Cell[BoxData[
 TemplateBox[{GraphicsBox[{{}, {}, {
      Hue[0.67, 0.6, 0.6], 
      LineBox[CompressedData["
1:eJxFlnc41W/4x60ykj1CZY8oZKfz+dwRCtmVyggJ2Vtmha+VhGRlZTullC0r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       "]]}, {
      Hue[0.9060679774997897, 0.6, 0.6], 
      LineBox[CompressedData["
1:eJxF13k0VV+8AHBTUmZFyKzMYxFxz/lGUobMUUimzDMpQ0qZkmQOZcic4keU
KWMUynxNocyzOxlLePet9dbr/HHP+qy9797f/T3fvdc5graeRrepKCgo3pF/
/vdO3Xi0e0bRBr3Z3uEudwsLp5caVPkSAap5rrnKkP2nTNZ+NEEfTDlP2ouR
Xb4Fg6ylZlAVx3edj+y54047HxNuwQ5qf5mF7BiudsbSOjsYaiTJ71thoUDM
Moui1BFKE/tPLJLdpESQM852BXc+pt9dZP/QDGvJT/CE5MLywf/I/iPBIBHc
4g0K5t9KnpEdeWbIJ7/OF4Y0XEMdyT6ukl3XXXkHIm7kGiBkv1ZzodkpuQv1
7pEnmcmW0VK4KlgYAOYq0tPjN7FQZ7CfrJ0dBCkW7/IKyB68lSCakfAA1O9n
8sqQXX5WRnmm7SG4iWhjVyyxcFcpcfxuSyg8u3MhMp9sGrh5+nXdY9DgSpxm
ILtTvaVDsToM6GWVntZaYCFeU9SjszIcqN0/yNmTzadH/LheEgmdObM+b82x
MGtoahFVHAX93qvMWmS/vVZ3wFP4BHROBBdP38CC8s3wK5rZT2FLb3PkCNlG
blw/UhOeQ//3I4JiZlhgUIbGlMtxcCdg7798UywQarxZp9riILJVBuUn+2P9
0Ic7LfHQ/OPKDdprWLjYlr2fWZcISd9q4/OMsCByecBg6XwSmNLgBKnIPtpx
KPdsdRIkH8RUWBhiofe7y+X2ymQ4s3tlnMoACzexCnHEkheweaZeV/AqFi6Y
Ok6rSqWCe9QlopUuFk6NpClEFKdCPfZXWqoOFpbH9ke4C9Mgd69p50CLnL+Z
dkGN7JfAuzK+nalJzg/JsiIlIQvE3g6a8gEWnrGnY5oYs4H9vHoMLYqF/vJw
fkWjbHC7OMm9jMGCxbLlHN9YNkyEimrmqmDBw4Lem7T6Gv7bK5ufUMRCEuIU
lcaSB5xe4fN+klgYHTV2ZbqWByHM6D6bBDn//qD3OC0PaA0kA9+JYaGwlOO4
u1A+1CfUv+47jYVa/rasCwoFsEFD82WWHwu/KIWqFsyKQORdAK/sMfL6MhnT
LV8VwVeaph+PWbHgpPI7uG+yCKyMvx7BMmOB5NOrXuf8BrYmBpocGMj1MRvS
HRtUDL2jz0quHcKCxJexOcWsd7Ca+MfKfGsAVNu0j6r7lkGy7aXntIMDwIIt
6FFKLINax8lgYv8AzE5TJUtXlEEFc+Pzkd4BiKWo4+daL4MnnAbiL78PwLSq
pCLBpxyumt6+Qvo8AFHv6a0zfd4Dr1+Q4FL5AAxlff/wx7sSMAom2xRPB+Bt
qVgQIb4SGkl/cn2iBuBhfdiF+fJKqFDPSpsMHwDxMcy3PmIlSJj32Jc/HIBg
jpLJIu8PcGf8Y4aI/wAIP3tGb+b9EY6JFn60th4Ar0A9mwqvavBYb/nKc2YA
tD0wRXRx1SCS5wDisuT+thL4m/9VQ0D3Eb0zUuR4tGjv0+Gq4ZFTi6KKyAAg
XA2pN11r4LDB/WuC3ANwtFq697BDLRw15GHWoxyA/E0GsLT4BH7xq6GSXf3g
Xn07lkq4Cea4sEs6Fv3k/WwoQKnQBGaHGniUzfqBMIp5f6DRBKSKqiYB437w
2z029NehCQL68uwXtPshEG3h3S5ugkCVa+baKv0Q0cpXsnKmGYIrvUlOnP2Q
3Tv8DaveAuXWtyc4+/sAu6h1pNC2FfJ0Mc4dqn0QLbtF8fFGO5x8rV0aSdML
3pLtyU353yEupFnxN28X/LFzLZ3w6AXK6KCfbkydYFtvahDn0A+OD09E6fJ8
BTsitqkpCgtncpqTAxc/Q4xclWdBxBBwFbYLp+41AVVTlVJY4Ajw88gocER9
AlYJne5fqT8gZiimlomxCq5kqecSEsYB3Y8X0/R6Dyfw3zUfVP2ED7EtUh/5
3kFqfKPNUuNP2BDr/HH44C1wKrwPNm7/CXpvlLs9fpEd8OK96OhPEDVAnwdn
vwVualu+3j8/ITjHp+6F8FvgO7G9KYD+glyZ4uhu6WIQAcH8ltZfQE20SL9i
VATpX2spqZ0nQYgr5nLEWB4QJssC8G6TwHpLsWOrJQ8u/ykgjnlNQtaQ73BA
cR5sSCVOVd6bBHoafEJVQB7oJbg2O0RNwlh0pTErVx5Q3eQJ7SycBApW3QsY
i1xwJd2nSJifBNn1ZvTW2mtoofe7F7I8CQ8FFTh5h18D52kXggtuEvT6UmTX
ml7DFzPTyYtbkzD3joG+Nek1CNTLNG0emoLu4dMcushrwEb+enDj9BRQ+aRb
t8RnA4ZX7UDAfgqQwtqp63GZcMUS62PrNAUN7abxG/aZYPLScT7XbQouvQvf
rzmfCa5csV0id6ZA2Il1qnkmA9LZx15KRUyBydott9bzGbDDeEdZuWgK2vJV
7Z+svYTK/SJv/dUpuHrR/0iFbxo0IZi5OMIUMHV4vXe7mgbfg3uu929MgcQ7
OUs90TSY+bMJ1/am4K/Uvs+TsVRg21ZnsmCahq3uOdz4pVTwwo8XO8hNw915
1f5lwRcgOckye99vGjyvJmdLbCeB3oJAi/+9aWBx/nXn73ASeOHksj2Dp4Hx
hocGnnyOV/41sLQJmwYm6pNxSkFJgOGKx2okkT2FyhtSJoGuEWsbfeU0tGt0
TaYfSwS3VtaCtPVpmPZJn+YwiIfYb4JhCdvToJoiRr2kEA9l/fK2T3en4dyF
rOM/uOJhY9KQ7z71DIRYWLZxzsZB8F58ivWxGaCWarpHGxgHMefYIkXPzkDs
OcFcUbPnUFLE5vTBZwbMa6ZFSVoxEDbYqEZ9dwa6uddunT4RA5ZU7icNg2bA
xDZ46+XsUzhq+bV79fEMnDRtfWj08Ck4MAcrnkqeAUtnvZ5ftdEg4D9HlVg1
A30crBKGmCeQdLE6w+vvDEzv8RUqe0aAq9ftuw0Us0DFDbkBGhGgnsFmyHBo
FhpKzCe2uSKAuOVGU8Q4C4V0cupv28JBr1jQ9RffLNQbxWgt8ocDHetTZT21
WbgTqL8T++sxBP+8OSAZMQu/c6SjxKNDYeMyknE7ehbG+dbTTBxDwa2cxzEr
dhZWNfZiKjVCwSJs7A/bi1mYyzlvzEYRCioSN4T+FM6Cbs6XQxcCHsLvOybe
7R2z4CnVeMlnOQT8GXWYbzPOwavwmLrkU0GA85cYzWSdA0P5LnWHlUBwmDyS
O8I+B80V0jpJ7wPBtKL9nC7fHKS8GzA7rB4Iijc0rc7KzkHRenApejsANvLU
SigN58CDmDH36tNd8MYo62QmzYHYjUUFz3d+QOGR9OB56hwsNzIPa4f6QWwW
oeLhqzlIO5Ng5G7qB8VUb3js8uZg1Y45K5zSD6bbuXCilXNgEX3++K65L5hc
240rH5gD7tW+xQ/cPnDOo2GolW0eSl14BgtTPKE1i5v+I8c8uBgtLa4YeIJR
nz8Ucs/DFWnj7GJ6T/BQkC16IjQPZk2uBcmPPKDwT1aA3pl5cH10G8vq7w6c
kaE8I4bz8CbvRLmgryv8ydKwXYmbhyjmKNX8ZkdAt5EE+eR5oHgyrBUY7gih
ekotd9PmwcqxX7JTyxHo9sSFaHLmob3K7vXwgAOwmzNP81TMQ3po4lLy2m2Q
O/7DRm9wHtSyL3LRKtmDr+tAfNLoPAz4napQpLKHjy3fm39MzMOB6LrMYJcd
IN6Ngo7z8/AWwy5g42AH2t15Uw+25wHZdr6a/soWbkd52pRzLcAEPWPKPo8N
FP1yit/mXQDZ2AsCEzhrWD1n24wILUDqKebjgs3W4DNnItgpsQBNeztvhxys
4aG6ytS06gJ848tv7XK/Bel/aWyOWy2AieN0Cl+/JfR6pVvfzVkAEZo9f3+h
6yARx7LrV7AAPzNuJtRPmcHj/yKSfYoXoFyN42viazM4h/PpdH+/AO2RF78u
CZlBhquOgn3LArAp/r4pJGUKLg5/DxtOL8BfT4FXf8xMoDXcJ0dvfgEWHimP
tfGbAG/+IkZ3eQFSoOAz66Ix9M5gvS+TyPNNGhwTCzQGJZuSMYRqEVzWDH3P
5RkBjaXVfxJCi2AsbqZ/ktkQrIKwWmIii5Az89Ig+qcBVKVrz56WWASZuaMe
bqUG4DJ6jkvwzCLs5T2tidA3gD5T5scn1BfB957e4G9pfcg0bDKlsV0EsaaE
gUA/XTh/WWh/4jW5nfmq0vW0y6CQ2xn1NX8RmJxejpkbXwaZA59j5W8Wwcfa
c4Ge6TIIVX0WCytfhH7hzUXfcE2gF71tLNG8CB2pIiPngi/BBG1Rkf/kIlyL
fX7IKeoijNganLWeXYS5gWdpH3QvQn/DTr3W4iI8u54jnMF6Eb74aw3wEBZB
q6RLSTFDHf6bX95rOViE0OTuGMc6NQj9Im3MzL8EKSk3Kr6xXYBgoaGJHaEl
cOHS4zZuAvAPCXGaFlkCXkne07yWAC7neu5/kFmCpTtXrg6koGBc4FVkgS5B
4FH97SecCJyOqNgrvElun+KvUdVRAYFpi6h4myWQiTRjHN48D9wozbGg20vw
JqXf2ur1eWDaMhHTc18CrY7hn2K7yrB9e8toI3gJtqtzh/1qlKDj0vmiC6+W
YLSgY0f2liLc+xoi8yB7CYp8PecTWRVBTKu1sj5vCXRK2t8ttipAhK5+s0rJ
EgxwHTG3kFEADePbPxQalqA9nB49xXAWmqzjGcQnl6Akq3BPiygHXtNDCY6z
S/C7VrLsTbkc8NvzcBUsLsFlpiq/IR85CHEsPC1MXAKGS2yvefGygPGoR3mp
lsEUXm6EHpeBqqAlL9ZTy8A9j3Hvz5cAhz2ZbX2xZaCVHOG5ikoAxwO/+7FS
y6DEVmcnNCIOfo8OntArLsOfVpupLmZxOPOEPfeQ5jL40/+93RIrCqUpaoO/
HZdB8MvV03Ttp8CKM9JC2W0ZjDP940P8TgFj+vcpf69lKAl1SjohdArcMsxw
6/eWwSbyi3neQ2GQyHM/jHuyDK1fyq71aAtBfnna+em3y+DcsrdXySIALrsW
EiP/LcMNyu8pqXn8IHeJ72R3xTLwHWm2cxPnh08jOX9r6pahzyVflKjEBwMH
bxvjvy3D3+Ub4QRHHqDUa7iktrIMjP6plXhmLvjy4uE5JfwyON4P+Gb5lhNi
ptRFpdeXQb8Y2yB+hRM473yl49oljxegJj0QfgJkX/V+Ixxdgdym5JZNFg64
uTxtmC2xAhT1DDXCdsdASCFfPUVmBb5qGHs0sh2DxfuOZ2POrEDMWG9nyGc2
8GNdPX5PZQXiJ6xSzcXY4Kny5rC+9grIX+mRFD1ggZqIw1YHziuQfLx00PET
I4T0duhtuq9Ap9ns4U0MI2hwx8CK9wokmml/t2lkgN4SFsHhgBWgdVlAWjro
YQHLNVv6ZAXSxRUcd9ePALuwlIvVmxWYNinusUujhbiEp6ZvSlbAqPSl34oU
LRylWlHfKF+BgFPZ/UjLIaCYenMyunYFHE/4H4iRaGA1U7Trw7cVONssf9TZ
gRocmSJrKHpXoK6paSr5MDVM35/P18GuwDj3r2GLYioYscwPmRpfgbbdlfyX
G5TQyi0sx4hbgcPfGlW1X1IARD/iuU5aAa8vdvuZVyig9vcUXe4WOZ6ZdsNG
3AFaNpI9pXywAqIlEWV87/fRVyl8ifYsqzD+iEJV6sZf1I+Ne6vuzCps6aqm
d/DvoPjQgGlapVXIms0alc3dRl2II92GqqsgF/VWpk9sG7XufVG4cHEVHJkP
KHJUtlDdWPYbx66tAjHeuSHm7gb6dc/vktWNVfCuHL4+Rr+Bqrtj5d/cXIXN
Q4zFgjnrqLJu4lFwWAXhAavWO1gSKnyU9ZPL3VXQ/zuKtdMnopkBXkUfglZB
XITf4QWJgHIu9SRRPFwFzhi79fAXBJSpPdY9JWoVnN5oUOO/49E/4Qz8LWmr
ICTtaYOVXUP7KekecX1ahbEWdf74iEUUV5JmZdC0CrkvP9M+plhEj5hLqka2
rkL9IEUs9f0F9MJ7vY2N76tQzr0pE35/Hi21TXbonVgFtb5TBLuXs2gnk+jF
w9OrEPGyfidHbBadq63mR+dXYXqZYpi3egblOTY+8ha3CttJkvbZE9Po089C
OpEHq7C7fSi2T20KLfCsFG2gXoOa14fYF35Noi0nNWk2D68BSafkOe7BJPrH
17nelmUN2p30Bmye/kKdTpXJooJrkKiU8EO+exzVCEeOb6qvgZLOBxzr5jBq
Ld9DkLy8Brc/6AgtOg6jQRPWXbY6a+BMpFcsnhhC3yuGRfQar0Ek3V5XXd8g
KjDfufPWfg2m/HMU838MoJgEy8FppzXorjLTcbYbQM1QXDmX+xrsqT4/9x7X
j8amsLpG3lkDroHrX3IY+tG/mtcnbCPW4OaMb2+tfS/Kub5Ukxa9BlVJk6rW
FL3o2ayglN7YNZg+JuB9C9ODumxn6qMv1uBqzV7npaYudKRwrpmraA1suR/9
DdzpRDeM72YavFuDrxVYE0mDTpSZ4khQZNkalPJO+8S97UA1r0spbFavgWaX
pIusezv6gc63oLdjDdDiFbFuri/ofHDoWkPXGjDMTRTFpLShnMTnCiV9azDk
zIRh4GhDg0fftTwZXQMP5jpbbt5WVKN4/qf60hpwNyiXsGi3oP58m6fl19ZA
qI/uot9YM1qUQO3OT1yDGXOkRdGzGaUPEtjd3SGPJ++dk5fRhPbrmJ/4QIcD
Kq6nJVviDShNk5NVLgMOTnOzJ0t51aPnFO7mx7Pg4JNykKNX7Sc0nSfprAcn
DiyKZp/2mdehNmtd+qJiOLAd7i3/0V6NJtiMp7BL4aCoq8zGSroabR1cnqCW
w0Gb1/CBWXIVKtZw2G1SCQexyRJ0jp4fUUKsWlTaZRy0N9jucmtXokLUBj2R
OjhwTzmZ59NegZrcteLw18dBRsKxH3VaFWj1raA8IzMcYJJ1TsybvEcfyH1o
onfEweHvEn37T8vQsrzPh/+44KB4+zHukkAZOs3Zr7fogYOTy0m3T3j8h2pS
4sdb/XHgG39h/9NwCcrUL/b7fgQOLvd1bQdOF6MXNJUuuEXjwLvN8YeYXDHq
U3sp0jwWB8qC3LqMj96gQzm27EopOGgWGV3hO1OEZvi+kifk4yDE17PvoCkf
7V4ovvfzDQ4KA1PI70f5KIVlTeP3EhxwiMeJPMjMQ+01hq6++YADHuHjDyae
5KJS7Cwutm044K24duFH5Gv02H917/I7cNDTsDLDeOg1+ueKI36xCwesGK/t
+vBstD24wc9zCAceJ5mfBgtlofazbg+CF3Dw0gxvSZfxEtUJ4WxpXMFBgvG5
4JrOdPQMZysNNQEHMUppTqf301AK3ZPRT3ZwQEk4MM68k4pmVHQkpRzBA7PZ
AoVJbjIadvXO8CgjHqr+63Jn301C3RYEuHnZ8JD6fiIgwiwJVTl5LyuXG0/+
fq6yPeBNRIceiRSXSeLhLZr2W+xnHFrP07+6LosHLrZRargeh+Z9vC+rpICH
9o27udrvnqM+y9jKegweBPZOG+7VPEOZjB43dl7FA0Pbi0+xYtHo5ooMFZMR
Hv4EqS8HmzxBx8N/aBia4sF17hZVakQUWlwj3zlshQe/wOe/S/9GoPHGEwwn
7fAgbNetZX4hAr23FqVv5YiHA2TAMv5JOKopOImd9cTDm4+KBHqpMFS67ukJ
MT88WF0IBNrwx+jxa0rmrvfw8K2IOPd7+hE6HRX7i/gQD3Sxt65olISiIQTM
8n48HgY11QqL8CHo7ehFKfUUPOTcehVGs3wf1T2V5BmejodNKeO466vBKPf1
lQ36XDzg86nc6eiCUEpSipJ+IXl+/zmjbYFAdPGpemDCWzy8cKgLpVELQD82
ph1wVuJh56H349Lku2jGjUvqltV4MONxW1zs8EfD1glhWZ/w0DZq/S6Yxh81
Er1yVKQNDzNnxEZ3nvqh+Nit42eH8FA2T9f64Jc3ukrga5H+Qf7/Uf0GJl1v
dNnosqfYT7Jtr4xR1nuhsxypHbzzeDDaVt5RNPNEp+81+XMu48F3/JMcg5EH
+uvHovAxHB5E/pyiaDRxR39kng+h28IDa4GaxU8vV3SEwlaS+g8eHjrJaU4+
cUEHbaNH9vbwQC0TcHfpjTPqlOie9puKAKqPmyu09x1RW7OGddxRAgjbnDXn
WbdHbaKMtFcZCKAgfp1HGOxR65r57CUmAghVvoKWODv05klmvVk2AmilHUsR
1bBFLXVz86aOEyBF8IRZVr4Nan5fafcnBwG4v8xEsTHYoNd/3Soa5SZA9v7R
sPfdt1BTlo39IR7y/ERHg+9VVug1tahrWD4CcFYk2bW8uYka5ZZR9QgRgPe2
dB2m0AK96kh5s1WCAFRH3CbTKa+juqnJFc1SBOgXfzdeK2GGaneIH22UIcCi
ns041twUvSJpVFVzhgDNOPxF4R4TVNNynrFKgQBXdahdiGwm6KVngfaV5whg
u5iyv2ppjKrjc1j/UyGAC13ir1IqI1RNQMnpHYYAk6FLr7isDNELht8a3qAE
CDZ8kf6nwQBFKtZd89QJgNlYiFgR0EeV72p8SdMmx1es+G58TBtVKhrheaFL
gNyjhTiY0kLPjbr5JumR8wONJcL4K+hZ1WSB50YEsHK+6GslfBk94yZ+N8aE
AE0ijhJntTRRuYz6riemBHDKnip47H8JlTmYCwwzJ0Cc12ejwvmLqJRcYF+o
Jbl/XOFjWvGLqKQNk9gDKwLstyg5/PZWR8U+nxsMsCXAuoKlTiuHGiocGSnr
6UKA477Fxwd1EdRnSCHE1o0A0zRZDWcVMWjT6env1zwI5O85lz4dUVXUqhXj
gvEhgNIzlWQX0fNoybHlalk/Aty6/l1jREEZ/Wv74rCwPwE4CsRVu7SV0HRK
Ut6RQAKIFmfLn32uiC4ZZK3/DSLA0Y9aj3jqFVDlbF11wn0CJJkGZ94nnUWH
0MJfQ6EEKFRfSi3xOYOyBVty5z0hQKwBt3tZmCxq8+2I84unBJDX7Vak15FB
y7irqqKfkeP5wNfzjUca1athveYdT4C8jqTQnUkJNIOuMdc+kQDVVOF8b/rF
0VUzN5JZMgHekIScr3SLodFbX56jaQTgKQtR3Z0SQUcv+f2Uf0mAirDiGOff
p1GxZEHp0xkEWEme3g7iOo1+ORvcSf+aAP4yDA+sfIRRKm/5Q6NFBCi+HKFi
9kAANWz6afy9mAAZZipbQkX8aDZzTE7jOwI8GODgf2nFh6Kl81BQRgDKj4H9
nwkn0Wd7ibFp7wlQ+vRjSNI3bnRcV20ippIA8dH3JorKudDAlZeBvtUEuEDb
xkqTeQLtUNHqcKglgKBzFikilwPljN46Yf6JAJYmjc5t79nRj2KGHy40kePd
kvjBvHYMJd2mJTC2E8B4PLar+isLqvahAqXsJMB703pkkpUFjaOxebbxjQCf
VK2fPv7ChMrk1kmM9RDg0O/V35qKDOh9klNAdx8Boi+uXbxIQY9+V+Nobx4g
QLLjrPbb4SOoy6TX7aJhAhDTck/PvzmM1sjyVb4cJQDdvD5+KJcWpXvwjer5
GAHyt3QEPIsOoQW8Itl3fhHANMutaLeHGp02H/uhvkAATWP2a8diKVAGxKzQ
eokAUw5lTKoRB4gi/4BvyAoBOm2yMOlU+0jUTCdDLZ4A1GkKglKyu8j7Ns3R
YSIBRk++NF+Z+I2MF7bkb66Tz49l1VHGVzuIrFstKr9DgBfydOdnLm4h1/XO
0ev/IQDp/n79DalN5JHc+2G3vwRIfPbbtFZwAxnaeONVREEE1UOTe9TyJIRi
+DTyhYoIEeW5apNaRES85vWRWRoinHhr/TLGnYAE30/L4T9ChJe6zZorBWtI
wS12T4SeCBRY5+1X4qtIj1q8qgUjEbh5Xn22alhGhGifYFNYibDR+8tpnnsR
0V2keV15jAgpldN4ial55E7nQ/d+diKcUXO5GvxxDmmPvUfLxE0Eti9PB148
nUFIXhv9kjxEcA7YI/JETyMnjb2ytPjI/Wm/ap5KnkI8TjgphwsRQUYm7zzh
1S8k9fcMTe4pIkw+2VR02J5AWsZu9TWJEIEDPZyd5jCOsGebufyVIIJ58X+J
Hg9GEfTRwDluaSKMxqxuaYiOIE72+tTKskSgOevyRm1yCPkkdvmV71ly/ze8
XKGPsMj80c9O8YpEEHzI63HRZQBhXkMV/1MiQoIRLkbCuh+xLT/XvaxKBEU1
lZ5G314kJvF9Oh1KBD/iysINgR7kwx0ZR5ELRBDqvJNwz6sLoVMRobDVIMLz
O41POIw6kTM8Od8faBIhCjMt8WCqHbHY503LuEKE2jXnzr3HX5HSFvYzo7pE
mKhpSHi+34qM5MXvb+kRAXvoWe489jNCGcn47bghEeSn2zN+1LYgJjqH7A2u
ESFJT7kv5n0TEiIdKudhRoQiBnPrj+GNSBHz3t+nN4iQ6M1L+b2xHtkd2Ej+
epMIPZR+t82CapFTH71s524RoUrhhZ/7n2pEL3VVhtqWCB9KPpWpxlYhOZaz
X1EHIiCvNFtH8JXId9Q6ydKJCMa+1EwVdRXIpsC4daALERxHK/QsUt8jV+YG
fn/wIIKS33Oetw/LkPuSsUH/eRFh8Uby+zDF/5D33lf2inyIsB1+9Z53aAly
cv8TxSt/IkgfcOeTLIoRA427j5LvEUEk6HWx1WIREhYtT/M8kAjBObucSlGF
CI6j4PCjEHJ7llaP7X4eInzT+knQQyJcfufRv9qfi1zP5aa/84gIZjWyjfpV
OUiz7HMmpwgixIYJPwh5l41s3dGKs4ki53N7MOH13SxE4hM1m0U0EVSSkhRZ
yjKQpCv32PViyf2jxOmFnNORjtgzLy7HEUHqfWSo2UIqso9d5VRLIIJ7uL9k
YOALxNHGhkchhQiFezxLV8aSkFeFJzOlU4mQn1XiuVWQiPSuDfKLphPBXzNp
NuFxAqISqC3MnUmEc0xBN/jc4hDPJpr8Y9nk+uhHI4ZWY5E82kYRxhwijI+P
zH7meYYwJp6VoCggr4cUzLDc/gRRH117+7uQXP/rFbT31KMQf/4i6fU35OfT
SXmZqj8CmXzLIz9fQoR2jq7XzjJhCDtp6P2v/8j7u9rkM/fvR4i2crzCaDkR
Aiz+DHoMhiIVrYeUv38gwm324VP3Qh4gi0ebatqqiPCX41DVTPJ9hMcwULWx
hgitsRxm4R1BSMQEDn1fT4SFNEt2wwf3kDrhN01vG4kgpivul73vjxCc7dTz
m4lAcrTz9Ui6g5wq423N/EwEnfZTYUHgh9zYGr6U2kaEEMr1gdR9HyQWk/A1
/isR6oY8Awt7vZGWR7paTzuIkPUqu+xFpRcixdysG9JFhEdqD9u0LN0Rm2tB
3Xd7iLB56nBP92NXJOWlooF3HxGi1VR9ir86I51T+D6XASJcY5cyAhEn5EC0
2Nh+kHz+da8Y02Y6IAoe9oM3h4kQBJEhz6RvI06VfGZmo+R61H666D9gh/Rf
SDTXniBCBm6A0eymDXI48ur4xV9EOBoWo7+GWiOYrsNWyBQRDCZGeDTtrRCv
Yy2/zs2Qzx/OyheTrpZI/o1gG7k5IjzkMdOrSjBHfmSdmxFfIILewzLF9aHr
CNM8wV54iQhfs9GI4XNmyD2f204ca+TztlPNXvCiCRKlg3NUwZP3q5yYSE2v
EfLi1F1HKyIRwu2a59LvGiIFewcOj9aJMLyrWCt4zgD5OBTlULBJBGGxh8bh
7HpI23+sDp3bRCiXKjLgWNRBsFHpt3G/ifDJxN6U/H6GrKu8sz+3TwTekdvy
xogmQnVc0d6cggRhZTtOmS81ELa1ersQKhLkdvs0IScuIoJfNO1yaEjApqmS
p1Kqhshl9dh+oSXBtWEF9warC8iFe9dtl+lIIPxqdU1AD0X0DadsmOhJ4Orx
M0eMHoN4UK9bmzKTYBmboRK+r4TcHw+yDmQlQaRZS5m97Dkk5gONdeYxElib
dh6tClVAXsU+u9XCTgLBu++OyqyfQd46ctyaP0ECiTqekzmh8kjthSyro9wk
uFSzvswsKYd0colZyfCQIE7C4rrUmDSy+O38TX8BEnjkPAym8xBHdvJaLNOF
SHD6mCvDozuiyOEQHcuGUyS49WiGKSDnNMJhhrWYFiHBg8NNghokYURE7qYF
rTgJpJdslxxthRDFI/PmEpIkaLF34E8iCCAa0x7metIkkFcTz1BT5Efskh7e
SJEnwdTfQOyKHzfi437kRu1ZEoR7+3xXv8GJPNJMuP5TkQQmvHysPx04kHj+
k9eplEmwWhOzU51+HMneyTUTUSFB+837pTQkNqSsT8pMG0OCHuAsOOXCijQW
fzD1QMnrl9LTeEvBgvy0/HrtozoJrhoU2PFQ0CNrigbXfmiQ4MtH14r6Djrk
L9Ooyb4mCczkK1jWG2kRhkUbEyEtEmxfmvS2/kWDnGxeNtbUIUH9lHvWwilq
RCLd19jlKgnufZ3bzX1Giaj4/jWK1SdBgYNr/DwHBXL9NJPRkDEJ5vPkf3hT
7WKc9lMM/1wjQbqTAm1p3Q7m7jC/Id91EnS+2nMUztvCRJQVGaibk0ClkPmo
aPUGJuWJvIGDJQn+nqB5ZbxBwuTb1upHW5HjP6r4JOwaEVOpelG/1JoEloYP
v+SU4zEDayZ6W/YkiLqwe9jGfxkz/WXiKrcjCaq93ymuSyxiSFkOV1FnEjwx
xPNGs8xjKAPwurauJCjaymI8LzyLYTG6pxvhTn7+asMq1remMQKSlLrFniQo
Z+wXL2yexMjSROt0e5PztTG+hHv2E4NOsOmQfMnjx2ZM40fGMHofX2pz+JNg
942ECcutUcxjOYlK9kByPrOkm0WuDmKqi6t52UNI8OlixKGP432YtVOXI48/
Is//Y0Hq4koXRihrkHAsggQLgWOeYbQdGMz4q/xjUSQYnEg95Db5BWPGZW9+
LJoE9GziGyMLrZiYRNJntlgSHL/QfJbJuxlT0Ftzjy2OBAzFnQo9I42YZsZQ
abYEsm1oFetZ6jFbkcwvWFPI9URjs5UnW41haRvSYU0lQWCB1tsrjB8xklSZ
FKzpJBid48hy46rEWAdLubBkksBHOozvcmkZptNLC2EuIMEHvJBsynQBZraE
hcRURILPryWN5HryMAfLwwVMxSSguxF9y3A5B6Nw24GFqZRcn0d22+LPZ2Ey
bzyeYfhIAn/hsZZvMsmY6hTtVIZqEiw2XjlgV0zEDAywXmWoJQEpwiQV7xSP
odPL/kjfQALKJhWX/MQYjI96/ZOjX0jQL1RWuSz+GKMpuS1LN0QCX8fj/Htr
XhjcX5dg6i1yfAu+2hGPrmBuXNcR/71NAvc/PEduHVzCtFZIDuF+k2D8OA7D
9ekiJs1lVfbHHgkMJo+wetcCRmPEfabs0Dpouh3+9NNBAfOywkvbin0dPr1W
f+QfJYC54uLPWaOwDoHWjXY+pHXV18OhlR6+6/C3+f6S606i6h8nxDpgdx2a
P918VzqcoMK7F2/hHbgBAg8rPXXT9c/PX37aSUezCfDfhQ79bVulzyLfge/p
JqQPWs/1KKcpuNAV0Age2YJzY4Uxai4ZclXZp5DP8VuQb12cie55iXerYtqM
WLfhxdKd2E8R/Lw7Li+NrWO3wb1vvXv5HQVNu0HWNUaOHaD4v8v2PKawMOmf
nde6NsdT/tnr9S0NtrR/fnDk8VRwxj+/Gu04aVTwz0MBZnF/q/5Zu9YnwHDs
nw09aNojJv75ulAKx6df/+wYXVMhMvvPYeYUuN3Vf27488y2YP+f20r5y8co
fv+/v9uWH7BQ//NYJ/ZV0OF/3kk/OWzA8s8HeiWnI9j+mZYa/OqO//NxV1tW
Ea5/Psm/ccvi5D8LDYSXxvH+s0Tkib02/n+WV32jsyv4z/8D2FeInw==
       "]]}}, 
    AspectRatio -> NCache[GoldenRatio^(-1), 0.6180339887498948], Axes -> True,
     AxesLabel -> {
      FormBox["x", TraditionalForm], None}, AxesOrigin -> {0, 0}, 
    Method -> {}, PlotLabel -> 
    FormBox["\"Initial data profiles\"", TraditionalForm], 
    PlotRange -> {All, All}, PlotRangeClipping -> True, 
    PlotRangePadding -> {Automatic, Automatic}],
   TemplateBox[{"\"\[CapitalPhi](0,x)\"", "\"\[CapitalPi](0,x)\""}, 
    "LineLegend", DisplayFunction -> (StyleBox[
      StyleBox[
       PaneBox[
        TagBox[
         GridBox[{{
            TagBox[
             GridBox[{{
                GraphicsBox[{{
                   Directive[
                    EdgeForm[{
                    Opacity[0.3], 
                    GrayLevel[0]}], 
                    Hue[0.67, 0.6, 0.6]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                   Directive[
                    EdgeForm[{
                    Opacity[0.3], 
                    GrayLevel[0]}], 
                    Hue[0.67, 0.6, 0.6]], {}}}, AspectRatio -> Full, 
                 ImageSize -> {20, 10}, PlotRangePadding -> None, 
                 ImagePadding -> 1, 
                 BaselinePosition -> (Scaled[0.1] -> Baseline)], #}, {
                GraphicsBox[{{
                   Directive[
                    EdgeForm[{
                    Opacity[0.3], 
                    GrayLevel[0]}], 
                    Hue[0.9060679774997897, 0.6, 0.6]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                   Directive[
                    EdgeForm[{
                    Opacity[0.3], 
                    GrayLevel[0]}], 
                    Hue[0.9060679774997897, 0.6, 0.6]], {}}}, AspectRatio -> 
                 Full, ImageSize -> {20, 10}, PlotRangePadding -> None, 
                 ImagePadding -> 1, 
                 BaselinePosition -> (Scaled[0.1] -> Baseline)], #2}}, 
              GridBoxAlignment -> {
               "Columns" -> {Center, Left}, "Rows" -> {{Baseline}}}, 
              AutoDelete -> False, 
              GridBoxDividers -> {
               "Columns" -> {{False}}, "Rows" -> {{False}}}, 
              GridBoxItemSize -> {"Columns" -> {{All}}, "Rows" -> {{All}}}, 
              GridBoxSpacings -> {"Columns" -> {{0.5}}, "Rows" -> {{0.8}}}], 
             "Grid"]}}, 
          GridBoxAlignment -> {"Columns" -> {{Left}}, "Rows" -> {{Top}}}, 
          AutoDelete -> False, 
          GridBoxItemSize -> {
           "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
          GridBoxSpacings -> {"Columns" -> {{1}}, "Rows" -> {{0}}}], "Grid"], 
        Alignment -> Left, AppearanceElements -> None, 
        ImageMargins -> {{5, 5}, {5, 5}}, ImageSizeAction -> "ResizeToFit"], 
       LineIndent -> 0, StripOnInput -> False], {FontFamily -> "Times"}, 
      Background -> Automatic, StripOnInput -> False]& ), Editable -> True, 
    InterpretationFunction :> (RowBox[{"LineLegend", "[", 
       RowBox[{
         RowBox[{"{", 
           RowBox[{
             RowBox[{"Directive", "[", 
               RowBox[{"Hue", "[", 
                 RowBox[{"0.67`", ",", "0.6`", ",", "0.6`"}], "]"}], "]"}], 
             ",", 
             RowBox[{"Directive", "[", 
               RowBox[{"Hue", "[", 
                 RowBox[{"0.9060679774997897`", ",", "0.6`", ",", "0.6`"}], 
                 "]"}], "]"}]}], "}"}], ",", 
         RowBox[{"{", 
           RowBox[{#, ",", #2}], "}"}], ",", 
         RowBox[{"LegendLayout", "\[Rule]", "\"Column\""}]}], "]"}]& )]},
  "Legended",
  DisplayFunction->(GridBox[{{
      TagBox[
       ItemBox[
        PaneBox[
         TagBox[#, "SkipImageSizeLevel"], Alignment -> {Center, Baseline}, 
         BaselinePosition -> Baseline], DefaultBaseStyle -> "Labeled"], 
       "SkipImageSizeLevel"], 
      ItemBox[#2, DefaultBaseStyle -> "LabeledLabel"]}}, 
    GridBoxAlignment -> {"Columns" -> {{Center}}, "Rows" -> {{Center}}}, 
    AutoDelete -> False, GridBoxItemSize -> Automatic, 
    BaselinePosition -> {1, 1}]& ),
  Editable->True,
  InterpretationFunction->(RowBox[{"Legended", "[", 
     RowBox[{#, ",", 
       RowBox[{"Placed", "[", 
         RowBox[{#2, ",", "After"}], "]"}]}], "]"}]& )]], "Output",
 CellChangeTimes->{3.583330653471265*^9}]
}, Open  ]],

Cell["\<\
Calling the solver with default options\
\>", "Text",
 CellChangeTimes->{{3.583327492248662*^9, 3.583327503986105*^9}, {
  3.583330682921515*^9, 3.583330683294639*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"sol", "=", 
  RowBox[{"First", "@", 
   RowBox[{"Solver", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"X", ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"\[CapitalPhi]", "[", "X", "]"}], ",", 
         RowBox[{"\[CapitalPi]", "[", "X", "]"}]}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"tmin", "=", "0"}], ",", 
       RowBox[{"tmax", "=", "\[Pi]"}]}], "}"}]}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.580629610777328*^9, 3.5806296111380053`*^9}, 
   3.583327489440921*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"u", "\[Rule]", 
   TagBox[
    RowBox[{"InterpolatingFunction", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"{", 
        RowBox[{"0.`", ",", "3.141592653589793`"}], "}"}], "}"}], 
      ",", "\<\"<>\"\>"}], "]"}],
    False,
    Editable->False]}], "}"}]], "Output",
 CellChangeTimes->{3.5833306678058357`*^9}]
}, Open  ]],

Cell["\<\
Solution is stored as nested list of two elements (for each of the matter \
fields)\
\>", "Text",
 CellChangeTimes->{{3.583327634275436*^9, 3.5833276801948013`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"u", "[", "tmax", "]"}], "/.", "sol"}]], "Input",
 CellChangeTimes->{{3.583327703972548*^9, 3.583327705319563*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"4.181482215096286`*^-6", ",", 
     RowBox[{"-", "0.007713833237008048`"}], ",", 
     RowBox[{"-", "0.015260342585381781`"}], ",", 
     RowBox[{"-", "0.0224635109260002`"}], ",", 
     RowBox[{"-", "0.029131733985545104`"}], ",", 
     RowBox[{"-", "0.035122155689165976`"}], ",", 
     RowBox[{"-", "0.04031117975048302`"}], ",", 
     RowBox[{"-", "0.04460137714911431`"}], ",", 
     RowBox[{"-", "0.047912723791621786`"}], ",", 
     RowBox[{"-", "0.050202111167469976`"}], ",", 
     RowBox[{"-", "0.05145775302876136`"}], ",", 
     RowBox[{"-", "0.05169986625494874`"}], ",", 
     RowBox[{"-", "0.050977776571148534`"}], ",", 
     RowBox[{"-", "0.04937051582522466`"}], ",", 
     RowBox[{"-", "0.04698003521190831`"}], ",", 
     RowBox[{"-", "0.043931203397353236`"}], ",", 
     RowBox[{"-", "0.0403633034253576`"}], ",", 
     RowBox[{"-", "0.03642421886586887`"}], ",", 
     RowBox[{"-", "0.03226555793774188`"}], ",", 
     RowBox[{"-", "0.028032790601764803`"}], ",", 
     RowBox[{"-", "0.023865155859940205`"}], ",", 
     RowBox[{"-", "0.019882294393921026`"}], ",", 
     RowBox[{"-", "0.016186765264684315`"}], ",", 
     RowBox[{"-", "0.012854313953480655`"}], ",", 
     RowBox[{"-", "0.00993746529035158`"}], ",", 
     RowBox[{"-", "0.007460328947489768`"}], ",", 
     RowBox[{"-", "0.005423774537384702`"}], ",", 
     RowBox[{"-", "0.0038056802688951324`"}], ",", 
     RowBox[{"-", "0.002567842790607959`"}], ",", 
     RowBox[{"-", "0.0016587666878516386`"}], ",", 
     RowBox[{"-", "0.0010210136906445451`"}], ",", 
     RowBox[{"-", "0.0005956535956988182`"}], ",", 
     RowBox[{"-", "0.00032781260848278616`"}], ",", 
     RowBox[{"-", "0.00016951513128686765`"}], ",", 
     RowBox[{"-", "0.00008224589475874637`"}], ",", 
     RowBox[{"-", "0.00003732965269199645`"}], ",", 
     RowBox[{"-", "0.000015437243518107587`"}], ",", 
     RowBox[{"-", "4.855566593939968`*^-6"}], ",", "7.124955729718573`*^-7", 
     ",", "3.988306313255529`*^-6", ",", "5.964674193216384`*^-6", ",", 
     "6.811181888183435`*^-6", ",", "6.814792016703064`*^-6", ",", 
     "6.190004739703366`*^-6", ",", "5.365376858999704`*^-6", ",", 
     "4.540252702819628`*^-6", ",", "3.896611547833553`*^-6", ",", 
     "3.3950920006959626`*^-6", ",", "3.0159461304921495`*^-6", ",", 
     "2.642475964838872`*^-6", ",", "2.2738601126118925`*^-6", ",", 
     "1.893809607901484`*^-6", ",", "1.5540687831051543`*^-6", ",", 
     "1.2505830610368154`*^-6", ",", "1.011228793527224`*^-6", ",", 
     "7.90024319850894`*^-7", ",", "5.663791503400922`*^-7", ",", 
     "4.221577371097521`*^-7", ",", "3.7380799250470183`*^-7", ",", 
     "1.577081380624584`*^-7", ",", 
     RowBox[{"-", "3.357429626628359`*^-8"}], ",", "2.4834556067212627`*^-7", 
     ",", "1.6859858907702246`*^-7", ",", 
     RowBox[{"-", "2.9912408238901865`*^-7"}], ",", "0.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "0.3185744261539936`"}], ",", 
     RowBox[{"-", "0.3173356772155778`"}], ",", 
     RowBox[{"-", "0.3136408555045279`"}], ",", 
     RowBox[{"-", "0.3075647005502883`"}], ",", 
     RowBox[{"-", "0.2992171304870802`"}], ",", 
     RowBox[{"-", "0.28874555281353687`"}], ",", 
     RowBox[{"-", "0.2763466316664229`"}], ",", 
     RowBox[{"-", "0.2622401374373063`"}], ",", 
     RowBox[{"-", "0.24668031123615078`"}], ",", 
     RowBox[{"-", "0.22994339308015288`"}], ",", 
     RowBox[{"-", "0.2123270614755155`"}], ",", 
     RowBox[{"-", "0.19413030951572333`"}], ",", 
     RowBox[{"-", "0.17566242450230943`"}], ",", 
     RowBox[{"-", "0.15722444416355624`"}], ",", 
     RowBox[{"-", "0.13910732505104548`"}], ",", 
     RowBox[{"-", "0.12157807934768705`"}], ",", 
     RowBox[{"-", "0.10488074939582338`"}], ",", 
     RowBox[{"-", "0.08922295476750317`"}], ",", 
     RowBox[{"-", "0.07477613407147946`"}], ",", 
     RowBox[{"-", "0.061667057661095794`"}], ",", 
     RowBox[{"-", "0.04997941128288728`"}], ",", 
     RowBox[{"-", "0.039749767608345504`"}], ",", 
     RowBox[{"-", "0.0309725007313571`"}], ",", 
     RowBox[{"-", "0.023598436793444776`"}], ",", 
     RowBox[{"-", "0.017543877834660264`"}], ",", 
     RowBox[{"-", "0.012694257737962941`"}], ",", 
     RowBox[{"-", "0.00891458476126222`"}], ",", 
     RowBox[{"-", "0.006055248638124349`"}], ",", 
     RowBox[{"-", "0.003963134386986317`"}], ",", 
     RowBox[{"-", "0.0024877940008980848`"}], ",", 
     RowBox[{"-", "0.001490362716903807`"}], ",", 
     RowBox[{"-", "0.000847269435993748`"}], ",", 
     RowBox[{"-", "0.00045476710137386993`"}], ",", 
     RowBox[{"-", "0.00022967642995275076`"}], ",", 
     RowBox[{"-", "0.00010966293260428675`"}], ",", 
     RowBox[{"-", "0.000050607588321459914`"}], ",", 
     RowBox[{"-", "0.000023754647474710033`"}], ",", 
     RowBox[{"-", "0.000012055902777579188`"}], ",", 
     RowBox[{"-", "6.604788296118927`*^-6"}], ",", 
     RowBox[{"-", "3.5336004443473782`*^-6"}], ",", 
     RowBox[{"-", "1.5024538439553542`*^-6"}], ",", 
     RowBox[{"-", "2.3142708917206884`*^-7"}], ",", "3.740654460810871`*^-7", 
     ",", "4.5277118059443294`*^-7", ",", "2.740210720105907`*^-7", ",", 
     "6.250277632077504`*^-8", ",", 
     RowBox[{"-", "1.491427578118679`*^-8"}], ",", "1.4741620651408455`*^-8", 
     ",", "9.458012859850093`*^-8", ",", "1.433319095499835`*^-7", ",", 
     "1.6266502805492855`*^-7", ",", "1.5147269489924395`*^-7", ",", 
     "1.2844095797198834`*^-7", ",", "1.0200297746222291`*^-7", ",", 
     "9.001230288096458`*^-8", ",", "7.791014935584684`*^-8", ",", 
     "6.39507908842884`*^-8", ",", "5.8863838200242485`*^-8", ",", 
     "4.054902693472321`*^-8", ",", "2.3831808963394565`*^-9", ",", 
     "8.28824722522562`*^-9", ",", "1.949879586035455`*^-8", ",", 
     "1.5976120624035462`*^-8", ",", "1.9677413814064007`*^-8", ",", "0.`"}], 
    "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.583330668313158*^9}]
}, Open  ]],

Cell["\<\
Below we plot scalar field configuration at the end of the simulation\
\>", "Text",
 CellChangeTimes->{{3.583327723909875*^9, 3.5833277479829073`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"GraphicsRow", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"ListPlot", "[", 
      RowBox[{
       RowBox[{"Transpose", "[", 
        RowBox[{"{", 
         RowBox[{"X", ",", 
          RowBox[{"Part", "[", 
           RowBox[{
            RowBox[{
             RowBox[{"u", "[", "tmax", "]"}], "/.", "sol"}], ",", "1"}], 
           "]"}]}], "}"}], "]"}], ",", 
       RowBox[{"PlotRange", "\[Rule]", "All"}], ",", 
       RowBox[{"PlotLabel", "\[Rule]", "\"\<\[CapitalPhi]\>\""}]}], "]"}], 
     ",", 
     RowBox[{"ListPlot", "[", 
      RowBox[{
       RowBox[{"Transpose", "[", 
        RowBox[{"{", 
         RowBox[{"X", ",", 
          RowBox[{"Part", "[", 
           RowBox[{
            RowBox[{
             RowBox[{"u", "[", "tmax", "]"}], "/.", "sol"}], ",", "2"}], 
           "]"}]}], "}"}], "]"}], ",", 
       RowBox[{"PlotRange", "\[Rule]", "All"}], ",", 
       RowBox[{"PlotLabel", "\[Rule]", "\"\<\[CapitalPi]\>\""}]}], "]"}]}], 
    "}"}], ",", 
   RowBox[{"ImageSize", "\[Rule]", "Large"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.583327551081925*^9, 3.583327610190572*^9}, {
  3.583327692020059*^9, 3.583327694806924*^9}, {3.5833277601104794`*^9, 
  3.583327835952932*^9}}],

Cell[BoxData[
 GraphicsBox[{{}, {InsetBox[
     GraphicsBox[{{}, 
       {RGBColor[0.24720000000000014`, 0.24, 0.6], PointBox[CompressedData["
1:eJw1lA1M00cYxquihhWtQx1WDBsba7CETSeby4z3ztXZpCtgKEindQ4GEguI
GzgZsjYYYCidLei0jVSBMi2lm7NUx+jgGJ9l4GhZ0VU60PJlQWiFlg+L2Uf+
fy65XC53977P83uSC07MiEleTqFQ9vw3/1+XBm8te0PfWTPaFL431husADn1
h/hzcjEm9tXQ1KE6Y3pfinuDd4hzrToY3v1yrZZymTz/BQ6cXSi9bVHiT96N
25ojxLBWTl/8xltB3m+Gb/0SGzSqKnzyhsFheN4GH0rSHj7vu06+7wStUrTL
p0iNDbruxvf2dUOTfzQvQF9N1uuBS7pWbQ1fgymDU50CthmypMXfp2RryPq9
EMRJOtBM1+CqpFMRZakWOLL3jjKAXU3264MElSK5dY0a7xv/52q/9D5sYxou
MERL/a3AZ8XXiTVVeDyjyDdQ/wDOC64tbL9eSeqxQUbWB9lbCsqxxLMu6+Bf
f0OH4qihXF9G6huEhJZ6ceAJOZY3cJ1c0UOInmzZtkpwkdT7CEQpzemsCzJ8
jFJSlbbODmmn400C3jlSvx2iR4QrNh3Mx7tYfR9LKocAGSV3686LSD/DEKsK
Sdq980vsV0inaSNG4NepFN+A8AzS3wi88GkvPdQ3GQ8YD7d2tY/CpI0VdiT8
EOl3DLr60ebP6/fjm9TKryb4j6Epm3tIn88i/TvAzGg+bjz9Ns6LGn2DOuGA
OMbAkHcng+QxDjKa+E66dCOOKWEOM7+egK42GT2ydAXJ5wmMtHs/GnvT1Rhi
Oa7g0CaBKsv1XjtsaSR4TcLdNVfjOI9vIM9LtVHCiimIGFBzjtWbEMHPCere
lNACHysa0nqXtdFdkBJ5LzWzxIYIni7Y/IpfK+87G+L+obRZ7C5gKxaLT81a
EcH3KfxeekW6Ou8euu2En4drnsIJ/nQojfonInhPQ21MWLo73oSCXrSXuLOm
IcfokI3ldCOC/zSoK1InbnE7UeFb+Wk+aAZ0NbGFWmY7IvKYAW9PkHn9+hbk
5DHYG1a7wcFh37S2YUTk44aVy4t0Wv96xD9pDA4xuSF99JnyHa8eEXl5oOOL
QPP2uZ/Qb5eEizsUHujuoT3Yc0aDiPw8IMqLfBK6TIW21vndZyXOgllsFyhj
yxCR5yyIXnc55zcqUKn1x1u8sDlI6B/L7GEWICLfOXjtUVSRcFVio/fZfsln
7jnIfbWcV6yRISLvebBWZg9SKgpR0paZo5kN89C0Ulzu8L/YSOS/AEv/wL9k
lBEY
         "]]}, {}},
      AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
      Axes->True,
      AxesLabel->{None, None},
      AxesOrigin->{0., 0.},
      Method->{},
      PlotLabel->FormBox["\"\[CapitalPhi]\"", TraditionalForm],
      PlotRangeClipping->True], {192., -116.80842387373012`}, 
     ImageScaled[{0.5, 0.5}], {360., 222.49223594996212`}], InsetBox[
     GraphicsBox[{{}, 
       {RGBColor[0.24720000000000014`, 0.24, 0.6], PointBox[CompressedData["
1:eJw1lA1M00cYxsvmPkE+TN0qkNUG1MECbAqxg3FvOlAcI8AQxofDCQUN1AGb
lBUFGSCI2Iy0JMyiMkdwWiVrAC3Djl7YBMqg5asVC5Zu5WOUjhZKC2zA2Jb/
n0sul8vdve/z/J7kGOm5cZnPUSgU1n/z/3V7FNM4mxVsNab5hcevM0TQ1ayP
Co7Z3otBFXSE1rJLjUcYh0qKtK2wiy4Y95KMkucd4EwtuP7p/lF8kpngcz4b
g7Wbf0t1foS8/zPcLU5UiCXDmHtHZpRtdgOrsGSiWjFEvu8Dbo84h1k7iGWt
A/LgowNwy1q/ochRkvUG4ZTpalGVXz+m6M19n0QMQ8K+cLcwrYKsPwJcVQDT
o6gHN2V8GXiDo4bsd+eCzfTHZD8NJDJ1w+GqLnx0fqthomYMvsp/2NpJx2R/
LVwRNG4UaB/h+dyqVzwejMPk6V5F7JiU1PMMhI9OpFz2bsN8u2t+ylMdhB7+
9fVRoYTUp4dNna5rtk6Mr3VGWaIu/gbUaqWemtJE6v0dXKW6j1nt3+IsiqDp
rKsBXjQ5f/C27zVSvwFOrvhJX1gV4JAwTTK/cQp4Dndyvti6QvqZhgaOc+wg
qww7Ve5xaQ6cgUqq6TO2kkf6m4FeQ3Tf7ZA8PKlIfdzfMwuJK5aQY2kZpN8/
oEAWpHiZk4Qljo2FpqQ50PyT+n7WLx+S/o1QvT412qEMxaXRs/6OJiMM6dvL
xO7+JI95SGd5PUnBnjhO4DvtW2wCWVzpxdyqV0k+f4KZ079UN7cm91bniCJd
FmAh7x1xwTGjnOC1AGVO9rQnbRNy+2tt0dnfmYFZzmYnNynlBD8LCLg/8TYD
O+RTzesO3XsW4UFFRGCPS42c4LkIrJiZ4Ex3EYpS3XymNixCAnunlJ/egAi+
S3DD4xznNluIHlqgffr+EmSN7+O92ZuHCN5WwG5nJuqfj5W/4WYQ2PKt4EX3
vxd5NwYR/K2Q3GI8XMIuRJUHL53dgZbB+Qhz8Ol75YjIYxmyKJPtezUVyHJ8
fwT1JRvwHQ/M18RfQkQ+NlC7h9w8GFqKkrgKhveQDTT0yBPfpF1ARF52oH8v
9RP58FBXXfbGIZEd2oqujy0Z8xGRnx1qPbeC7vl+jnx+dBoLS18BfbkgIKA+
FxF5rgBHG7BzR3cmEmp/aDn+1iqcYtFq7/O8EZHvKpyRmGjlAyy0/ncsn21b
BXPq7t4+Szwi8l6DKeHXVy8c+AhleC6fPte5Bg6M3bOGvQmIyP8v2P4H/gUY
mhJo
         "]]}, {}},
      AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
      Axes->True,
      AxesLabel->{None, None},
      AxesOrigin->{0., 0.},
      Method->{},
      PlotLabel->FormBox["\"\[CapitalPi]\"", TraditionalForm],
      PlotRangeClipping->True], {576., -116.80842387373012`}, 
     ImageScaled[{0.5, 0.5}], {360., 222.49223594996212`}]}, {}},
  ContentSelectable->True,
  ImageSize->Large,
  PlotRangePadding->{6, 5}]], "Output",
 CellChangeTimes->{3.583330668685223*^9}]
}, Open  ]],

Cell[TextData[{
 "Solution visualization (please note the use of the geometric factor ",
 Cell[BoxData[
  FormBox[
   RowBox[{"tan", " ", "x"}], TraditionalForm]],
  FormatType->"TraditionalForm"],
 " for convenience)"
}], "Text",
 CellChangeTimes->{{3.580480010159945*^9, 3.580480014120749*^9}, {
  3.5806328315613527`*^9, 3.580632835112205*^9}, {3.583327847067403*^9, 
  3.583327914977055*^9}}],

Cell[BoxData[
 RowBox[{"Manipulate", "[", "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"ListPlot", "[", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"Transpose", "@", 
        RowBox[{"{", 
         RowBox[{"X", ",", 
          RowBox[{
           RowBox[{"Tan", "[", "X", "]"}], "#"}]}], "}"}]}], "&"}], "/@", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"u", "[", "t", "]"}], "/.", "sol"}], ")"}]}], ",", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{
         RowBox[{"-", "\[Epsilon]"}], "/", "5"}], ",", 
        RowBox[{"\[Epsilon]", "/", "5"}]}], "}"}]}], ",", 
     RowBox[{"Joined", "\[Rule]", "True"}], ",", 
     RowBox[{"Mesh", "\[Rule]", "All"}], ",", 
     RowBox[{"AxesLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"x", ",", "None"}], "}"}]}], ",", 
     RowBox[{"PlotLegends", "\[Rule]", 
      RowBox[{"LineLegend", "[", 
       RowBox[{"{", 
        RowBox[{
        "\"\<tan(x)\[CapitalPhi](t,x)\>\"", ",", 
         "\"\<tan(x)\[CapitalPi](t,x)\>\""}], "}"}], "]"}]}]}], "]"}], ",", 
   "\[IndentingNewLine]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"t", ",", "0", ",", 
       RowBox[{"TraditionalForm", "@", "t"}]}], "}"}], ",", "tmin", ",", 
     "tmax", ",", 
     RowBox[{"Appearance", "\[Rule]", "\"\<Labeled\>\""}]}], "}"}]}], 
  "\[IndentingNewLine]", "]"}]], "Input",
 CellChangeTimes->{{3.580480024795167*^9, 3.580480110992095*^9}, {
  3.5804802652460318`*^9, 3.580480370230212*^9}, {3.580480407110992*^9, 
  3.5804805541594152`*^9}, {3.580480584769487*^9, 3.580480595423612*^9}, {
  3.5804847669679823`*^9, 3.580484769161642*^9}, {3.580632851955055*^9, 
  3.5806328910062733`*^9}, {3.583327618272705*^9, 3.583327619976667*^9}}],

Cell[BoxData[
 RowBox[{"Manipulate", "[", "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"ListPlot", "[", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"Transpose", "@", 
        RowBox[{"{", 
         RowBox[{"X", ",", "#"}], "}"}]}], "&"}], "/@", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"u", "[", "t", "]"}], "/.", "sol"}], ")"}]}], ",", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"x1", ",", "x2"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"y1", ",", "y2"}], "}"}]}], "}"}]}], ",", 
     RowBox[{"Joined", "\[Rule]", "True"}], ",", 
     RowBox[{"Mesh", "\[Rule]", "All"}], ",", 
     RowBox[{"AxesLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"x", ",", "None"}], "}"}]}], ",", 
     RowBox[{"PlotLegends", "\[Rule]", 
      RowBox[{"LineLegend", "[", 
       RowBox[{"{", 
        RowBox[{
        "\"\<\[CapitalPhi](t,x)\>\"", ",", "\"\<\[CapitalPi](t,x)\>\""}], 
        "}"}], "]"}]}], ",", 
     RowBox[{"ImageSize", "\[Rule]", "400"}]}], "]"}], ",", 
   "\[IndentingNewLine]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"t", ",", "0", ",", 
       RowBox[{"TraditionalForm", "@", "t"}]}], "}"}], ",", "tmin", ",", 
     "tmax", ",", 
     RowBox[{"Appearance", "\[Rule]", "\"\<Labeled\>\""}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"x1", ",", "0", ",", 
       SubscriptBox["x", "1"]}], "}"}], ",", "0", ",", "x2", ",", 
     RowBox[{"ControlPlacement", "\[Rule]", "Bottom"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"x2", ",", 
       RowBox[{"\[Pi]", "/", "2"}], ",", 
       SubscriptBox["x", "2"]}], "}"}], ",", "x1", ",", 
     RowBox[{"\[Pi]", "/", "2"}], ",", 
     RowBox[{"ControlPlacement", "\[Rule]", "Bottom"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"y1", ",", 
       RowBox[{"-", "\[Epsilon]"}], ",", 
       SubscriptBox["y", "1"]}], "}"}], ",", 
     RowBox[{"-", "\[Epsilon]"}], ",", "y2", ",", 
     RowBox[{"ControlPlacement", "\[Rule]", "Left"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"y2", ",", "\[Epsilon]", ",", 
       SubscriptBox["y", "2"]}], "}"}], ",", "y1", ",", "\[Epsilon]", ",", 
     RowBox[{"ControlPlacement", "\[Rule]", "Left"}]}], "}"}]}], 
  "\[IndentingNewLine]", "]"}]], "Input",
 CellChangeTimes->{{3.580484802311315*^9, 3.5804848050453176`*^9}, {
  3.580484987388411*^9, 3.580485122344164*^9}, {3.580485191859289*^9, 
  3.580485281980069*^9}, {3.580485411065117*^9, 3.5804854376890373`*^9}, {
  3.580625476907143*^9, 3.5806254901003723`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"Clear", "[", 
   RowBox[{
   "X", ",", "\[CapitalPi]", ",", "\[CapitalPhi]", ",", "\[Epsilon]", ",", 
    "\[Sigma]", ",", "sol"}], "]"}], ";"}]], "Input",
 CellChangeTimes->{{3.580479548868829*^9, 3.580479558687595*^9}, {
   3.580626992639715*^9, 3.580626992859437*^9}, 3.583327267309698*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Convergence test", "Subsubsection",
 CellChangeTimes->{{3.580479535089082*^9, 3.580479537211094*^9}, {
  3.580480700623465*^9, 3.580480703337995*^9}, {3.583327936933613*^9, 
  3.583327937787497*^9}}],

Cell["\<\
 The convergence test (based on Richardson extrapolation) of the numerical \
method is performed here. The expected fourth order of convergence is \
obtained.\
\>", "Item",
 CellChangeTimes->{{3.584680189235927*^9, 3.584680202306673*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"Clear", "[", 
   RowBox[{
   "\[CapitalPi]", ",", "\[CapitalPhi]", ",", "\[Epsilon]", ",", "\[Sigma]", 
    ",", "sol"}], "]"}], ";"}]], "Input",
 CellChangeTimes->{{3.580474669163686*^9, 3.580474691579561*^9}, 
   3.580480889248583*^9, {3.580485680646534*^9, 3.580485682042045*^9}, 
   3.583327932775968*^9}],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"{", 
    RowBox[{"\[Epsilon]", ",", "\[Sigma]"}], "}"}], "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"1", "/", "2"}], ",", 
     RowBox[{"1", "/", "4"}]}], "}"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"\[CapitalPi]", "[", "x_", "]"}], ":=", 
   RowBox[{
    RowBox[{"If", "[", 
     RowBox[{
      RowBox[{"x", "\[Equal]", 
       RowBox[{"\[Pi]", "/", "2"}]}], ",", "0", ",", 
      RowBox[{
       RowBox[{"2", "/", "\[Pi]"}], " ", "\[Epsilon]", " ", 
       RowBox[{"Exp", "[", 
        RowBox[{"-", 
         SuperscriptBox[
          RowBox[{"(", 
           FractionBox[
            RowBox[{"Tan", "[", "x", "]"}], 
            RowBox[{
             RowBox[{"\[Pi]", "/", "2"}], " ", "\[Sigma]"}]], ")"}], "2"]}], 
        "]"}]}]}], "]"}], "//", 
    RowBox[{
     RowBox[{"Chop", "[", 
      RowBox[{"#", ",", "$MinMachineNumber"}], "]"}], "&"}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"\[CapitalPhi]", "[", "x_", "]"}], ":=", 
   RowBox[{
    RowBox[{"If", "[", 
     RowBox[{
      RowBox[{"x", "\[Equal]", 
       RowBox[{"\[Pi]", "/", "2"}]}], ",", "0", ",", 
      RowBox[{
       RowBox[{"2", "/", "\[Pi]"}], " ", "\[Epsilon]", " ", "x", " ", 
       RowBox[{"Exp", "[", 
        RowBox[{"-", 
         SuperscriptBox[
          RowBox[{"(", 
           FractionBox[
            RowBox[{"Tan", "[", "x", "]"}], 
            RowBox[{
             RowBox[{"\[Pi]", "/", "2"}], " ", "\[Sigma]"}]], ")"}], "2"]}], 
        "]"}]}]}], "]"}], "//", 
    RowBox[{
     RowBox[{"Chop", "[", 
      RowBox[{"#", ",", "$MinMachineNumber"}], "]"}], "&"}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"SetAttributes", "[", 
     RowBox[{"#", ",", "Listable"}], "]"}], "&"}], "/@", 
   RowBox[{"{", 
    RowBox[{"\[CapitalPi]", ",", "\[CapitalPhi]"}], "}"}]}], ";"}]}], "Input",\

 CellChangeTimes->{{3.5804809080131187`*^9, 3.5804809094082193`*^9}, {
  3.583327949497264*^9, 3.583327952586666*^9}}],

Cell[TextData[{
 "Here we calculate then solution for three different resolutions (defined by \
grid spacing ",
 Cell[BoxData[
  FormBox["h", TraditionalForm]]],
 "): ",
 Cell[BoxData[
  FormBox["h", TraditionalForm]]],
 ", ",
 Cell[BoxData[
  FormBox[
   RowBox[{"h", "/", "2"}], TraditionalForm]]],
 ", ",
 Cell[BoxData[
  FormBox[
   RowBox[{"h", "/", "4"}], TraditionalForm]]],
 "."
}], "Text",
 CellChangeTimes->{{3.580485563521241*^9, 3.580485638316787*^9}, {
  3.580629674403583*^9, 3.580629674953974*^9}, {3.583327963313006*^9, 
  3.58332796946459*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"Table", "[", 
   RowBox[{
    RowBox[{"Module", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"n", "=", 
         RowBox[{
          RowBox[{"32", "*", "i"}], "+", "1"}]}], ",", "h", ",", "X"}], "}"}],
       ",", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"h", "=", 
        RowBox[{
         FractionBox["\[Pi]", "2"], "/", 
         RowBox[{"(", 
          RowBox[{"n", "-", "1"}], ")"}]}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"X", "=", 
        RowBox[{"N", "@", 
         RowBox[{"Range", "[", 
          RowBox[{"0", ",", 
           FractionBox["\[Pi]", "2"], ",", "h"}], "]"}]}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"sol", "[", "i", "]"}], "=", 
        RowBox[{"First", "@", 
         RowBox[{"Solver", "[", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{"X", ",", 
             RowBox[{"{", 
              RowBox[{
               RowBox[{"\[CapitalPhi]", "[", "X", "]"}], ",", 
               RowBox[{"\[CapitalPi]", "[", "X", "]"}]}], "}"}]}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"tmin", "=", "0"}], ",", 
             RowBox[{"tmax", "=", "\[Pi]"}]}], "}"}], ",", 
           RowBox[{"Method", "\[Rule]", 
            RowBox[{"{", 
             RowBox[{"\"\<ExplicitRungeKutta\>\"", ",", 
              RowBox[{"\"\<DifferenceOrder\>\"", "\[Rule]", "4"}], ",", 
              RowBox[{"\"\<StiffnessTest\>\"", "\[Rule]", "False"}]}], 
             "}"}]}], ",", 
           RowBox[{"MaxStepSize", "\[Rule]", 
            RowBox[{"h", "/", "2"}]}], ",", 
           RowBox[{"MaxSteps", "\[Rule]", "Infinity"}]}], "]"}]}]}]}]}], 
     "\[IndentingNewLine]", "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"i", ",", 
      RowBox[{"{", 
       RowBox[{"1", ",", "2", ",", "4"}], "}"}]}], "}"}]}], "]"}], "//", 
  "AbsoluteTiming"}]], "Input",
 CellChangeTimes->{{3.580480741199759*^9, 3.58048075687671*^9}, {
  3.580480810380052*^9, 3.580480865767086*^9}, {3.580481327360407*^9, 
  3.580481351359791*^9}, {3.580481721481148*^9, 3.580481736006837*^9}, {
  3.580629599450264*^9, 3.5806296001732063`*^9}, {3.58332826955365*^9, 
  3.5833283674186296`*^9}, {3.583328626611908*^9, 3.583328647451285*^9}, {
  3.583328679544908*^9, 3.583328712519188*^9}, {3.583328786454652*^9, 
  3.5833287882453537`*^9}, {3.583328915018531*^9, 3.583328917892138*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"103.58183800000000474028638564050197601318`8.035883526335082", ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"u", "\[Rule]", 
       TagBox[
        RowBox[{"InterpolatingFunction", "[", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"{", 
            RowBox[{"0.`", ",", "3.141592653589793`"}], "}"}], "}"}], 
          ",", "\<\"<>\"\>"}], "]"}],
        False,
        Editable->False]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"u", "\[Rule]", 
       TagBox[
        RowBox[{"InterpolatingFunction", "[", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"{", 
            RowBox[{"0.`", ",", "3.141592653589793`"}], "}"}], "}"}], 
          ",", "\<\"<>\"\>"}], "]"}],
        False,
        Editable->False]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"u", "\[Rule]", 
       TagBox[
        RowBox[{"InterpolatingFunction", "[", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"{", 
            RowBox[{"0.`", ",", "3.141592653589793`"}], "}"}], "}"}], 
          ",", "\<\"<>\"\>"}], "]"}],
        False,
        Editable->False]}], "}"}]}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{
  3.58332811134682*^9, 3.583328497598564*^9, {3.583328685100711*^9, 
   3.583328689519665*^9}, 3.5833287326079063`*^9, 3.5833287809815607`*^9, 
   3.583328927411172*^9, 3.583330649381748*^9}]
}, Open  ]],

Cell[TextData[{
 "Convergence factor ",
 Cell[BoxData[
  FormBox["Q", TraditionalForm]],
  FormatType->"TraditionalForm"],
 " is defined as"
}], "Text",
 CellChangeTimes->{{3.580481758457921*^9, 3.580481761877098*^9}, {
  3.583328012665172*^9, 3.5833280296748667`*^9}}],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"Q", "(", "t", ")"}], "=", 
   FractionBox[
    RowBox[{"||", 
     RowBox[{
      RowBox[{
       SuperscriptBox["u", 
        RowBox[{"h", "/", "2"}]], "(", 
       RowBox[{"t", ",", "."}], ")"}], "-", 
      RowBox[{
       SuperscriptBox["u", "h"], "(", 
       RowBox[{"t", ",", "."}], ")"}]}], "||"}], 
    RowBox[{"||", 
     RowBox[{
      RowBox[{
       SuperscriptBox["u", 
        RowBox[{"h", "/", "4"}]], "(", 
       RowBox[{"t", ",", "."}], ")"}], "-", 
      RowBox[{
       SuperscriptBox["u", 
        RowBox[{"h", "/", "2"}]], "(", 
       RowBox[{"t", ",", "."}], ")"}]}], "||"}]]}], TraditionalForm]], "Input",\

 Evaluatable->False,
 CellChangeTimes->{{3.580481767094646*^9, 3.580481802536029*^9}, 
   3.58048185687854*^9, {3.5804818989950323`*^9, 3.58048198641927*^9}, {
   3.5833281903708467`*^9, 3.5833281985270777`*^9}}],

Cell[TextData[{
 "which for numerical scheme of accuracy order ",
 Cell[BoxData[
  FormBox["p", TraditionalForm]]],
 " is equal"
}], "Text",
 CellChangeTimes->{{3.580485712466631*^9, 3.580485793684884*^9}, {
  3.583328046923953*^9, 3.583328090315016*^9}}],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{
    UnderscriptBox["lim", 
     RowBox[{"h", "\[Rule]", "0"}]], "\[ThinSpace]", 
    RowBox[{
     SubscriptBox["Q", "h"], "(", "t", ")"}]}], "\[LongEqual]", 
   SuperscriptBox["2", "p"]}], TraditionalForm]], "Input",
 Evaluatable->False,
 CellChangeTimes->{{3.583328099007024*^9, 3.5833281227558403`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", 
   RowBox[{"Convergence", " ", "factor", " ", "definition"}], "*)"}], 
  "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Q", "[", 
     RowBox[{
      RowBox[{"t_", "?", "NumericQ"}], ",", 
      RowBox[{"p_:", "2"}]}], "]"}], ":=", 
    RowBox[{"With", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"u1", "=", 
         RowBox[{
          RowBox[{"u", "[", "t", "]"}], "/.", 
          RowBox[{"sol", "[", "1", "]"}]}]}], ",", 
        RowBox[{"u2", "=", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            RowBox[{"u", "[", "t", "]"}], "/.", 
            RowBox[{"sol", "[", "2", "]"}]}], ")"}], "[", 
          RowBox[{"[", 
           RowBox[{"All", ",", 
            RowBox[{";;", ";;", "2"}]}], "]"}], "]"}]}], ",", 
        RowBox[{"u4", "=", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            RowBox[{"u", "[", "t", "]"}], "/.", 
            RowBox[{"sol", "[", "4", "]"}]}], ")"}], "[", 
          RowBox[{"[", 
           RowBox[{"All", ",", 
            RowBox[{";;", ";;", "4"}]}], "]"}], "]"}]}]}], "}"}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{"Log2", "[", 
       FractionBox[
        RowBox[{
         RowBox[{
          RowBox[{"Norm", "[", 
           RowBox[{"#", ",", "p"}], "]"}], "&"}], "/@", 
         RowBox[{"(", 
          RowBox[{"u2", "-", "u1"}], ")"}]}], 
        RowBox[{
         RowBox[{
          RowBox[{"Norm", "[", 
           RowBox[{"#", ",", "p"}], "]"}], "&"}], "/@", 
         RowBox[{"(", 
          RowBox[{"u4", "-", "u2"}], ")"}]}]], "]"}]}], "\[IndentingNewLine]",
      "]"}]}], ";"}]}]], "Input",
 CellChangeTimes->{{3.58048110537645*^9, 3.5804812858243513`*^9}, {
   3.5804814808613863`*^9, 3.5804815031881866`*^9}, {3.5804815415713577`*^9, 
   3.580481594471779*^9}, {3.5804816337252274`*^9, 3.580481684948855*^9}, 
   3.580485813263278*^9, {3.583328144179401*^9, 3.583328153859058*^9}, {
   3.583328205436922*^9, 3.583328233185747*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Plot", "[", 
  RowBox[{
   RowBox[{"Q", "[", 
    RowBox[{"t", ",", "2"}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"t", ",", "tmin", ",", "tmax"}], "}"}], ",", 
   "\[IndentingNewLine]", 
   RowBox[{"AxesLabel", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"t", ",", 
      RowBox[{"Q", "[", "t", "]"}]}], "}"}]}], ",", 
   RowBox[{"PlotLabel", "\[Rule]", "\"\<Convergence factor\>\""}], ",", 
   RowBox[{"Prolog", "\[RuleDelayed]", 
    RowBox[{"{", 
     RowBox[{"Gray", ",", "Dashed", ",", 
      RowBox[{"Line", "[", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"tmin", ",", "4"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"tmax", ",", "4"}], "}"}]}], "}"}], "]"}]}], "}"}]}], ",", 
   "\[IndentingNewLine]", 
   RowBox[{"PlotRange", "\[Rule]", "All"}]}], "\[IndentingNewLine]", 
  "]"}]], "Input",
 CellChangeTimes->{{3.58048128851897*^9, 3.580481303700016*^9}, {
  3.580481514316379*^9, 3.580481526724556*^9}, {3.580481599838146*^9, 
  3.58048160004539*^9}, {3.580481676092106*^9, 3.58048167638862*^9}, {
  3.580481993387314*^9, 3.580482124074348*^9}, {3.58048569139007*^9, 
  3.5804857078190517`*^9}, {3.580485816620412*^9, 3.580485818105839*^9}, {
  3.583328806070653*^9, 3.583328810110278*^9}}],

Cell[BoxData[
 GraphicsBox[{{}, {}, 
   {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJwUm3c8le8bx4Ui6zwHyUpGIZVUMjKumwqVSrKyRxqoUCijSKGSJBQR2ZHs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     "]], LineBox[CompressedData["
1:eJwUmnc81d8fx+3N/dx7pSW7zJRRKLxPkRKlNMgoEalkVfSNCg0qCUlRIrtC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     "]]}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesLabel->{
    FormBox["t", TraditionalForm], 
    FormBox[
     RowBox[{"Q", "(", "t", ")"}], TraditionalForm]},
  AxesOrigin->{0, 2.9000000000000004`},
  Method->{},
  PlotLabel->FormBox["\"Convergence factor\"", TraditionalForm],
  PlotRange->{All, All},
  PlotRangeClipping->True,
  PlotRangePadding->{Automatic, Automatic},
  Prolog->{
    GrayLevel[0.5], 
    Dashing[{Small, Small}], 
    LineBox[
     NCache[{{0, 4}, {Pi, 4}}, {{0, 4}, {3.141592653589793, 4}}]]}]], "Output",\

 CellChangeTimes->{
  3.58332824687101*^9, 3.583328502688395*^9, {3.583328793182073*^9, 
   3.5833288111674347`*^9}, 3.583328933616783*^9, 3.583330650619195*^9}]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"Clear", "[", 
   RowBox[{
   "\[CapitalPi]", ",", "\[CapitalPhi]", ",", "\[Epsilon]", ",", "\[Sigma]", 
    ",", "sol", ",", "Q"}], "]"}], ";"}]], "Input",
 CellChangeTimes->{{3.580479548868829*^9, 3.580479558687595*^9}, {
   3.5804821465379047`*^9, 3.580482149177795*^9}, 3.580485820564115*^9, 
   3.583328402047596*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Trick with the l\[CloseCurlyQuote]Hopital\[CloseCurlyQuote]s rule\
\>", "Subsubsection",
 CellChangeTimes->{{3.580479535089082*^9, 3.580479537211094*^9}, {
  3.5804821719809303`*^9, 3.580482182399352*^9}, {3.5806313872335167`*^9, 
  3.580631394181633*^9}, {3.5833284532110987`*^9, 3.583328455195744*^9}}],

Cell[TextData[{
 "This section contains example showing how different formulations of the \
equatiotions, with use of the l\[CloseCurlyQuote]Hopital\[CloseCurlyQuote]s \
rule near the boundaries, affects numerical solution. Using the option ",
 StyleBox["\[OpenCurlyDoubleQuote]lHopitalsRule\[CloseCurlyDoubleQuote]->{\
lbound, rbound}", "Input"],
 " passed to the ",
 StyleBox["Solver", "Input"],
 " function, one can control if and where this trick is used. Passed numbers ",
 StyleBox["{lbound, rbound}", "Input"],
 " are used to control portinon of the computational grid where this trick is \
applied. For ",
 StyleBox["\[OpenCurlyDoubleQuote]lHopitalsRule\[CloseCurlyDoubleQuote]->{1/4,\
 1/4}", "Input"],
 " it is used in the first and the last quarter of a grid points, with option \
",
 StyleBox["\[OpenCurlyDoubleQuote]lHopitalsRule\[CloseCurlyDoubleQuote]->{0, \
1/5}", "Input"],
 " l\[CloseCurlyQuote]Hopital rule will be applied to the last 1/5 of the \
grid, whereas setting  ",
 StyleBox["\[OpenCurlyDoubleQuote]lHopitalsRule\[CloseCurlyDoubleQuote]->{0, \
0}", "Input"],
 " will disable it at all. Example showing how this option affects the \
solution is presented in the last section."
}], "Item",
 CellChangeTimes->{{3.584680228552973*^9, 3.584680279434443*^9}, {
  3.584683639002372*^9, 3.584683640869548*^9}}],

Cell["Spatial grid", "Text",
 CellChangeTimes->{{3.580479695297282*^9, 3.580479697811748*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"X", "=", 
   RowBox[{"With", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"n", "=", "65"}], "}"}], ",", 
     RowBox[{"N", "@", 
      RowBox[{"Range", "[", 
       RowBox[{"0", ",", 
        FractionBox["\[Pi]", "2"], ",", 
        RowBox[{
         FractionBox["\[Pi]", "2"], "/", 
         RowBox[{"(", 
          RowBox[{"n", "-", "1"}], ")"}]}]}], "]"}]}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"X", "//", "Short"}]}], "Input",
 CellChangeTimes->{{3.580473839161524*^9, 3.580473962048113*^9}, {
   3.5804741455288963`*^9, 3.5804741906250134`*^9}, 3.580474351002509*^9, {
   3.580474602455761*^9, 3.5804746047943*^9}, {3.5804746965631523`*^9, 
   3.580474721047655*^9}, {3.580474756047286*^9, 3.5804747639445*^9}, 
   3.5804749570857677`*^9, {3.5804750108417463`*^9, 3.5804750124867153`*^9}, {
   3.5804750830503607`*^9, 3.5804750835631523`*^9}, {3.580475117223477*^9, 
   3.580475119951385*^9}, {3.580475228766856*^9, 3.5804752310820503`*^9}, {
   3.5804769440725193`*^9, 3.58047696553258*^9}, {3.5804774352383137`*^9, 
   3.580477489567349*^9}, 3.580477590923512*^9, {3.5804776331179743`*^9, 
   3.580477633442761*^9}, {3.580477759752592*^9, 3.580477760947213*^9}, {
   3.580477793245263*^9, 3.58047779881894*^9}, {3.580477851289905*^9, 
   3.580477852960273*^9}, {3.58047960503271*^9, 3.5804796099955177`*^9}, {
   3.5804796609038486`*^9, 3.580479745350217*^9}, 3.580627833434416*^9, {
   3.580627937868588*^9, 3.580627940802422*^9}, {3.580628348416924*^9, 
   3.5806283486937027`*^9}, {3.5806322413744783`*^9, 3.580632241803946*^9}, {
   3.580632950734221*^9, 3.580632954123193*^9}, {3.5833284132881603`*^9, 
   3.58332841684634*^9}}],

Cell[BoxData[
 TagBox[
  RowBox[{"{", 
   RowBox[{
   "0.`", ",", "0.02454369260617026`", ",", "0.04908738521234052`", ",", 
    RowBox[{"\[LeftSkeleton]", "60", "\[RightSkeleton]"}], ",", 
    "1.5462526341887264`", ",", "1.5707963267948966`"}], "}"}],
  Short]], "Output",
 CellChangeTimes->{3.583328939675848*^9}]
}, Open  ]],

Cell["Initial data", "Text",
 CellChangeTimes->{{3.580479750425507*^9, 3.580479752686597*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"{", 
    RowBox[{"\[Epsilon]", ",", "\[Sigma]"}], "}"}], "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"1", "/", "2"}], ",", 
     RowBox[{"1", "/", "4"}]}], "}"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"\[CapitalPi]", "[", "x_", "]"}], ":=", 
   RowBox[{
    RowBox[{"If", "[", 
     RowBox[{
      RowBox[{"x", "\[Equal]", 
       RowBox[{"\[Pi]", "/", "2"}]}], ",", "0", ",", 
      RowBox[{
       RowBox[{"2", "/", "\[Pi]"}], " ", "\[Epsilon]", " ", 
       RowBox[{"Exp", "[", 
        RowBox[{"-", 
         SuperscriptBox[
          RowBox[{"(", 
           FractionBox[
            RowBox[{"Tan", "[", "x", "]"}], 
            RowBox[{
             RowBox[{"\[Pi]", "/", "2"}], " ", "\[Sigma]"}]], ")"}], "2"]}], 
        "]"}]}]}], "]"}], "//", 
    RowBox[{
     RowBox[{"Chop", "[", 
      RowBox[{"#", ",", "$MinMachineNumber"}], "]"}], "&"}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"\[CapitalPhi]", "[", "x_", "]"}], ":=", 
   RowBox[{
    RowBox[{"If", "[", 
     RowBox[{
      RowBox[{"x", "\[Equal]", 
       RowBox[{"\[Pi]", "/", "2"}]}], ",", "0", ",", 
      RowBox[{
       RowBox[{"2", "/", "\[Pi]"}], " ", "\[Epsilon]", " ", "x", " ", 
       RowBox[{"Exp", "[", 
        RowBox[{"-", 
         SuperscriptBox[
          RowBox[{"(", 
           FractionBox[
            RowBox[{"Tan", "[", "x", "]"}], 
            RowBox[{
             RowBox[{"\[Pi]", "/", "2"}], " ", "\[Sigma]"}]], ")"}], "2"]}], 
        "]"}]}]}], "]"}], "//", 
    RowBox[{
     RowBox[{"Chop", "[", 
      RowBox[{"#", ",", "$MinMachineNumber"}], "]"}], "&"}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"SetAttributes", "[", 
     RowBox[{"#", ",", "Listable"}], "]"}], "&"}], "/@", 
   RowBox[{"{", 
    RowBox[{"\[CapitalPi]", ",", "\[CapitalPhi]"}], "}"}]}], ";"}]}], "Input",\

 CellChangeTimes->{{3.580479756096974*^9, 3.5804798430614862`*^9}, {
  3.580479924186016*^9, 3.580479939583112*^9}, {3.580532586009873*^9, 
  3.580532598863662*^9}, {3.580532805931031*^9, 3.580532807550427*^9}, {
  3.5833284267240343`*^9, 3.583328428515902*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Plot", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"\[CapitalPhi]", "[", "x", "]"}], ",", 
     RowBox[{"\[CapitalPi]", "[", "x", "]"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"x", ",", "0", ",", 
     RowBox[{"\[Pi]", "/", "2"}]}], "}"}], ",", "\[IndentingNewLine]", 
   RowBox[{"AxesLabel", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"x", ",", "None"}], "}"}]}], ",", 
   RowBox[{"PlotLabel", "\[Rule]", "\"\<Initial data profiles\>\""}], ",", 
   RowBox[{"PlotRange", "\[Rule]", "All"}], ",", 
   RowBox[{"PlotLegends", "\[Rule]", 
    RowBox[{"LineLegend", "[", 
     RowBox[{"{", 
      RowBox[{
      "\"\<\[CapitalPhi](0,x)\>\"", ",", "\"\<\[CapitalPi](0,x)\>\""}], "}"}],
      "]"}]}]}], "\[IndentingNewLine]", "]"}]], "Input",
 CellChangeTimes->{{3.580479845036976*^9, 3.5804799117485447`*^9}, {
  3.5804799511122093`*^9, 3.580479969381691*^9}, {3.5804801592634783`*^9, 
  3.5804801648997087`*^9}, {3.580480195848237*^9, 3.5804802570793133`*^9}, {
  3.5804823973656597`*^9, 3.5804824000711603`*^9}, {3.580484639891711*^9, 
  3.580484647814703*^9}}],

Cell[BoxData[
 TemplateBox[{GraphicsBox[{{}, {}, {
      Hue[0.67, 0.6, 0.6], 
      LineBox[CompressedData["
1:eJxFlnc41W/4x60ykj1CZY8oZKfz+dwRCtmVyggJ2Vtmha+VhGRlZTullC0r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       "]]}, {
      Hue[0.9060679774997897, 0.6, 0.6], 
      LineBox[CompressedData["
1:eJxF13k0VV+8AHBTUmZFyKzMYxFxz/lGUobMUUimzDMpQ0qZkmQOZcic4keU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       "]]}}, 
    AspectRatio -> NCache[GoldenRatio^(-1), 0.6180339887498948], Axes -> True,
     AxesLabel -> {
      FormBox["x", TraditionalForm], None}, AxesOrigin -> {0, 0}, 
    Method -> {}, PlotLabel -> 
    FormBox["\"Initial data profiles\"", TraditionalForm], 
    PlotRange -> {All, All}, PlotRangeClipping -> True, 
    PlotRangePadding -> {Automatic, Automatic}],
   TemplateBox[{"\"\[CapitalPhi](0,x)\"", "\"\[CapitalPi](0,x)\""}, 
    "LineLegend", DisplayFunction -> (StyleBox[
      StyleBox[
       PaneBox[
        TagBox[
         GridBox[{{
            TagBox[
             GridBox[{{
                GraphicsBox[{{
                   Directive[
                    EdgeForm[{
                    Opacity[0.3], 
                    GrayLevel[0]}], 
                    Hue[0.67, 0.6, 0.6]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                   Directive[
                    EdgeForm[{
                    Opacity[0.3], 
                    GrayLevel[0]}], 
                    Hue[0.67, 0.6, 0.6]], {}}}, AspectRatio -> Full, 
                 ImageSize -> {20, 10}, PlotRangePadding -> None, 
                 ImagePadding -> 1, 
                 BaselinePosition -> (Scaled[0.1] -> Baseline)], #}, {
                GraphicsBox[{{
                   Directive[
                    EdgeForm[{
                    Opacity[0.3], 
                    GrayLevel[0]}], 
                    Hue[0.9060679774997897, 0.6, 0.6]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                   Directive[
                    EdgeForm[{
                    Opacity[0.3], 
                    GrayLevel[0]}], 
                    Hue[0.9060679774997897, 0.6, 0.6]], {}}}, AspectRatio -> 
                 Full, ImageSize -> {20, 10}, PlotRangePadding -> None, 
                 ImagePadding -> 1, 
                 BaselinePosition -> (Scaled[0.1] -> Baseline)], #2}}, 
              GridBoxAlignment -> {
               "Columns" -> {Center, Left}, "Rows" -> {{Baseline}}}, 
              AutoDelete -> False, 
              GridBoxDividers -> {
               "Columns" -> {{False}}, "Rows" -> {{False}}}, 
              GridBoxItemSize -> {"Columns" -> {{All}}, "Rows" -> {{All}}}, 
              GridBoxSpacings -> {"Columns" -> {{0.5}}, "Rows" -> {{0.8}}}], 
             "Grid"]}}, 
          GridBoxAlignment -> {"Columns" -> {{Left}}, "Rows" -> {{Top}}}, 
          AutoDelete -> False, 
          GridBoxItemSize -> {
           "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
          GridBoxSpacings -> {"Columns" -> {{1}}, "Rows" -> {{0}}}], "Grid"], 
        Alignment -> Left, AppearanceElements -> None, 
        ImageMargins -> {{5, 5}, {5, 5}}, ImageSizeAction -> "ResizeToFit"], 
       LineIndent -> 0, StripOnInput -> False], {FontFamily -> "Times"}, 
      Background -> Automatic, StripOnInput -> False]& ), Editable -> True, 
    InterpretationFunction :> (RowBox[{"LineLegend", "[", 
       RowBox[{
         RowBox[{"{", 
           RowBox[{
             RowBox[{"Directive", "[", 
               RowBox[{"Hue", "[", 
                 RowBox[{"0.67`", ",", "0.6`", ",", "0.6`"}], "]"}], "]"}], 
             ",", 
             RowBox[{"Directive", "[", 
               RowBox[{"Hue", "[", 
                 RowBox[{"0.9060679774997897`", ",", "0.6`", ",", "0.6`"}], 
                 "]"}], "]"}]}], "}"}], ",", 
         RowBox[{"{", 
           RowBox[{#, ",", #2}], "}"}], ",", 
         RowBox[{"LegendLayout", "\[Rule]", "\"Column\""}]}], "]"}]& )]},
  "Legended",
  DisplayFunction->(GridBox[{{
      TagBox[
       ItemBox[
        PaneBox[
         TagBox[#, "SkipImageSizeLevel"], Alignment -> {Center, Baseline}, 
         BaselinePosition -> Baseline], DefaultBaseStyle -> "Labeled"], 
       "SkipImageSizeLevel"], 
      ItemBox[#2, DefaultBaseStyle -> "LabeledLabel"]}}, 
    GridBoxAlignment -> {"Columns" -> {{Center}}, "Rows" -> {{Center}}}, 
    AutoDelete -> False, GridBoxItemSize -> Automatic, 
    BaselinePosition -> {1, 1}]& ),
  Editable->True,
  InterpretationFunction->(RowBox[{"Legended", "[", 
     RowBox[{#, ",", 
       RowBox[{"Placed", "[", 
         RowBox[{#2, ",", "After"}], "]"}]}], "]"}]& )]], "Output",
 CellChangeTimes->{3.583328943008616*^9}]
}, Open  ]],

Cell[TextData[{
 "Symbol ",
 StyleBox["sol[True]", "Input"],
 " stores solution with the l\[CloseCurlyQuote]Hopital rule, whereas solution \
in ",
 StyleBox["sol[False]", "Input"],
 " is obtained without this trick. "
}], "Text",
 CellChangeTimes->{{3.5804824125567627`*^9, 3.580482520290567*^9}, {
  3.580485870207408*^9, 3.58048587198914*^9}, {3.583328445714367*^9, 
  3.583328446215826*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"sol", "[", "True", "]"}], ",", 
      RowBox[{"sol", "[", "False", "]"}]}], "}"}], "=", 
    RowBox[{
     RowBox[{
      RowBox[{"First", "@", 
       RowBox[{"Solver", "[", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"X", ",", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"\[CapitalPhi]", "[", "X", "]"}], ",", 
             RowBox[{"\[CapitalPi]", "[", "X", "]"}]}], "}"}]}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"tmin", "=", "0"}], ",", 
           RowBox[{"tmax", "=", 
            RowBox[{"2", "\[Pi]"}]}]}], "}"}], ",", 
         RowBox[{"\"\<DissipationStrength\>\"", "\[Rule]", "0"}], ",", 
         RowBox[{"\"\<lHopitalsRule\>\"", "\[Rule]", "#"}], ",", 
         RowBox[{"Method", "\[Rule]", 
          RowBox[{"{", 
           RowBox[{"\"\<ExplicitRungeKutta\>\"", ",", 
            RowBox[{"\"\<DifferenceOrder\>\"", "\[Rule]", "4"}], ",", 
            RowBox[{"\"\<StiffnessTest\>\"", "\[Rule]", "False"}]}], "}"}]}], 
         ",", 
         RowBox[{"MaxStepSize", "\[Rule]", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             RowBox[{"X", "[", 
              RowBox[{"[", "2", "]"}], "]"}], "-", 
             RowBox[{"X", "[", 
              RowBox[{"[", "1", "]"}], "]"}]}], ")"}], "/", "2"}]}], ",", 
         RowBox[{"MaxSteps", "\[Rule]", "Infinity"}]}], "]"}]}], "&"}], "/@", 
     
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"1", "/", "4"}], ",", 
         RowBox[{"1", "/", "4"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", "0"}], "}"}]}], "}"}]}]}], ";"}], "//", 
  "AbsoluteTiming"}]], "Input",
 CellChangeTimes->{
  3.580482203097102*^9, {3.58048226057412*^9, 3.580482324588829*^9}, 
   3.580532826362926*^9, {3.580628343517495*^9, 3.580628343943095*^9}, {
   3.580628830446454*^9, 3.580628830727755*^9}, {3.580629930071706*^9, 
   3.580629930195771*^9}, {3.5806302092000217`*^9, 3.580630248271907*^9}, 
   3.58063056475359*^9, 3.580631087789867*^9, {3.580631959821706*^9, 
   3.580631960286566*^9}, 3.580632232975902*^9, {3.583328948988241*^9, 
   3.583328951922822*^9}, {3.5833289894391003`*^9, 3.583328995999954*^9}, {
   3.5833290673302097`*^9, 3.583329074435234*^9}, {3.583329175783791*^9, 
   3.5833291775327272`*^9}, {3.583329233564763*^9, 3.5833292337581263`*^9}, {
   3.583329458832024*^9, 3.583329470847332*^9}, 3.583329657187402*^9, {
   3.5833297960546217`*^9, 3.5833298000364513`*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "145.47291100000001051739673130214214324951`8.183382042694227", ",", 
   "Null"}], "}"}]], "Output",
 CellChangeTimes->{3.583328945722356*^9, 3.5833289858934526`*^9, 
  3.583329075653928*^9, 3.583329208789321*^9, 3.583329298245133*^9, 
  3.583329530021921*^9, 3.583329739619419*^9, 3.58332994602597*^9}]
}, Open  ]],

Cell[BoxData[
 RowBox[{"Manipulate", "[", "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"makeplot", "=", 
     RowBox[{
      RowBox[{"ListPlot", "[", 
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{"Transpose", "@", 
           RowBox[{"{", 
            RowBox[{"X", ",", 
             RowBox[{
              RowBox[{"Tan", "[", "X", "]"}], 
              RowBox[{"Part", "[", 
               RowBox[{
                RowBox[{
                 RowBox[{"u", "[", "t", "]"}], "/.", 
                 RowBox[{"sol", "[", "#", "]"}]}], ",", 
                RowBox[{"If", "[", 
                 RowBox[{
                  RowBox[{"f", "===", "\[CapitalPhi]"}], ",", "1", ",", "2"}],
                  "]"}]}], "]"}]}]}], "}"}]}], "&"}], "/@", 
         RowBox[{"{", 
          RowBox[{"True", ",", "False"}], "}"}]}], ",", "\[IndentingNewLine]", 
        RowBox[{"Joined", "\[Rule]", "True"}], ",", 
        RowBox[{"AxesLabel", "\[Rule]", 
         RowBox[{"{", 
          RowBox[{"x", ",", "None"}], "}"}]}], ",", 
        RowBox[{"ImageSize", "\[Rule]", "Medium"}], ",", 
        RowBox[{"PlotLegends", "\[Rule]", 
         RowBox[{"LineLegend", "[", 
          RowBox[{"{", 
           RowBox[{"\"\<with lHopitalsRule\>\"", ",", "\"\<without\>\""}], 
           "}"}], "]"}]}], ",", 
        RowBox[{"PlotStyle", "\[Rule]", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"Directive", "[", 
             RowBox[{"Thick", ",", "#"}], "]"}], "&"}], "/@", 
           RowBox[{"{", 
            RowBox[{"Blue", ",", "Red"}], "}"}]}], ")"}]}], ",", 
        RowBox[{"MeshStyle", "\[Rule]", "Black"}], ",", "##"}], "]"}], 
      "&"}]}], ";", "\[IndentingNewLine]", 
    RowBox[{"With", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"p1", "=", 
         RowBox[{"makeplot", "[", 
          RowBox[{
           RowBox[{"PlotRange", "\[Rule]", 
            RowBox[{"{", 
             RowBox[{"All", ",", 
              RowBox[{"{", 
               RowBox[{
                RowBox[{
                 RowBox[{"-", "\[Epsilon]"}], "/", "10"}], ",", 
                RowBox[{"\[Epsilon]", "/", "10"}]}], "}"}]}], "}"}]}], ",", 
           RowBox[{"PlotLabel", "\[Rule]", 
            RowBox[{"ToString", "[", 
             RowBox[{
              RowBox[{
               RowBox[{"Tan", "[", "x", "]"}], 
               RowBox[{"f", "[", 
                RowBox[{"\"\<t\>\"", ",", "x"}], "]"}]}], ",", 
              "TraditionalForm"}], "]"}]}]}], "]"}]}], ",", 
        "\[IndentingNewLine]", 
        RowBox[{"p2", "=", 
         RowBox[{"makeplot", "[", 
          RowBox[{
           RowBox[{"PlotRange", "\[Rule]", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"{", 
               RowBox[{"0", ",", 
                RowBox[{"1", "/", "2"}]}], "}"}], ",", 
              RowBox[{"{", 
               RowBox[{
                RowBox[{"-", "0.005"}], ",", "0.005"}], "}"}]}], "}"}]}], ",", 
           RowBox[{"Mesh", "\[Rule]", "All"}]}], "]"}]}], ",", 
        "\[IndentingNewLine]", 
        RowBox[{"p3", "=", 
         RowBox[{"makeplot", "[", 
          RowBox[{
           RowBox[{"PlotRange", "\[Rule]", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"{", 
               RowBox[{
                RowBox[{"\[Pi]", "/", "2"}], ",", 
                RowBox[{
                 RowBox[{"\[Pi]", "/", "2"}], "-", 
                 RowBox[{"1", "/", "2"}]}]}], "}"}], ",", 
              RowBox[{"{", 
               RowBox[{
                RowBox[{"-", "0.005"}], ",", "0.005"}], "}"}]}], "}"}]}], ",", 
           RowBox[{"Mesh", "\[Rule]", "All"}]}], "]"}]}]}], "}"}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{"Column", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"p1", ",", "p2", ",", "p3"}], "}"}], ",", "Right", ",", 
        RowBox[{"Spacings", "\[Rule]", "3"}]}], "]"}]}], 
     "\[IndentingNewLine]", "]"}]}], ",", "\[IndentingNewLine]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"t", ",", "0", ",", 
       RowBox[{"TraditionalForm", "@", "t"}]}], "}"}], ",", "tmin", ",", 
     "tmax", ",", 
     RowBox[{"Appearance", "\[Rule]", "\"\<Labeled\>\""}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
      "f", ",", "\[CapitalPhi]", ",", "\"\<Dynamical function: \>\""}], "}"}],
      ",", 
     RowBox[{"{", 
      RowBox[{"\[CapitalPhi]", ",", "\[CapitalPi]"}], "}"}]}], "}"}]}], 
  "\[IndentingNewLine]", "]"}]], "Input",
 CellChangeTimes->{{3.5804827581698847`*^9, 3.580482807796895*^9}, {
   3.580482839884158*^9, 3.580482924857209*^9}, {3.5804829912230062`*^9, 
   3.580483061566345*^9}, {3.5804831104083023`*^9, 3.580483110815585*^9}, {
   3.580483184151328*^9, 3.580483190280983*^9}, {3.580483285167192*^9, 
   3.5804833708252172`*^9}, {3.580483466200325*^9, 3.5804834702172327`*^9}, {
   3.580483509799652*^9, 3.5804835506235523`*^9}, {3.580483591178072*^9, 
   3.580483591578661*^9}, {3.580483650175756*^9, 3.580483766441402*^9}, 
   3.580483809408943*^9, {3.58048386698066*^9, 3.5804839490915117`*^9}, {
   3.5804839882606983`*^9, 3.580484087104474*^9}, {3.580484125670429*^9, 
   3.580484256144045*^9}, {3.580484286148494*^9, 3.5804842905678377`*^9}, {
   3.580484323726184*^9, 3.5804845851366673`*^9}, {3.5804846701996202`*^9, 
   3.5804846915005617`*^9}, {3.580485948279845*^9, 3.580485957745386*^9}, {
   3.580532697209173*^9, 3.5805326988629227`*^9}, {3.58053288866994*^9, 
   3.580532917191016*^9}, {3.5806285269006243`*^9, 3.580628535799446*^9}, {
   3.580628636620205*^9, 3.5806286963680153`*^9}, {3.5806287434885798`*^9, 
   3.5806287793788*^9}, {3.5833291173167458`*^9, 3.583329141427916*^9}}],

Cell[BoxData[
 RowBox[{"Clear", "[", 
  RowBox[{
  "X", ",", "\[CapitalPi]", ",", "\[CapitalPhi]", ",", "\[Epsilon]", ",", 
   "\[Sigma]", ",", "tmin", ",", "tmax", ",", "sol", ",", "makeplot"}], 
  "]"}]], "Input",
 CellChangeTimes->{{3.580479548868829*^9, 3.580479558687595*^9}, {
  3.580485975237316*^9, 3.580485978370904*^9}, {3.580532625104837*^9, 
  3.5805326288619432`*^9}, {3.5806332388385067`*^9, 3.580633239049601*^9}}]
}, Open  ]]
}, Open  ]]
},
WindowSize->{740, 867},
WindowMargins->{{Automatic, 171}, {61, Automatic}},
ShowSelection->True,
FrontEndVersion->"9.0 for Linux x86 (64-bit) (February 7, 2013)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[557, 20, 309, 6, 51, "Text"],
Cell[CellGroupData[{
Cell[891, 30, 148, 2, 44, "Subsection"],
Cell[CellGroupData[{
Cell[1064, 36, 125, 2, 35, "Subsubsection",
 InitializationGroup->True],
Cell[1192, 40, 425, 8, 66, "Item"],
Cell[1620, 50, 189, 4, 31, "Input"],
Cell[1812, 56, 157, 3, 31, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2006, 64, 112, 1, 35, "Subsubsection"],
Cell[2121, 67, 1464, 38, 68, "Item"],
Cell[3588, 107, 179, 4, 30, "Text"],
Cell[3770, 113, 270, 7, 31, "Input"],
Cell[4043, 122, 149, 2, 30, "Text"],
Cell[CellGroupData[{
Cell[4217, 128, 1524, 30, 66, "Input"],
Cell[5744, 160, 316, 8, 31, "Output"]
}, Open  ]],
Cell[6075, 171, 455, 16, 32, "Text"],
Cell[6533, 189, 2778, 83, 212, "Input"],
Cell[CellGroupData[{
Cell[9336, 276, 181, 3, 31, "Input"],
Cell[9520, 281, 2119, 34, 235, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[11676, 320, 1491, 40, 112, "Input"],
Cell[13170, 362, 39085, 654, 204, "Output"]
}, Open  ]],
Cell[52270, 1019, 270, 7, 31, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[52577, 1031, 101, 1, 35, "Subsubsection"],
Cell[52681, 1034, 2462, 64, 203, "Item"],
Cell[55146, 1100, 149, 2, 30, "Text"],
Cell[CellGroupData[{
Cell[55320, 1106, 1550, 31, 66, "Input"],
Cell[56873, 1139, 316, 8, 31, "Output"]
}, Open  ]],
Cell[57204, 1150, 198, 3, 30, "Text"],
Cell[57405, 1155, 2097, 65, 172, "Input"],
Cell[CellGroupData[{
Cell[59527, 1224, 1101, 25, 92, "Input"],
Cell[60631, 1251, 33780, 583, 247, "Output"]
}, Open  ]],
Cell[94426, 1837, 178, 4, 30, "Text"],
Cell[CellGroupData[{
Cell[94629, 1845, 553, 16, 31, "Input"],
Cell[95185, 1863, 362, 12, 31, "Output"]
}, Open  ]],
Cell[95562, 1878, 175, 4, 30, "Text"],
Cell[CellGroupData[{
Cell[95762, 1886, 149, 3, 31, "Input"],
Cell[95914, 1891, 5956, 112, 523, "Output"]
}, Open  ]],
Cell[101885, 2006, 161, 3, 30, "Text"],
Cell[CellGroupData[{
Cell[102071, 2013, 1238, 34, 92, "Input"],
Cell[103312, 2049, 3696, 71, 204, "Output"]
}, Open  ]],
Cell[107023, 2123, 396, 10, 30, "Text"],
Cell[107422, 2135, 1758, 45, 132, "Input"],
Cell[109183, 2182, 2686, 72, 212, "Input"],
Cell[111872, 2256, 328, 7, 31, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[112237, 2268, 205, 3, 35, "Subsubsection"],
Cell[112445, 2273, 248, 5, 45, "Item"],
Cell[112696, 2280, 344, 8, 31, "Input"],
Cell[113043, 2290, 2050, 64, 172, "Input"],
Cell[115096, 2356, 561, 20, 51, "Text"],
Cell[CellGroupData[{
Cell[115682, 2380, 2428, 60, 198, "Input"],
Cell[118113, 2442, 1405, 41, 72, "Output"]
}, Open  ]],
Cell[119533, 2486, 269, 8, 32, "Text"],
Cell[119805, 2496, 893, 28, 58, "Input",
 Evaluatable->False],
Cell[120701, 2526, 255, 7, 32, "Text"],
Cell[120959, 2535, 353, 10, 42, "Input",
 Evaluatable->False],
Cell[121315, 2547, 2025, 57, 173, "Input"],
Cell[CellGroupData[{
Cell[123365, 2608, 1275, 31, 112, "Input"],
Cell[124643, 2641, 89519, 1479, 269, "Output"]
}, Open  ]],
Cell[214177, 4123, 356, 8, 31, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[214570, 4136, 314, 5, 35, "Subsubsection"],
Cell[214887, 4143, 1330, 26, 179, "Item"],
Cell[216220, 4171, 94, 1, 30, "Text"],
Cell[CellGroupData[{
Cell[216339, 4176, 1701, 33, 66, "Input"],
Cell[218043, 4211, 316, 8, 31, "Output"]
}, Open  ]],
Cell[218374, 4222, 94, 1, 30, "Text"],
Cell[218471, 4225, 2194, 66, 172, "Input"],
Cell[CellGroupData[{
Cell[220690, 4295, 1103, 25, 92, "Input"],
Cell[221796, 4322, 33780, 583, 247, "Output"]
}, Open  ]],
Cell[255591, 4908, 394, 10, 51, "Text"],
Cell[CellGroupData[{
Cell[256010, 4922, 2588, 62, 132, "Input"],
Cell[258601, 4986, 345, 7, 31, "Output"]
}, Open  ]],
Cell[258961, 4996, 5742, 138, 392, "Input"],
Cell[264706, 5136, 429, 8, 31, "Input"]
}, Open  ]]
}, Open  ]]
}
]
*)

(* End of internal cache information *)
